@@ -11,7 +11,7 @@
  * @author Matthias Biggeleben <matthias.biggeleben@open-xchange.com>
  */
 
-define('io.ox/backbone/mini-views/dropdown', ['io.ox/backbone/mini-views/abstract'], function (AbstractView) {
+define('io.ox/backbone/mini-views/dropdown', ['io.ox/backbone/mini-views/abstract', 'io.ox/core/a11y'], function (AbstractView, a11y) {
 
     'use strict';
 
@@ -32,13 +32,19 @@ define('io.ox/backbone/mini-views/dropdown', ['io.ox/backbone/mini-views/abstrac
             'shown.bs.dropdown': 'onShown',
             'hidden.bs.dropdown': 'resetDropdownOverlay',
             'keydown *[data-toggle="dropdown"]': 'onKeyDown',
-            'ready': 'onReady'
+            'ready': 'onReady',
+            'contextmenu': 'onContextMenu'
+        },
+
+        onContextMenu: function (e) {
+            e.preventDefault();
         },
 
         onReady: function () {
-            if (_.device('smartphone')) return;
+            if (_.device('smartphone') && !this.options.dontProcessOnMobile) return;
             if (this.smart === false && !this.$overlay) return;
             if (!this.$el.hasClass('open')) return;
+            this.$ul.css({ width: 'auto', height: 'auto' });
             this.adjustBounds();
         },
 
@@ -56,9 +62,9 @@ define('io.ox/backbone/mini-views/dropdown', ['io.ox/backbone/mini-views/abstrac
         setDropdownOverlay: function () {
             var self = this;
 
-            this.$overlay = $('<div class="smart-dropdown-container dropdown open">')
-                .addClass(this.$el.prop('className'))
-                .on('ready', this.onReady.bind(this));
+            this.$overlay = $('<div class="smart-dropdown-container dropdown open">', this.onReady.bind(this))
+                .addClass(this.$el.prop('className'));
+
             this.$ul.data('style', this.$ul.attr('style'));
             this.adjustBounds();
 
@@ -80,9 +86,13 @@ define('io.ox/backbone/mini-views/dropdown', ['io.ox/backbone/mini-views/abstrac
 
         adjustBounds: function () {
             var bounds = this.$ul.get(0).getBoundingClientRect(),
+                margins = {
+                    top: parseInt(this.$ul.css('margin-top') || 0, 10),
+                    left: parseInt(this.$ul.css('margin-left') || 0, 10)
+                },
                 positions = {
-                    top: bounds.top,
-                    left: bounds.left,
+                    top: bounds.top - margins.top,
+                    left: bounds.left - margins.left,
                     width: bounds.width,
                     height: 'auto'
                 },
@@ -90,10 +100,10 @@ define('io.ox/backbone/mini-views/dropdown', ['io.ox/backbone/mini-views/abstrac
                 width = this.$toggle.outerWidth(),
                 availableWidth = $(window).width(),
                 availableHeight = $(window).height(),
-                topbar = $('#io-ox-topbar');
+                topbar = $('#io-ox-appcontrol');
 
             // hits bottom ?
-            if (bounds.top + bounds.height > availableHeight + this.margin) {
+            if (bounds.top + bounds.height > availableHeight - this.margin) {
                 // left or right?
                 if ((offset.left + width + bounds.width + this.margin) < availableWidth) {
                     // enough room on right side
@@ -116,6 +126,7 @@ define('io.ox/backbone/mini-views/dropdown', ['io.ox/backbone/mini-views/abstrac
                 if (_.browser.IE === 11) {
                     positions.bottom = 'auto';
                 }
+
                 // outside viewport?
                 positions.left = Math.max(this.margin, positions.left);
                 positions.left = Math.min(availableWidth - positions.width - this.margin, positions.left);
@@ -127,7 +138,7 @@ define('io.ox/backbone/mini-views/dropdown', ['io.ox/backbone/mini-views/abstrac
 
         onShown: function () {
             if (this.smart === false) return;
-            if (_.device('smartphone')) return;
+            if (_.device('smartphone') && !this.options.dontProcessOnMobile) return;
             this.setDropdownOverlay();
         },
 
@@ -135,8 +146,9 @@ define('io.ox/backbone/mini-views/dropdown', ['io.ox/backbone/mini-views/abstrac
             // select first or last item, if already open
             if (!this.$el.hasClass('open') || !this.$overlay) return;
             // special focus handling, because the $ul is no longer a child of the view
-            if (e.which === 40) $('a[role^="menuitem"]', this.$ul).first(':visible').focus();
-            if (e.which === 38) $('a[role^="menuitem"]', this.$ul).last(':visible').focus();
+            var items = a11y.getTabbable(this.$ul);
+            if (e.which === 40) items.first(':visible').focus();
+            if (e.which === 38) items.last(':visible').focus();
             // special close handling on ESC
             if (e.which === 27) {
                 this.$toggle.trigger('click');
@@ -145,6 +157,15 @@ define('io.ox/backbone/mini-views/dropdown', ['io.ox/backbone/mini-views/abstrac
             }
         },
 
+        open: function () {
+            if (this.$el.hasClass('open') || this.$overlay) return;
+            this.$toggle.trigger('click');
+        },
+
+        close: function () {
+            if (this.$el.hasClass('open') || this.$overlay) this.$toggle.trigger('click');
+        },
+
         onClick: function (e) {
             var node = $(e.currentTarget),
                 href = node.attr('href'),
@@ -175,7 +196,7 @@ define('io.ox/backbone/mini-views/dropdown', ['io.ox/backbone/mini-views/abstrac
                 $temp.replaceWith(node);
             }
 
-            if (value === undefined) return;
+            if (!this.options.allowUndefined && value === undefined) return;
             if (this.model) {
                 var nextValue = value;
                 if (toggle) {
@@ -202,6 +223,10 @@ define('io.ox/backbone/mini-views/dropdown', ['io.ox/backbone/mini-views/abstrac
             this.$ul.on('click', 'a', $.proxy(this.onClick, this));
 
             if (this.model) this.listenTo(this.model, 'change', this.options.update || this.update);
+            if (this.options.dontProcessOnMobile) {
+                this.$el.attr('dontProcessOnMobile', true);
+                this.$ul.attr('dontProcessOnMobile', true);
+            }
         },
 
         update: function () {
@@ -250,6 +275,7 @@ define('io.ox/backbone/mini-views/dropdown', ['io.ox/backbone/mini-views/abstrac
                 .attr({
                     'role': role,
                     'aria-checked': checked,
+                    'data-keep-open': options.keepOpen ? true : undefined,
                     'data-name': name,
                     'data-value': this.stringify(value),
                     // you may use toggle with boolean values or provide a toggleValue ('togglevalue' is the option not checked value, 'value' is the option checked value)
@@ -269,9 +295,14 @@ define('io.ox/backbone/mini-views/dropdown', ['io.ox/backbone/mini-views/abstrac
             );
         },
 
+        // used to manually prevent the popup from closing. Make sure to reset this or the popup stays open all the time
+        forceOpen: function (state) {
+            this.$el.attr('forceOpen', state);
+        },
+
         link: function (name, text, callback, options) {
             options = options || {};
-            var link = $('<a href="#" draggable="false" role="menuitem">')
+            var link = $('<a href="#" draggable="false" role="menuitem" tabindex="-1">')
                 .attr('data-name', name)
                 // in firefox draggable=false is not enough to prevent dragging...
                 .on('dragstart', false)
@@ -296,6 +327,9 @@ define('io.ox/backbone/mini-views/dropdown', ['io.ox/backbone/mini-views/abstrac
         },
 
         render: function () {
+            $(this.$el, function () {
+                this.trigger('ready');
+            }.bind(this));
             var label = getLabel(this.options.label),
                 ariaLabel = this.options.aria ? this.options.aria : null;
 
@@ -303,7 +337,10 @@ define('io.ox/backbone/mini-views/dropdown', ['io.ox/backbone/mini-views/abstrac
             this.$el.append(
                 this.$toggle = this.options.$toggle || $('<a href="#" draggable="false">').attr({
                     'aria-label': ariaLabel,
-                    'data-action': this.options.dataAction
+                    'data-action': this.options.dataAction,
+                    'title': this.options.title || null,
+                    // in firefox draggable=false is not enough to prevent dragging...
+                    'ondragstart': _.device('firefox') ? 'return false;' : null
                 })
                 .append(
                     // label
@@ -313,11 +350,6 @@ define('io.ox/backbone/mini-views/dropdown', ['io.ox/backbone/mini-views/abstrac
                 ),
                 this.$ul
             );
-            // add title?
-            if (this.options.title) this.$toggle.attr('title', this.options.title);
-            // in firefox draggable=false is not enough to prevent dragging...
-            if (_.device('firefox')) this.$toggle.attr('ondragstart', 'return false;');
-
             // update custom label
             this.label();
             this.ensureA11y();
@@ -330,10 +362,12 @@ define('io.ox/backbone/mini-views/dropdown', ['io.ox/backbone/mini-views/abstrac
             this.$toggle.attr({
                 'aria-haspopup': true,
                 'aria-expanded': false,
-                role: 'button',
+                'role': 'button',
                 'data-toggle': 'dropdown'
             });
 
+            if (this.options.tabindex) this.$toggle.attr('tabindex', this.options.tabindex);
+
             this.$ul
                 .not('[role]')
                 .attr({ role: 'menu' });
@@ -344,12 +378,13 @@ define('io.ox/backbone/mini-views/dropdown', ['io.ox/backbone/mini-views/abstrac
 
             items
                 .find('a:not([role])')
-                .attr({ role: 'menuitem', tabIndex: '-1' });
+                .attr({ role: 'menuitem', tabindex: '-1' });
         },
 
         prepareReuse: function () {
             if (this.$toggle) this.$toggle.remove();
             if (this.$ul) this.$ul.empty();
+            return this;
         },
 
         dispose: function () {
