@@ -44,7 +44,7 @@ define('io.ox/backbone/views/datepicker', [
             this.options = options || {};
             this.$target = $();
             this.$parent = $(this.options.parent || 'body');
-            this.date = moment(this.options.date);
+            this.date = this.getInitialDate();
             this.mode = 'month';
             this.closing = false;
             // the original constructor will call initialize()
@@ -79,9 +79,25 @@ define('io.ox/backbone/views/datepicker', [
                 this.close(false);
             }, 1);
             this.$el.on('focusout', $.proxy(this.focusOut, this));
+
+            // add attribute information
+            if (this.options.attribute) {
+                this.$el.attr('data-attribute', this.options.attribute);
+            }
+
             $(window).on('resize', $.proxy(this.onWindowResize, this));
         },
 
+        getInitialDate: function () {
+            if (this.options.mandatory) return null;
+            if (this.options.date !== undefined) return moment(this.options.date);
+            return this.getToday();
+        },
+
+        getToday: function () {
+            return moment().startOf('day');
+        },
+
         //
         // Focus behavior
         //
@@ -101,7 +117,7 @@ define('io.ox/backbone/views/datepicker', [
                 // just open from input fields (no toggle)
                 this.$target.on('focus click', $.proxy(this.open, this));
                 this.on('select', function () {
-                    this.$target.val(this.date.format('l')).trigger('change');
+                    this.$target.val(this.getFormattedDate()).trigger('change');
                 });
             } else {
                 // click (i.e. mouse click and enter) to toggle
@@ -109,8 +125,7 @@ define('io.ox/backbone/views/datepicker', [
             }
             this.$target
                 .attr({
-                    'aria-haspopup': true,
-                    'aria-expanded': false
+                    'aria-haspopup': true
                 })
                 .on('change input', $.proxy(this.onTargetInput, this))
                 .on('keydown', $.proxy(this.onTargetKeydown, this))
@@ -144,9 +159,12 @@ define('io.ox/backbone/views/datepicker', [
                 this.$el.css({ top: offset.top + targetHeight });
             }
             this.$el.css({ left: offset.left }).addClass('open');
-            this.$target.attr('aria-expanded', true);
             // only change for non-input fields
             if (!this.$target.is(':input')) this.$el.focus();
+
+            var id =  _.uniqueId('datepicker');
+            this.$el.attr('id', id);
+            this.$target.attr('aria-owns', id);
             this.trigger('open');
         },
 
@@ -155,7 +173,7 @@ define('io.ox/backbone/views/datepicker', [
             this.closing = true;
             this.trigger('before:close');
             this.$el.removeClass('open');
-            this.$target.attr('aria-expanded', false);
+            this.$target.removeAttr('aria-owns');
             if (restoreFocus !== false) this.$target.focus();
             this.closing = false;
             this.trigger('close');
@@ -187,11 +205,16 @@ define('io.ox/backbone/views/datepicker', [
                     $('<button type="button" class="btn-next pull-right"><i class="fa fa-chevron-right" aria-hidden="true"></i></button>')
                 ),
                 this.$grid = $('<table class="grid" role="grid" tabindex="0">')
-                    .attr('aria-label', gt('Use cursor keys to navigate, press enter to select a date')),
-                $('<button type="button" class="btn-today">')
+                    .attr('aria-label', gt('Use cursor keys to navigate, press enter to select a date'))
+            );
+            // today button
+            if (this.options.showTodayButton !== false) {
+                this.$el.append(
+                    $('<button type="button" class="btn-today">')
                     .attr('aria-label', 'Go to today')
                     .text(gt('Today: %1$s', moment().format('l')))
-            );
+                );
+            }
         },
 
         renderHeader: function () {
@@ -217,7 +240,7 @@ define('io.ox/backbone/views/datepicker', [
 
         renderMonth: function () {
 
-            var current = this.date.clone().startOf('day'),
+            var current = this.getDate().clone().startOf('day'),
                 m = current.clone();
 
             this.renderHeader(
@@ -289,8 +312,8 @@ define('io.ox/backbone/views/datepicker', [
 
         renderYear: function () {
 
-            var current = this.date.month(),
-                m = this.date.clone().month(0);
+            var current = this.getDate().month(),
+                m = this.getDate().clone().month(0);
 
             this.renderHeader(
                 $('<button type="button" class="switch-mode">')
@@ -330,8 +353,8 @@ define('io.ox/backbone/views/datepicker', [
 
         renderDecade: function () {
 
-            var current = this.date.year(),
-                m = this.date.clone();
+            var current = this.getDate().year(),
+                m = this.getDate().clone();
 
             m.year(Math.floor(m.year() / 10) * 10);
 
@@ -367,7 +390,7 @@ define('io.ox/backbone/views/datepicker', [
 
         onNavigate: function (e) {
             var fn = $(e.currentTarget).hasClass('btn-prev') ? 'subtract' : 'add',
-                date = this.date.clone();
+                date = this.getDate().clone();
             switch (this.mode) {
                 case 'decade': date[fn](10, 'years'); break;
                 case 'year': date[fn](1, 'year'); break;
@@ -380,17 +403,17 @@ define('io.ox/backbone/views/datepicker', [
             if (this.mode !== 'month') {
                 // switch to current date in month view
                 this.mode = 'month';
-                this.setDate(moment());
+                this.setDate(this.getToday());
                 this.$grid.focus();
             } else {
                 // select current date and close picker
-                this.trigger('select', moment());
+                this.trigger('select', this.getToday());
             }
         },
 
         switchMode: function (mode, value) {
             this.mode = mode;
-            var date = this.date.clone();
+            var date = this.getDate().clone();
             switch (this.mode) {
                 case 'year': date.year(value); break;
                 case 'month': date.month(value); break;
@@ -406,7 +429,9 @@ define('io.ox/backbone/views/datepicker', [
         },
 
         onSelectDate: function (e) {
-            var date = moment($(e.currentTarget).data('date'));
+            var target = $(e.currentTarget),
+                date = moment(target.data('date'));
+            if (target.hasClass('cw')) return;
             this.trigger('select', date);
         },
 
@@ -454,8 +479,8 @@ define('io.ox/backbone/views/datepicker', [
 
                 var tabbable = this.$(':input, :button'),
                     index = tabbable.index(e.target),
-                    lowOut = e.shiftKey && index === 0,
-                    highOut = !e.shiftKey && index === tabbable.length - 1;
+                    lowOut = e.shiftKey && index === 0 && !!this.$target.length,
+                    highOut = !e.shiftKey && index === tabbable.length - 1 && !!this.$target.length;
 
                 // apply focus trap
                 if (lowOut || highOut) e.preventDefault();
@@ -471,7 +496,9 @@ define('io.ox/backbone/views/datepicker', [
                 all.eq(index + 1).focus();
             }
 
-            function handleEscape() {
+            function handleEscape(e) {
+                // we use preventDefault for nested handlers, e.g. picker in a modal dialog
+                e.preventDefault();
                 this.close();
             }
 
@@ -479,7 +506,7 @@ define('io.ox/backbone/views/datepicker', [
                 // handle enter only if focus is on grid
                 if (this.$grid[0] !== document.activeElement) return;
                 if (this.mode === 'month') {
-                    this.trigger('select', this.date.clone());
+                    this.trigger('select', this.getDate().clone());
                 } else {
                     var selected = this.$('[aria-selected="true"]'),
                         mode = selected.attr('data-mode');
@@ -495,12 +522,12 @@ define('io.ox/backbone/views/datepicker', [
                     case 'decade': interval.year = sign * (e.shiftKey ? 100 : 10); break;
                     // no default
                 }
-                this.setDate(this.date.clone().add(interval));
+                this.setDate(this.getDate().clone().add(interval));
             }
 
             function handleHomeEnd(e) {
                 var isEnd = e.which === 35, fn = isEnd ? 'endOf' : 'startOf';
-                this.setDate(this.date.clone()[fn]('month'));
+                this.setDate(this.getDate().clone()[fn]('month'));
             }
 
             function handleCursor(e) {
@@ -521,7 +548,7 @@ define('io.ox/backbone/views/datepicker', [
                     // no default
                 }
 
-                this.setDate(this.date.clone()[type](movement[direction][this.mode]));
+                this.setDate(this.getDate().clone()[type](movement[direction][this.mode]));
                 this.$grid.focus();
             }
 
@@ -536,8 +563,11 @@ define('io.ox/backbone/views/datepicker', [
                     e.preventDefault();
                     this.$el.focus();
                     break;
-                case 13:
                 case 27:
+                    // we use preventDefault for nested handlers, e.g. picker in a modal dialog
+                    e.preventDefault();
+                    // falls through
+                case 13:
                     this.toggle();
                     break;
                 // no default
@@ -549,6 +579,14 @@ define('io.ox/backbone/views/datepicker', [
             this.setDate(date);
         },
 
+        getDate: function () {
+            return this.date || this.getToday();
+        },
+
+        getFormattedDate: function () {
+            return this.getDate().format('l');
+        },
+
         setDate: function (date, forceRender) {
 
             date = moment(date || this.date);
@@ -558,7 +596,7 @@ define('io.ox/backbone/views/datepicker', [
             if (date.year() <= 0) return;
 
             // update internal date
-            var isSame = date.isSame(this.date);
+            var isSame = date.isSame(this.getDate());
             this.date = date;
 
             var selector,
@@ -575,21 +613,21 @@ define('io.ox/backbone/views/datepicker', [
             } else {
                 // currently visible?
                 switch (this.mode) {
-                    case 'decade': selector = '#year_' + this.date.year(); break;
-                    case 'year': selector = '#month_' + this.date.format('YYYY-MM'); break;
-                    case 'month': selector = '#date_' + $.escape(this.date.format('l')); break;
+                    case 'decade': selector = '#year_' + date.year(); break;
+                    case 'year': selector = '#month_' + date.format('YYYY-MM'); break;
+                    case 'month': selector = '#date_' + $.escape(date.format('l')); break;
                     // no default
                 }
                 // found?
                 var node = this.$grid.find(selector);
                 if (node.length) select(node); else this.render();
             }
-            if (!isSame) this.trigger('change', this.date);
+            if (!isSame) this.trigger('change', date);
         }
     });
 
     function isSame(a, b) {
-        return a.clone().startOf('day').isSame(b.clone().startOf('day'));
+        return a.isSame(b, 'day');
     }
 
     function isToday(m) {
