@@ -104,10 +104,7 @@ define('io.ox/backbone/views/modal', ['io.ox/backbone/views/extensible', 'io.ox/
             }
 
             // track focusin
-            // keep focus is a prototype function and all listeners will be removed from document with off
-            // make it unique by binding to this
-            this.keepFocus = this.keepFocus.bind(this);
-            $(document).on('focusin', this.keepFocus);
+            $(document).on('focusin', $.proxy(this.keepFocus, this));
             this.on('dispose', function () {
                 $(document).off('focusin', this.keepFocus);
                 $(window).off('resize', this.scrollToInput);
@@ -184,7 +181,7 @@ define('io.ox/backbone/views/modal', ['io.ox/backbone/views/extensible', 'io.ox/
         disableFormElements: function () {
             // disable all form elements; mark already disabled elements via CSS class
             this.$(':input').each(function () {
-                if ($(this).attr('data-action') === 'cancel') return;
+                if ($(this).attr('data-action') === 'cancel' || $(this).attr('data-state') === 'manual') return;
                 $(this).toggleClass('disabled', $(this).prop('disabled')).prop('disabled', true);
             });
         },
@@ -192,12 +189,14 @@ define('io.ox/backbone/views/modal', ['io.ox/backbone/views/extensible', 'io.ox/
         enableFormElements: function () {
             // enable all form elements
             this.$(':input').each(function () {
-                $(this).prop('disabled', $(this).hasClass('disabled')).removeClass('disabled');
+                if ($(this).attr('data-state') === 'manual') return;
+                $(this).prop('disabled', false).removeClass('disabled');
             });
         },
 
-        build: function (fn) {
-            fn.call(this);
+        hideBody: function () {
+            this.$('.modal-body').hide();
+            this.$('.modal-footer').css('border-top', 0);
             return this;
         },
 
@@ -236,6 +235,24 @@ define('io.ox/backbone/views/modal', ['io.ox/backbone/views/extensible', 'io.ox/
             );
         },
 
+        addCheckbox: function (options) {
+            var o = _.extend({ className: 'pull-left' }, options),
+                id = _.uniqueId('custom-');
+            this.$footer.prepend(
+                $('<div class="checkbox custom">').append(
+                    $('<label>').attr('for', id).prepend(
+                        $('<input type="checkbox" class="sr-only">')
+                            .attr({ 'id': id, 'name': o.action })
+                            .prop('checked', o.status),
+                        $('<i class="toggle" aria-hidden="true">'),
+                        $.txt(o.label || '\u00a0')
+                    )
+                )
+                .addClass(o.className)
+            );
+            return this;
+        },
+
         onAction: function (e) {
             this.invokeAction($(e.currentTarget).attr('data-action'));
         },
@@ -245,6 +262,8 @@ define('io.ox/backbone/views/modal', ['io.ox/backbone/views/extensible', 'io.ox/
             // otherwise we cannot idle the dialog in the action listener
             if (this.options.async && action !== 'cancel') this.busy();
             this.trigger(action);
+            // for general event listeners
+            this.trigger('action', action);
             // check if this.options is there, if the dialog was closed in the handling of the action this.options is empty and we run into a js error otherwise
             if ((this.options && !this.options.async) || action === 'cancel') this.close();
         },
@@ -253,6 +272,7 @@ define('io.ox/backbone/views/modal', ['io.ox/backbone/views/extensible', 'io.ox/
             if (e.which !== 13) return;
             if (!this.options.enter) return;
             if (!$(e.target).is('input:text, input:password')) return;
+            e.preventDefault();
             this.invokeAction(this.options.enter);
         },
 
@@ -264,6 +284,7 @@ define('io.ox/backbone/views/modal', ['io.ox/backbone/views/extensible', 'io.ox/
         onEscape: function (e) {
             if (e.which !== 27) return;
             if (e.isDefaultPrevented()) return;
+            if (this.$footer.find('[data-action="cancel"]').length > 0) this.trigger('cancel');
             this.close();
         },
 
@@ -280,9 +301,12 @@ define('io.ox/backbone/views/modal', ['io.ox/backbone/views/extensible', 'io.ox/
         },
 
         resume: function () {
-            $(document).on('focusin', this.keepFocus);
+            $(document).on('focusin', $.proxy(this.keepFocus, this));
             this.$el.next().addBack().show();
+            // add marker class again(needed by yells for example)
+            $(document.body).addClass('modal-open');
             this.toggleAriaHidden(true);
+            this.idle();
         }
     });
 
