@@ -31,6 +31,21 @@ define('io.ox/backbone/views/recurrence-view', [
             }
         });
 
+    var recurrenceUtil = {
+        getStart: function (model) {
+            // calendar model
+            if (model.has('startDate')) return util.getMoment(model.get('startDate'));
+            // tasks model
+            return moment(model.get('start_time') || model.get('start_date')).utc();
+        },
+        previousStart: function (model) {
+            // calendar model
+            if (model.has('startDate')) return util.getMoment(model.previous('startDate'));
+            // tasks model
+            return moment(model.previous('start_time') || model.previous('start_date')).utc();
+        }
+    };
+
     ext.point('io.ox/backbone/views/recurrence-view/dialog').extend({
         index: INDEX += 100,
         id: 'repeat',
@@ -89,8 +104,7 @@ define('io.ox/backbone/views/recurrence-view', [
                     }),
                     update = function (model) {
                         var type = model.get('recurrence_type'),
-                            startAttribute = model.get('start_time') || model.get('start_date'),
-                            startDate = moment(startAttribute),
+                            startDate = recurrenceUtil.getStart(model),
                             day_in_month = model.get('day_in_month'),
                             days = model.get('days');
 
@@ -178,8 +192,7 @@ define('io.ox/backbone/views/recurrence-view', [
                             value: 'weekday'
                         }],
                         serialize: function (selection) {
-                            var startAttribute = this.model.get('start_time') || this.model.get('start_date'),
-                                day = moment(startAttribute),
+                            var day = recurrenceUtil.getStart(this.model),
                                 type = this.model.get('recurrence_type');
 
                             if (selection === 'date') {
@@ -283,7 +296,8 @@ define('io.ox/backbone/views/recurrence-view', [
                 });
 
             return function () {
-                var days = _(_.range(7)).map(function (num) {
+                var guid = guid = _.uniqueId('form-control-label-'),
+                    days = _(_.range(7)).map(function (num) {
                         return moment().weekday(num).format('dd');
                     }),
                     firstDayOfWeek = moment.localeData().firstDayOfWeek(),
@@ -297,6 +311,7 @@ define('io.ox/backbone/views/recurrence-view', [
                         };
                     }),
                     input = new CheckboxButtonsView({
+                        id: guid,
                         className: 'btn-group',
                         model: this.model,
                         list: list
@@ -312,7 +327,7 @@ define('io.ox/backbone/views/recurrence-view', [
 
                 this.$body.append(
                     formGroup = $('<div class="form-group hidden">').append(
-                        $('<label class="control-label col-sm-4">').text(gt('Weekday')),
+                        $('<label class="control-label col-sm-4">').attr('for', guid).text(gt('Weekday')),
                         $('<div class="col-sm-8">').append(
                             input.render().$el,
                             new mini.ErrorView({
@@ -410,7 +425,7 @@ define('io.ox/backbone/views/recurrence-view', [
                         old = this.getValue();
                     if (old === selection) return;
 
-                    var start = this.model.get('start_time') || this.model.get('start_date');
+                    var start = recurrenceUtil.getStart(this.model);
 
                     if (selection === 'never') {
                         this.model.set({
@@ -425,7 +440,7 @@ define('io.ox/backbone/views/recurrence-view', [
                                 this.model.get('occurrences') - 1,
                                 momentShorthands[this.model.get('recurrence_type') - 1]
                             );
-                            date = moment.max(moment(start), date);
+                            date = moment.max(start, date);
                         }
                         this.model.set({
                             'occurrences': undefined,
@@ -437,7 +452,7 @@ define('io.ox/backbone/views/recurrence-view', [
                         if (old === 'until') {
                             var until = moment(this.model.get('until'));
                             occurrences = Math.ceil(until.diff(
-                                moment(start),
+                                start,
                                 momentShorthands[this.model.get('recurrence_type') - 1],
                                 true
                             )) + 1;
@@ -572,14 +587,13 @@ define('io.ox/backbone/views/recurrence-view', [
         })()
     });
 
-    var SerializeCheckboxView = mini.CheckboxView.extend({
+    var SerializeCheckboxView = mini.CustomCheckboxView.extend({
 
             onChange: function () {
-                var val = this.$el.prop('checked'),
+                var val = this.$input.prop('checked'),
                     old = this.model.get('recurrence_type') > 0;
                 if (!old && val) {
-                    var startAttribute = this.model.get('start_time') || this.model.get('start_date'),
-                        startDate = moment(startAttribute);
+                    var startDate = recurrenceUtil.getStart(this.model);
                     this.model.set({
                         'recurrence_type': 2,
                         'interval': 1,
@@ -587,7 +601,7 @@ define('io.ox/backbone/views/recurrence-view', [
                     });
                 }
                 if (old && !val) {
-                    // cleanup
+                // cleanup
                     this.model.set('recurrence_type', 0);
                     this.model.unset('interval');
                     this.model.unset('days');
@@ -598,7 +612,7 @@ define('io.ox/backbone/views/recurrence-view', [
                 }
             },
             update: function () {
-                this.$el.prop('checked', this.model.get('recurrence_type') > 0);
+                this.$input.prop('checked', this.model.get('recurrence_type') > 0);
             }
         }),
         RecurrenceModel = Backbone.Model.extend({
@@ -626,7 +640,7 @@ define('io.ox/backbone/views/recurrence-view', [
             },
             validateUntil: function () {
                 var until = moment(this.get('until')),
-                    start = moment(this.get('start_time') || this.get('start_date')),
+                    start = recurrenceUtil.getStart(this),
                     valid = !this.has('until') || until.isAfter(start, 'day') || until.isSame(start, 'day');
                 if (valid) this.trigger('valid:until');
                 else this.trigger('invalid:until', gt('Please insert a date after the start date'));
@@ -651,7 +665,7 @@ define('io.ox/backbone/views/recurrence-view', [
             }
         });
 
-    return Backbone.View.extend({
+    return mini.AbstractView.extend({
 
         className: 'recurrence-view',
 
@@ -660,15 +674,22 @@ define('io.ox/backbone/views/recurrence-view', [
         },
 
         initialize: function () {
+            this.originalModel = this.model;
+            this.model = this.getMappedModel();
             this.listenTo(this.model, 'change:recurrence_type change:interval change:days change:day_in_month change:month change:occurrences change:until', this.updateSummary);
-            this.listenTo(this.model, 'change:start_time change:start_date', this.onChangeStart);
+            this.listenTo(this.model, 'change:start_time change:start_date change:startDate', this.onChangeStart);
+        },
+
+        getMappedModel: function () {
+            if (this.model.getRruleMapModel) return this.model.getRruleMapModel();
+            return this.model;
         },
 
         onOpenDialog: function () {
             var self = this;
             new ModalDialog({
                 title: gt('Edit recurrence'),
-                width: _.device('smartphone') ? window.innerWidth - 30 : 560,
+                width: 560,
                 point: 'io.ox/backbone/views/recurrence-view/dialog',
                 async: true,
                 model: new RecurrenceModel(this.model.pick(
@@ -679,48 +700,43 @@ define('io.ox/backbone/views/recurrence-view', [
                     'month',
                     'occurrences',
                     'until',
+                    'startDate',
                     'start_time',
                     'start_date'
                 )),
                 focus: 'select'
             })
-            .build(function () {
-                this.$el.addClass('recurrence-view-dialog');
-                this.$body.addClass('form-horizontal');
-            })
-            .addCancelButton()
-            .addButton({ label: gt('Apply'), action: 'apply' })
-            .on('apply', function () {
-                if (!this.model.checkValidation()) {
-                    this.idle();
-                    // focus first element which has error
-                    $('.has-error input').first().focus();
-                    return;
-                }
+                .build(function () {
+                    this.$el.addClass('recurrence-view-dialog');
+                    this.$body.addClass('form-horizontal');
+                })
+                .addCancelButton()
+                .addButton({ label: gt('Apply'), action: 'apply' })
+                .on('apply', function () {
+                    if (!this.model.checkValidation()) {
+                        this.idle();
+                        // focus first element which has error
+                        $('.has-error input').first().focus();
+                        return;
+                    }
 
-                // remove own fields
-                self.model.unset('every-weekday');
+                    // remove own fields
+                    self.model.unset('every-weekday');
 
-                self.model.set(this.model.toJSON());
-                this.close();
-            })
-            .open();
+                    self.model.set(this.model.toJSON());
+                    this.close();
+                })
+                .open();
         },
 
         render: function () {
-            var guid = _.uniqueId('form-control-label-');
             this.$el.append(
-                $('<div class="checkbox">').append(
-                    $('<label>').attr('for', guid).append(
-                        new SerializeCheckboxView({
-                            id: guid,
-                            model: this.model,
-                            name: 'recurrence_type'
-                        }).render().$el,
-                        gt('Repeat')
-                    ),
-                    $('<a href="#" class="summary">').append()
-                )
+                new SerializeCheckboxView({
+                    model: this.model,
+                    name: 'recurrence_type',
+                    label: gt('Repeat')
+                }).render().$el,
+                $('<button type="button" class="btn btn-link summary">')
             );
             this.updateSummary();
             return this;
@@ -731,20 +747,29 @@ define('io.ox/backbone/views/recurrence-view', [
                 visible = this.model.get('recurrence_type') > 0;
             this.$('.summary').toggleClass('hidden', !visible);
             if (visible) {
-                var data = this.model.toJSON();
-                $summary.text(util.getRecurrenceString(data));
+                $summary.text(util.getRecurrenceString(this.model));
             }
         },
 
         onChangeStart: function () {
             var type = this.model.get('recurrence_type');
             if (type === 0) return;
-            var oldDate = moment(this.model.previous('start_time') || this.model.previous('start_date')),
-                date = moment(this.model.get('start_time') || this.model.get('start_date'));
 
-            // if weekly and only single day selected
-            if (type === 2 && this.model.get('days') === 1 << oldDate.day()) {
-                this.model.set('days', 1 << date.day());
+            var oldDate = recurrenceUtil.previousStart(this.model),
+                date = recurrenceUtil.getStart(this.model);
+
+            if (this.model.get('full_time') === true) date.utc();
+
+            // if weekly, shift bits
+            if (type === 2) {
+                var shift = date.diff(oldDate, 'days') % 7,
+                    days = this.model.get('days');
+                if (shift < 0) shift += 7;
+                for (var i = 0; i < shift; i++) {
+                    days = days << 1;
+                    if (days > 127) days -= 127;
+                }
+                this.model.set('days', days);
             }
 
             // if monthly or yeary, adjust date/day of week
@@ -770,6 +795,12 @@ define('io.ox/backbone/views/recurrence-view', [
             if (this.model.get('until') && moment(this.model.get('until')).isBefore(date)) {
                 this.model.set('until', date.add(1, momentShorthands[this.model.get('recurrence_type') - 1]).valueOf());
             }
+        },
+
+        dispose: function () {
+            // make sure, that the events of the mapped model are removed
+            if (this.originalModel !== this.model) this.model.stopListening();
+            mini.AbstractView.prototype.dispose.call(this);
         }
 
     });
