@@ -14,11 +14,12 @@
 
 define('io.ox/calendar/detail/main', [
     'io.ox/calendar/api',
+    'io.ox/calendar/util',
     'io.ox/core/extensions',
     'io.ox/calendar/view-detail',
     'gettext!io.ox/calendar',
     'io.ox/core/notifications'
-], function (api, ext, detailView, gt, notifications) {
+], function (api, util, ext, detailView, gt, notifications) {
 
     'use strict';
 
@@ -29,14 +30,13 @@ define('io.ox/calendar/detail/main', [
             app.showAppointment = function (appointment) {
 
                 api.get(appointment).then(
-                    function success(data) {
-                        app.setTitle(data.title);
+                    function success(model) {
+                        app.setTitle(model.get('summary'));
                         app.getWindowNode().addClass('detail-view-app').append($('<div class="f6-target detail-view-container" tabindex="0" role="complementary">').attr({
                             'aria-label': gt('Appointment Details')
-                        }).append(detailView.draw(data)));
+                        }).append(detailView.draw(model)));
 
-                        // make sure this works for single events and whole series
-                        api.one('delete:' + _.ecid(data) + (data.recurrence_position === undefined ? '' : ' delete:' + (data.folder || data.folder_id) + ':' + data.id), function () {
+                        api.once('delete:' + util.cid(model.attributes), function () {
                             app.quit();
                         });
                     },
@@ -45,6 +45,34 @@ define('io.ox/calendar/detail/main', [
                     }
                 );
             };
+        },
+
+        'metrics': function (app) {
+            require(['io.ox/metrics/main'], function (metrics) {
+                if (!metrics.isEnabled()) return;
+                var body = app.getWindow().nodes.body;
+                // toolbar actions
+                body.on('mousedown', '.io-ox-action-link:not(.dropdown, [data-toggle="dropdown"])', function (e) {
+                    metrics.trackEvent({
+                        app: 'calendar',
+                        target: 'detail/toolbar',
+                        type: 'click',
+                        action: $(e.currentTarget).attr('data-action')
+                    });
+                });
+                // toolbar options dropdown
+                body.on('mousedown', '.io-ox-inline-links .dropdown a:not([data-toggle])', function (e) {
+                    var action = $(e.target).closest('.dropdown').find('> a');
+                    metrics.trackEvent({
+                        app: 'calendar',
+                        target: 'detail/toolbar',
+                        type: 'click',
+                        action: action.attr('data-action'),
+                        detail: $(e.target).val()
+                    });
+                });
+
+            });
         }
     });
 
@@ -54,16 +82,18 @@ define('io.ox/calendar/detail/main', [
         var app = ox.ui.createApp({
             closable: true,
             name: NAME,
-            title: ''
+            title: '',
+            floating: !_.device('smartphone')
         });
 
         // launcher
         return app.setLauncher(function (options) {
-
             var win = ox.ui.createWindow({
                 chromeless: true,
                 name: NAME,
-                toolbar: false
+                toolbar: false,
+                closable: true,
+                floating: !_.device('smartphone')
             });
             app.setWindow(win);
             app.mediate();
@@ -72,8 +102,8 @@ define('io.ox/calendar/detail/main', [
             var cid = options.cid, obj;
             if (cid !== undefined) {
                 // called from calendar app
-                obj = _.cid(cid);
-                app.setState({ folder: obj.folder_id, id: obj.id, recurrence_position: obj.recurrence_position || null });
+                obj = util.cid(cid);
+                app.setState({ folder: obj.folder, id: obj.id, recurrenceId: obj.recurrenceId || null });
                 app.showAppointment(obj);
                 return;
             }
