@@ -18,19 +18,22 @@ define('io.ox/calendar/main', [
     'io.ox/core/folder/api',
     'io.ox/core/folder/tree',
     'io.ox/core/folder/view',
+    'io.ox/backbone/views/datepicker',
     'settings!io.ox/calendar',
     'gettext!io.ox/calendar',
-    'io.ox/core/tk/vgrid',
+    'io.ox/core/tk/list-control',
+    'io.ox/calendar/list/listview',
     'io.ox/core/toolbars-mobile',
     'io.ox/core/page-controller',
     'io.ox/calendar/api',
+    'io.ox/calendar/folder-select-support',
     'io.ox/calendar/mobile-navbar-extensions',
     'io.ox/calendar/mobile-toolbar-actions',
     'io.ox/calendar/toolbar',
     'io.ox/calendar/actions',
     'less!io.ox/calendar/style',
     'io.ox/calendar/week/view'
-], function (commons, ext, capabilities, folderAPI, TreeView, FolderView, settings, gt, VGrid, Bars, PageController, api) {
+], function (commons, ext, capabilities, folderAPI, TreeView, FolderView, DatePicker, settings, gt, ListViewControl, CalendarListView, Bars, PageController, api, addFolderSelectSupport) {
 
     'use strict';
 
@@ -166,6 +169,21 @@ define('io.ox/calendar/main', [
                 container: c
             });
 
+            app.pages.addPage({
+                name: 'listView',
+                classes: 'leftside'
+            });
+
+            app.pages.addPage({
+                name: 'detailView',
+                classes: 'rightside'
+            });
+
+            app.pages.addPage({
+                name: 'year',
+                container: c
+            });
+
         },
 
         'subscription': function (app) {
@@ -174,21 +192,12 @@ define('io.ox/calendar/main', [
             };
         },
 
-        /*
-         * Early List view vsplit - we need that to get a Vgrid instance
-         * Vsplit compatibilty
-         */
         'list-vsplit': function (app) {
             if (_.device('smartphone')) return;
-            var vsplit = commons.vsplit($('<div>'), app);
-            app.left = vsplit.left;
-            app.right = vsplit.right;
+            app.left = app.pages.getPage('listView');
+            app.right = app.pages.getPage('detailView');
         },
 
-        /*
-         * Early List view vsplit - we need that to get a Vgrid instance
-         * Vsplit compatibilty
-         */
         'list-vsplit-mobile': function (app) {
             if (_.device('!smartphone')) return;
             app.left = app.pages.getPage('list');
@@ -244,143 +253,203 @@ define('io.ox/calendar/main', [
             app.pages.getNavbar('list').on('rightAction', function () {
                 if (app.props.get('checkboxes') === true) {
                     // leave multiselect? -> clear selection
-                    app.grid.selection.clear();
-                    app.grid.showTopbar(false);
-                    app.grid.showToolbar(false);
+                    app.listView.selection.clear();
                     app.pages.getNavbar('list').setRight(gt('Edit')).show('.left');
                 } else {
-                    // also show sorting options
-                    app.grid.showTopbar(true);
-                    app.grid.showToolbar(true);
                     app.pages.getNavbar('list').setRight(gt('Cancel')).hide('.left');
                 }
                 app.props.set('checkboxes', !app.props.get('checkboxes'));
+                app.listView.toggleCheckboxes(app.props.get('checkboxes'));
+                app.listControl.$el.toggleClass('toolbar-top-visible', app.props.get('checkboxes'));
             });
         },
 
-        /*
-         * VGrid
-         */
-        'vgrid': function (app) {
+        //
+        // Mini calendar
+        //
+        'mini-calendar': function (app) {
 
-            var gridOptions = {
-                    settings: settings,
-                    showToggle: _.device('smartphone'),
-                    hideTopbar: _.device('smartphone'),
-                    hideToolbar: _.device('smartphone'),
-                    // if it's shown, it should be on the top
-                    toolbarPlacement: 'top'
-                },
-                savedWidth = app.settings.get('vgrid/width/' + _.display());
+            ext.point('io.ox/calendar/sidepanel').extend({
+                id: 'mini-calendar',
+                index: 50,
+                draw: function () {
 
-            // do not apply on touch devices. it's not possible to change the width there
-            if (!_.device('touch') && savedWidth) {
-                app.right.css('left', savedWidth + 'px');
-                app.left.css('width', savedWidth + 'px');
-            }
+                    if (_.device('smartphone')) return;
+                    var layoutRanges = { 'week:workweek': 'week', 'week:week': 'week', 'month': 'month', 'year': 'year' };
 
-            // show "load more" link
-            gridOptions.tail = function () {
-                var link = $('<div class="vgrid-cell tail">').append(
-                    //#. Label for a button which shows more upcoming
-                    //#. appointments in a listview by extending the search
-                    //#. by one month in the future
-                    $('<a href="#">').text(gt('Expand timeframe by one month'))
-                );
-                return link;
-            };
+                    new DatePicker({ parent: this.closest('#io-ox-core'), showTodayButton: false })
+                        .on('select', function (date) {
+                            app.setDate(date, { propagate: false });
+                            this.setDate(date, true);
+                        })
+                        .listenTo(app.props, 'change:date', function (model, value) {
+                            // check if the layout supports ranges (week, month year). If the new date is still within that range, we don't need to change the mini calendar
+                            // those layous set it always to the first day within their specific range and would overwrite the selection of the user, see(bug 57223)
+                            var unit = layoutRanges[app.props.get('layout')];
+                            if (unit && moment(value).startOf(unit).valueOf() === moment(this.getDate()).startOf(unit).valueOf()) return;
 
-            app.grid = new VGrid(app.left, gridOptions);
-            app.left.attr({
-                role: 'navigation',
-                'aria-label': 'Appointment list'
+                            this.setDate(value, true);
+                        })
+                        .listenTo(app.props, 'change:showMiniCalendar', function (model, value) {
+                            this.$el.toggle(!!value);
+                        })
+                        .render().$el
+                        .toggle(app.props.get('showMiniCalendar'))
+                        .appendTo(this);
+                }
             });
-
-            app.getGrid = function () {
-                return this.grid;
-            };
-
-            if (_.device('smartphone')) {
-                // remove some stuff from toolbar once
-                app.grid.one('meta:update', function () {
-                    app.grid.getToolbar().find('.select-all-toggle, .grid-info').hide();
-                });
-            }
         },
 
         /*
          * Folder view support
          */
         'folder-view': function (app) {
+            if (_.device('smartphone')) return;
 
-            app.treeView = new TreeView({ app: app, contextmenu: true, flat: true, indent: false, module: 'calendar' });
+            app.treeView = new TreeView({ app: app, contextmenu: true, flat: true, indent: false, module: 'calendar', dblclick: true });
             FolderView.initialize({ app: app, tree: app.treeView });
             app.folderView.resize.enable();
             app.folderView.tree.$el.attr('aria-label', gt('Calendars'));
         },
 
-        'folderview-toolbar': function (app) {
-            if (_.device('smartphone')) return;
+        'folder-view-mobile': function (app) {
+            if (_.device('!smartphone')) return;
 
-            app.toggleFolderView = function (e) {
-                e.preventDefault();
-                app.folderView.toggle(e.data.state);
+            var nav = app.pages.getNavbar('folderTree'),
+                page = app.pages.getPage('folderTree');
+
+            nav.on('rightAction', function () {
+                app.toggleFolders();
+            });
+
+            var tree = new TreeView({
+                app: app,
+                contextmenu: true,
+                flat: true,
+                indent: false,
+                module: 'calendar'
+            });
+
+            var cb = function () {
+                if (app.getWindow().currentPerspective !== 'month') {
+                    ox.ui.Perspective.show(app, 'month');
+                }
             };
 
-            function onFolderViewOpen(app) {
-                app.getWindow().nodes.sidepanel.show();
-                app.left.removeClass('bottom-toolbar');
-                // for perspectives other than list
-                app.getWindow().nodes.body.removeClass('bottom-toolbar-visible');
-            }
+            // initialize folder view
+            FolderView.initialize({ app: app, tree: tree, firstResponder: 'month', respondCallback: cb });
+            page.append(tree.render().$el);
+            app.treeView = tree;
+        },
 
-            function onFolderViewClose(app) {
-                // hide sidepanel so invisible objects are not tabbable
-                app.getWindow().nodes.sidepanel.hide();
-                app.left.addClass('bottom-toolbar');
-                // for perspectives other than list
-                app.getWindow().nodes.body.addClass('bottom-toolbar-visible');
-            }
-
-            // create extension point for second toolbar
-            ext.point('io.ox/calendar/vgrid/second-toolbar').extend({
-                id: 'default',
-                index: 100,
-                draw: function () {
-                    this.addClass('visual-focus').append(
-                        $('<a href="#" class="toolbar-item" data-action="open-folder-view">')
-                        .attr('aria-label', gt('Open folder view'))
-                        .append($('<i class="fa fa-angle-double-right" aria-hidden="true">').attr('title', gt('Open folder view')))
-                        .on('click', { state: true }, app.toggleFolderView)
-                    );
-                }
+        'folder-create': function (app) {
+            folderAPI.on('create', function (folder) {
+                if (folder.module !== 'calendar') return;
+                app.folders.add(folder.id);
+                app.folder.set(folder.id);
             });
+        },
+
+        'folder-remove': function (app) {
+            folderAPI.on('hide remove', function (id) {
+                app.folders.remove(id);
+            });
+            api.on('all:fail', function (id) {
+                app.folders.remove(id, { silent: true });
+            });
+        },
+
+        'multi-folder-selection': function (app) {
+            addFolderSelectSupport(app);
+            app.on('folder:change', function () {
+                app.folders.reset();
+            });
+            app.folderView.tree.on('dblclick', function (e, folder) {
+                if (!folder) return;
+                if ($(e.target).hasClass('color-label')) return;
+                if (folderAPI.isVirtual(folder)) return;
+                app.folder.set(folder);
+                if (app.folders.isSingleSelection()) app.folders.reset();
+                else app.folders.setOnly(folder);
+            });
+        },
+
+        'toggle-folder-view': function (app) {
+            app.toggleFolderView = function (e) {
+                e.preventDefault();
+                app.trigger('before:change:folderview');
+                app.folderView.toggle(e.data.state);
+            };
 
             ext.point('io.ox/calendar/sidepanel').extend({
                 id: 'toggle-folderview',
                 index: 1000,
                 draw: function () {
+                    if (_.device('smartphone')) return;
                     this.addClass('bottom-toolbar').append(
                         $('<div class="generic-toolbar bottom visual-focus">').append(
                             $('<a href="#" class="toolbar-item" role="button" data-action="close-folder-view">').attr('aria-label', gt('Close folder view'))
                             .append(
                                 $('<i class="fa fa-angle-double-left" aria-hidden="true">').attr('title', gt('Close folder view'))
                             )
-                            .on('click', { app: app, state: false }, app.toggleFolderView)
+                            .on('click', { state: false }, app.toggleFolderView)
                         )
                     );
                 }
             });
+        },
 
-            app.on({
-                'folderview:open': onFolderViewOpen.bind(null, app),
-                'folderview:close': onFolderViewClose.bind(null, app)
+        'account-errors': function (app) {
+            app.treeView.on('click:account-error', function (folder) {
+                var accountError = folder['com.openexchange.calendar.accountError'];
+                if (!accountError) return;
+                require(['io.ox/backbone/views/modal', 'io.ox/core/notifications'], function (ModalDialog, notifications) {
+                    new ModalDialog({
+                        point: 'io.ox/calendar/account-errors',
+                        title: gt('Calendar account error')
+                    })
+                    .extend({
+                        default: function () {
+                            this.$body.append(
+                                $('<div class="info-text">')
+                                    .css('word-break', 'break-word')
+                                    .text(accountError.error)
+                            );
+                        }
+                    })
+                    .addCancelButton()
+                    .addButton({ label: gt('Try again'), action: 'retry', className: 'btn-primary' })
+                    .on('retry', function () {
+                        notifications.yell('warning', gt('Refreshing calendar might take some time...'));
+                        api.refreshCalendar(folder.id).then(function () {
+                            notifications.yell('success', gt('Successfully refreshed calendar'));
+                        }, notifications.yell).always(function () {
+                            folderAPI.pool.unfetch(folder.id);
+                            folderAPI.refresh();
+                        });
+                    })
+                    .open();
+                });
             });
+        },
 
-            var grid = app.getGrid(), topbar = grid.getTopbar();
-            ext.point(app.get('name') + '/vgrid/second-toolbar').invoke('draw', topbar, ext.Baton({ grid: grid }));
-            onFolderViewClose(app);
-            if (app.folderViewIsVisible()) _.defer(onFolderViewOpen, app);
+        'listview': function (app) {
+            app.listView = new CalendarListView({ app: app, draggable: false, pagination: false, labels: true, ignoreFocus: true, noPullToRefresh: true });
+            app.listView.model.set({ view: 'list' }, { silent: true });
+        },
+
+        'list-view-control': function (app) {
+            app.listControl = new ListViewControl({ id: 'io.ox/chronos', listView: app.listView, app: app });
+            app.left.append(
+                app.listControl.render().$el
+                    .attr('aria-label', gt('Appointments'))
+                    .find('.toolbar')
+                    //#. toolbar with 'select all' and 'sort by'
+                    .attr('aria-label', gt('Appointment options'))
+                    .end()
+            );
+            // make resizable
+            app.listControl.resizable();
         },
 
         'premium-area': function (app) {
@@ -417,59 +486,46 @@ define('io.ox/calendar/main', [
             app.toggleFolders = toggle;
         },
 
-        /*
-         * Folder view mobile support
-         */
-        'folder-view-mobile': function (app) {
-            if (_.device('!smartphone')) return;
-
-            var nav = app.pages.getNavbar('folderTree'),
-                page = app.pages.getPage('folderTree');
-
-            nav.on('rightAction', function () {
-                app.toggleFolders();
-            });
-
-            var tree = new TreeView({
-                app: app,
-                contextmenu: true,
-                flat: true,
-                indent: false,
-                module: 'calendar'
-            });
-            // always change to month view after folder change
-            var cb = function () {
-                if (app.getWindow().currentPerspective !== 'month') {
-                    ox.ui.Perspective.show(app, 'month');
-                }
-            };
-            // initialize folder view
-            FolderView.initialize({ app: app, tree: tree, firstResponder: 'month', respondCallback: cb });
-            page.append(tree.render().$el);
-        },
-
         /*
          * Default application properties
          */
         'props': function (app) {
+
             var view = settings.get('viewView') || 'week:week';
+
             // introduce shared properties
             app.props = new Backbone.Model({
+                'date': moment().valueOf(),
                 'layout': view,
                 'checkboxes': _.device('smartphone') ? false : app.settings.get('showCheckboxes', false),
-                'colorScheme': app.settings.get('colorScheme', 'custom'),
-                'mobileFolderSelectMode': false
+                'mobileFolderSelectMode': false,
+                'showMiniCalendar': app.settings.get('showMiniCalendar', true),
+                'showMonthviewWeekend': app.settings.get('showMonthviewWeekend', true)
             });
 
-            // store colorScheme in settings to ensure that 'colorScheme' is not undefined
-            app.settings.set('colorScheme', app.props.get('colorScheme'));
+            // convenience functions
+            app.getDate = function () {
+                return moment(app.props.get('date'));
+            };
+
+            app.setDate = function (newDate, opt) {
+                // try to keep month and year if possible
+                if (!_.isArray(newDate._i)) return app.props.set('date', moment(newDate).valueOf(), opt);
+                var oldDate = this.getDate(),
+                    initArgs = newDate._i,
+                    year = initArgs.length > 0 ? initArgs[0] : oldDate.year(),
+                    month = initArgs.length > 1 ? initArgs[1] : oldDate.month(),
+                    day = initArgs.length > 2 ? initArgs[2] : oldDate.date();
+                // don't try to select dates that don't exist
+                if (_.isNaN(moment([year, month, day]).valueOf())) day = 1;
+                app.props.set('date', moment([year, month, day]).valueOf(), opt);
+            };
         },
 
-        'vgrid-checkboxes': function (app) {
-            // always hide checkboxes on small devices initially
-            if (_.device('smartphone')) return;
-            var grid = app.getGrid();
-            grid.setEditable(app.props.get('checkboxes'));
+        'listview-checkboxes': function (app) {
+            if (_.device('smartphone')) app.listControl.$el.toggleClass('toolbar-top-visible', app.props.get('checkboxes'));
+            else app.listControl.$('.select-all').toggle(app.props.get('checkboxes'));
+            app.listView.toggleCheckboxes(app.props.get('checkboxes'));
         },
 
         /*
@@ -499,7 +555,8 @@ define('io.ox/calendar/main', [
                 app.settings
                     .set('viewView', data.layout)
                     .set('showCheckboxes', data.checkboxes)
-                    .set('colorScheme', data.colorScheme)
+                    .set('showMiniCalendar', data.showMiniCalendar)
+                    .set('showMonthviewWeekend', data.showMonthviewWeekend)
                     .save();
             }, 500));
         },
@@ -524,39 +581,19 @@ define('io.ox/calendar/main', [
          * Respond to change:checkboxes
          */
         'change:checkboxes': function (app) {
-            //if (_.device('smartphone')) return;
+            if (_.device('smartphone')) return;
+            function toggleTopbar(value) {
+                app.listControl.$el.toggleClass('toolbar-top-visible', value);
+            }
             app.props.on('change:checkboxes', function (model, value) {
-                app.grid.setEditable(value);
+                app.listView.toggleCheckboxes(value);
+                if (value) toggleTopbar(true);
+                app.listControl.$('.select-all').toggle('value', function () {
+                    if (!value) toggleTopbar(false);
+                });
             });
         },
 
-        /*
-         * Respond to change:colorScheme
-         */
-        'change:colorScheme': function (app) {
-            var selectScheme = function (app, value) {
-                var node = app.getWindow().nodes.outer;
-
-                switch (value) {
-                    case 'classic': node.removeClass('dark-colors custom-colors'); break;
-                    case 'dark':
-                        if (_.device('smartphone')) {
-                            node.removeClass('dark-colors custom-colors');
-                        } else {
-                            node.removeClass('custom-colors').addClass('dark-colors');
-                        }
-                        break;
-                    case 'custom': node.removeClass('dark-colors').addClass('custom-colors'); break;
-                    default: node.removeClass('dark-colors custom-colors'); break;
-                }
-            };
-
-            app.props.on('change:colorScheme', function (model, value) {
-                selectScheme(app, value);
-            });
-            selectScheme(app, app.props.get('colorScheme'));
-        },
-
         /*
          * Respond to layout change
          */
@@ -574,6 +611,18 @@ define('io.ox/calendar/main', [
             app.folder.handleErrors();
         },
 
+        'create': function (app) {
+            api.on('create', function (event) {
+                var folder = folderAPI.pool.getModel(event.folder);
+                // do not select public folder if allPublic is selected
+                if (app.folders.isSelected('cal://0/allPublic') && folder && folder.is('public')) return;
+                if (app.folders.isSingleSelection()) return;
+                app.folders.add(event.folder);
+                var model = folderAPI.pool.getModel(event.folder);
+                model.trigger('change', model);
+            });
+        },
+
         /*
          * Handle page change on delete on mobiles
          */
@@ -586,30 +635,34 @@ define('io.ox/calendar/main', [
             });
         },
 
+        // to update the context menu in the foldertree
+        'api-events': function (app) {
+            api.on('create update delete refresh.all', function () {
+                folderAPI.reload(app.folder.get());
+            });
+        },
+
         'inplace-find': function (app) {
-
             if (_.device('smartphone') || !capabilities.has('search')) return;
-
-            app.searchable();
+            if (!app.isFindSupported()) return;
+            app.initFind();
 
             var lastPerspective,
-                SEARCH_PERSPECTIVE = 'list',
-                find = app.get('find'),
-                emptyMessage = function findResultEmptyMessage() { return gt('No matching items found.'); };
+                SEARCH_PERSPECTIVE = 'list';
 
-            if (find) {
-                // WORKAROUND: no suitable way other of wrapping getEmptyMessage
-                app.grid.getEmptyMessage = _.wrap(app.grid.getEmptyMessage, function (fn) {
-                    if (app.grid.getMode() === 'search') return emptyMessage;
-                    // return function set by grid.setEmptyMessage
-                    return fn.apply(fn);
-                });
+            ext.point('io.ox/chronos/listview/notification/empty').extend({
+                id: 'no-resulsts',
+                index: 200,
+                draw: function () {
+                    if (!lastPerspective) return;
+                    this.text(gt('No matching items found.'));
+                }
+            });
 
+            function registerHandler(model, find) {
                 // additional handler: switch to list perspective (and back)
                 find.on({
                     'find:query': function () {
-                        // hide sort options
-                        app.grid.getToolbar().find('.grid-options:first').hide();
                         // switch to supported perspective
                         lastPerspective = lastPerspective || app.props.get('layout') || _.sanitize.option(_.url.hash('perspective'));
                         if (lastPerspective !== SEARCH_PERSPECTIVE) {
@@ -625,8 +678,6 @@ define('io.ox/calendar/main', [
                         if (lastPerspective && lastPerspective !== currentPerspective) {
                             app.props.set('layout', lastPerspective);
                         }
-                        // show sort options again
-                        app.grid.getToolbar().find('.grid-options:first').show();
                         // disable
                         app.props.off('change', find.cancel);
                         // reset
@@ -634,6 +685,8 @@ define('io.ox/calendar/main', [
                     }
                 });
             }
+
+            return app.get('find') ? registerHandler(app, app.get('find')) : app.once('change:find', registerHandler);
         },
 
         /*
@@ -653,7 +706,7 @@ define('io.ox/calendar/main', [
         'show-weekview-mobile': function (app) {
             if (_.device('!smartphone')) return;
             app.pages.getPage('week').on('pageshow', function () {
-                app.pages.getNavbar('week').setLeft(app.refDate.format('MMMM'));
+                app.pages.getNavbar('week').setLeft(app.getDate().format('MMMM'));
                 //app.pages.getPageObject('week').perspective.view.setScrollPos();
             });
         },
@@ -665,31 +718,44 @@ define('io.ox/calendar/main', [
             // detail app does not make sense on small devices
             // they already see appointments in full screen
             if (_.device('smartphone')) return;
-            app.grid.selection.on('selection:doubleclick', function (e, key) {
-                ox.launch('io.ox/calendar/detail/main', { cid: key });
+            app.listView.on('selection:doubleclick', function (list) {
+                if (list.length < 1) return;
+                ox.launch('io.ox/calendar/detail/main', { cid: list[0] });
             });
         },
 
         /*
-         * Add support for virtual folder "All my appointments"
+         * Add support for virtual folder "All my public appointments"
          */
-        'all-my-appointments': function (app) {
-
-            app.folderView.tree.selection.addSelectableVirtualFolder('virtual/all-my-appointments');
+        'virtual-folders': function (app) {
+            app.folderView.tree.selection.addSelectableVirtualFolder('cal://0/allPublic');
         },
 
+
         'contextual-help': function (app) {
             app.getContextualHelp = function () {
-                return 'ox.appsuite.user.sect.calendar.gui.html#ox.appsuite.user.sect.calendar.gui';
+                return 'ox.appsuite.user.sect.calendar.gui.html';
             };
         },
 
+        // reverted for 7.10
+        // 'primary-action': function (app) {
+
+        //     app.addPrimaryAction({
+        //         point: 'io.ox/calendar/sidepanel',
+        //         label: gt('New appointment'),
+        //         action: 'io.ox/calendar/detail/actions/create',
+        //         toolbar: 'create'
+        //     });
+        // },
+
         'sidepanel': function (app) {
 
             ext.point('io.ox/calendar/sidepanel').extend({
                 id: 'tree',
                 index: 100,
                 draw: function (baton) {
+                    if (_.device('smartphone')) return;
                     // add border & render tree and add to DOM
                     this.addClass('border-right').append(baton.app.treeView.$el);
                 }
@@ -707,8 +773,8 @@ define('io.ox/calendar/main', [
 
                 var nodes = app.getWindow().nodes,
                     sidepanel = nodes.sidepanel;
-                // vgrid toolbar
-                nodes.main.on('mousedown', '.vgrid-toolbar a[data-name], .vgrid-toolbar a[data-action]', function (e) {
+                // listview toolbar toolbar
+                nodes.main.on('mousedown', '.calendar-list-view .toolbar.top a a[data-name], .calendar-list-view .toolbar.top a a[data-action]', function (e) {
                     var node = $(e.currentTarget);
                     var action = node.attr('data-name') || node.attr('data-action');
                     if (!action) return;
@@ -779,8 +845,8 @@ define('io.ox/calendar/main', [
                         });
                 });
                 // selection in listview
-                app.grid.selection.on({
-                    'change': function (event, list) {
+                app.listView.on({
+                    'selection:change': function (list) {
                         if (!list.length) return;
                         metrics.trackEvent({
                             app: 'calendar',
@@ -803,7 +869,7 @@ define('io.ox/calendar/main', [
                     });
                 });
                 // double click or mousedown -> mark-time-slot -> mouseup
-                app.on('createAppoinment openCreateAppointment', function (e, data, layout) {
+                app.on('createAppointment openCreateAppointment', function (e, data, layout) {
                     var target = layout || 'list';
                     metrics.trackEvent({
                         app: 'calendar',
@@ -828,14 +894,12 @@ define('io.ox/calendar/main', [
         }));
 
         app.settings = settings;
-        app.refDate = moment();
 
         win.addClass('io-ox-calendar-main');
 
         // go!
-        var defaultFolder  = options.folder || 'virtual/all-my-appointments';
+        var defaultFolder  = options.folder || folderAPI.getDefaultFolder('calendar');
         if (!options.folder && capabilities.has('guest')) {
-            // guests don't have the all-my-appointments folder
             // try to select the first shared folder available
             if (folderAPI.getFlatCollection('calendar', 'shared').fetched) {
                 addFolderSupport(folderAPI.getFlatCollection('calendar', 'shared').models[0].get('id'));
@@ -856,7 +920,6 @@ define('io.ox/calendar/main', [
                     win.show();
                 })
                 .done(function () {
-
                     // app perspective
                     var lastPerspective = options.perspective || _.sanitize.option(_.url.hash('perspective')) || app.props.get('layout');
 
@@ -866,8 +929,12 @@ define('io.ox/calendar/main', [
                         // corrupt data fix
                         lastPerspective = 'week:workweek';
                     }
-                    ox.ui.Perspective.show(app, lastPerspective, { disableAnimations: true });
-                    app.props.set('layout', lastPerspective);
+
+                    ox.ui.Perspective.show(app, lastPerspective, { disableAnimations: true })
+                        .then(undefined, function applyFallback() {
+                            lastPerspective = 'week:workweek';
+                            return ox.ui.Perspective.show(app, lastPerspective, { disableAnimations: true });
+                        }).done(function () { app.props.set('layout', lastPerspective); });
                 });
         }
     });
