@@ -28,63 +28,59 @@ define('io.ox/calendar/view-grid-template', [
         main: {
 
             build: function () {
-                var title, location, time, date, shown_as, isPrivate;
+                var summary, location, time, date, transp, isPrivate;
 
-                this.addClass('calendar').append(
+                this.addClass('calendar calendar-grid-cell').append(
                     time = $('<div class="time">'),
                     date = $('<div class="date">'),
                     isPrivate = $('<i class="fa fa-lock private-flag" aria-hidden="true">').hide(),
-                    title = $('<div class="title">'),
+                    summary = $('<div class="title">'),
                     $('<div class="location-row">').append(
-                        shown_as = $('<span class="shown_as label label-info">&nbsp;</span>'),
+                        transp = $('<span class="shown_as label label-info">&nbsp;</span>'),
                         location = $('<span class="location">')
                     )
                 );
 
                 return {
-                    title: title,
+                    summary: summary,
                     location: location,
                     time: time,
                     date: date,
-                    shown_as: shown_as,
+                    transp: transp,
                     isPrivate: isPrivate
                 };
             },
 
             set: function (data, fields) {
 
-                var self = this,
-                    isPrivate = _.isUndefined(data.title),
-                    title = isPrivate ? gt('Private') : gt.noI18n(data.title || '\u00A0'),
+                var isPrivate = _.isUndefined(data.summary),
+                    summary = isPrivate ? gt('Private') : (data.summary || '\u00A0'),
                     a11yLabel = [];
 
                 //conflicts with appointments, where you aren't a participant don't have a folder_id.
                 if (data.folder_id) {
-                    var folder = folderAPI.get(data.folder_id);
-                    folder.done(function (folder) {
-                        var conf = util.getConfirmationStatus(data, folderAPI.is('shared', folder) ? folder.created_by : ox.user_id);
-                        self.addClass(util.getConfirmationClass(conf) + (data.hard_conflict ? ' hardconflict' : ''));
-                    });
+                    var conf = util.getConfirmationStatus(data);
+                    this.addClass(util.getConfirmationClass(conf) + (data.hard_conflict ? ' hardconflict' : ''));
                 }
 
-                fields.title.text(title);
+                fields.summary.text(summary);
 
-                fields.location.text(gt.noI18n(data.location || '\u00A0'));
-                fields.time.text(gt.noI18n(util.getTimeInterval(data)));
-                fields.date.text(gt.noI18n(util.getDateInterval(data)));
-                fields.shown_as.addClass(util.getShownAsLabel(data)).attr('title', util.getShownAs(data));
+                fields.location.text(data.location || '\u00A0');
+                fields.time.text(util.getTimeInterval(data));
+                fields.date.text(util.getDateInterval(data));
+                fields.transp.addClass(util.getShownAsLabel(data)).attr('summary', util.getShownAs(data));
 
                 fields.isPrivate.toggle(isPrivate);
 
                 // a11y: this should be unnecessary!
 
-                a11yLabel.push(title);
+                a11yLabel.push(summary);
                 //#. %1$s is an appointment location (e.g. a room, a telco line, a company, a city)
                 //#. This fragment appears within a long string for screen readers.
                 //#. Some languages (e.g. German) might need to translate "location:".
                 if (data.location) a11yLabel.push(gt.pgettext('a11y', 'at %1$s', data.location));
                 a11yLabel.push(util.getTimeIntervalA11y(data));
-                a11yLabel.push(gt.noI18n(util.getDateIntervalA11y(data)));
+                a11yLabel.push(util.getDateIntervalA11y(data));
 
                 this.attr('aria-label', _.escape(a11yLabel.join(', ') + '.'));
             }
@@ -98,7 +94,7 @@ define('io.ox/calendar/view-grid-template', [
                     tagName: 'li',
                     defaultClassName: 'vgrid-cell list-unstyled'
                 }),
-                $ul = $('<ul>');
+                $ul = $('<ul class="calendar-grid">');
 
             // add template
             tmpl.add(that.main);
