@@ -19,13 +19,13 @@ define('io.ox/contacts/addressbook/popup', [
     'io.ox/core/extensions',
     'io.ox/contacts/util',
     'io.ox/contacts/api',
+    'l10n/ja_JP/io.ox/collation',
     'gettext!io.ox/contacts',
     'gettext!io.ox/core',
     'settings!io.ox/contacts',
     'settings!io.ox/mail',
-    'l10n/ja_JP/io.ox/collation',
     'less!io.ox/contacts/addressbook/style'
-], function (http, folderAPI, ModalDialog, ListView, ext, util, api, gt, gtCore, settings, mailSettings, collation) {
+], function (http, folderAPI, ModalDialog, ListView, ext, util, api, collation, gt, gtCore, settings, mailSettings) {
 
     'use strict';
 
@@ -46,7 +46,8 @@ define('io.ox/contacts/addressbook/popup', [
     var collected_id = mailSettings.get('contactCollectFolder', 0);
 
     // split words
-    var regSplitWords = /[\s,.\-:;\<\>\(\)\_\@\/\'\"]/;
+    var regSplitWords = /[\s,.\-:;<>()_@/'"]/;
+    // '
 
     // feature toggles
     var useInitials = settings.get('picker/useInitials', true),
@@ -54,7 +55,9 @@ define('io.ox/contacts/addressbook/popup', [
         useLabels = settings.get('picker/useLabels', false),
         closeOnDoubleClick = settings.get('picker/closeOnDoubleClick', true),
         useGlobalAddressBook = settings.get('picker/globalAddressBook', true),
-        useDepartments = settings.get('picker/departments', true);
+        //TODO: unify feature toggles: showDepartment is a newer backend toggle, picker/departments is frontend only
+        showDepartment = settings.get('showDepartment'),
+        useDepartments = typeof showDepartment === 'undefined' ? settings.get('picker/departments', true) : showDepartment;
 
     if (useDepartments) names.push('department');
 
@@ -147,6 +150,7 @@ define('io.ox/contacts/addressbook/popup', [
     var getAllMailAddresses = (function () {
 
         return function (options) {
+            options = options || {};
             return $.when(
                 fetchAddresses(options),
                 useLabels ? fetchLabels() : $.when()
@@ -163,14 +167,13 @@ define('io.ox/contacts/addressbook/popup', [
 
             options = _.extend({
                 // keep this list really small for good performance!
-                columns: '1,20,500,501,502,505,519,555,556,557,592,602,606,610,611',
+                columns: '1,20,500,501,502,505,519,524,555,556,557,592,602,606,616,617',
                 exclude: useGlobalAddressBook ? [] : ['6'],
                 limit: LIMITS.fetch
             }, options);
 
             var data = {
-                exclude_folders: options.exclude,
-                last_name: '*'
+                exclude_folders: options.exclude
             };
 
             if (options.folder === 'all') delete options.folder;
@@ -182,7 +185,8 @@ define('io.ox/contacts/addressbook/popup', [
                     admin: settings.get('showAdmin', false),
                     columns: options.columns,
                     right_hand_limit: options.limit,
-                    sort: 609
+                    sort: 608,
+                    order: 'desc'
                 },
                 // emailAutoComplete doesn't work; need to clean up client-side anyway
                 data: data
@@ -238,7 +242,9 @@ define('io.ox/contacts/addressbook/popup', [
                     // get a match for each address
                     addresses.forEach(function (field, i) {
                         var obj = process(item, sort_name, (item[field] || '').toLowerCase(), rank, i, field);
-                        if (obj) result.push((hash[obj.cid] = obj));
+                        if (obj) {
+                            result.push((hash[obj.cid] = obj));
+                        }
                     });
                 }
             });
@@ -252,7 +258,7 @@ define('io.ox/contacts/addressbook/popup', [
             // drop no-reply addresses
             if (/^(noreply|no-reply|do-not-reply)@/.test(address)) return;
             // drop broken imports
-            if (/^\=\?iso\-8859\-1\?q\?\=22/i.test(item.display_name)) return;
+            if (/^=\?iso-8859-1\?q\?=22/i.test(item.display_name)) return;
             // add to results
             // do all calculations now; during rendering is more expensive
             var folder_id = String(item.folder_id),
@@ -282,7 +288,8 @@ define('io.ox/contacts/addressbook/popup', [
                 sort_name: sort_name.concat(address).join('_').toLowerCase().replace(/\s/g, '_'),
                 // allow sorters to have special handling for sortnames and addresses
                 sort_name_without_mail: sort_name.join('_').toLowerCase().replace(/\s/g, '_'),
-                title: item.title
+                title: item.title,
+                rank: 1000 + ((folder_id === '6' ? 10 : 0) + rank) * 10 + i
             };
         }
 
@@ -346,7 +353,8 @@ define('io.ox/contacts/addressbook/popup', [
                     mail_full_name: util.getMailFullName(item),
                     // all lower-case to be case-insensitive; replace spaces to better match server-side collation
                     sort_name: item.display_name.toLowerCase().replace(/\s/g, '_'),
-                    title: item.title
+                    title: item.title,
+                    rank: i
                 };
                 result.push((hash[item.cid] = item));
             });
@@ -367,6 +375,10 @@ define('io.ox/contacts/addressbook/popup', [
         };
     }());
 
+    function rankSorter(a, b) {
+        return a.rank - b.rank;
+    }
+
     //
     // Match all words
     //
@@ -418,8 +430,8 @@ define('io.ox/contacts/addressbook/popup', [
                 var $dropdown = this.$('.folder-dropdown'),
                     count = 0, self = this;
                 // remove global address book?
-                if (!useGlobalAddressBook && folders['public']) {
-                    folders['public'] = _(folders['public']).reject({ id: '6' });
+                if (!useGlobalAddressBook && folders.public) {
+                    folders.public = _(folders.public).reject({ id: '6' });
                 }
                 if (this.options.useGABOnly) {
                     folders = _.pick(folders, 'public');
@@ -514,7 +526,7 @@ define('io.ox/contacts/addressbook/popup', [
                     ref: 'io.ox/contacts/addressbook-popup/list',
                     selection: { behavior: 'simple' }
                 });
-                this.$body.append(this.listView.render().$el);
+                this.$body.append(this.listView.render().$el.addClass('address-picker'));
             },
             onOpen: function () {
 
@@ -552,13 +564,7 @@ define('io.ox/contacts/addressbook/popup', [
                     query = $.trim(query);
                     var result, isSearch = query.length && query !== '@';
                     if (isSearch) {
-                        // split query into single words (without leading @; covers edge-case)
-                        var words = query.replace(/^@/, '').split(regSplitWords), firstWord = words[0];
-                        // use first word for the index-based lookup
-                        result = searchIndex(this.index, firstWord);
-                        result = this.resolveItems(result).sort(sorter);
-                        // final filter to match all words
-                        result = matchAllWords(result, words.slice(1));
+                        result = search(query, this.index, this.store.getHash());
                         // render
                         var json = JSON.stringify(result);
                         if (json === this.lastJSON) return;
@@ -613,6 +619,9 @@ define('io.ox/contacts/addressbook/popup', [
                             // full data
                             hash = data;
                         },
+                        getHash: function () {
+                            return hash;
+                        },
                         add: function (list) {
                             _(list).each(function (id) { selection[id] = true; });
                         },
@@ -706,64 +715,11 @@ define('io.ox/contacts/addressbook/popup', [
         .build(function () {
             var self = this;
 
-            // use a template for maximum performance
-            // yep, no extensions here; too slow for find-as-you-type
-            var template = _.template(
-                '<% _(list).each(function (item) { %>' +
-                '<li class="list-item selectable" aria-selected="false" role="option" tabindex="-1" data-cid="<%- item.cid %>">' +
-                '  <div class="list-item-checkmark"><i class="fa fa-checkmark" aria-hidden="true"></i></div>' +
-                '  <div class="list-item-content">' +
-                '    <% if (item.list) { %>' +
-                '      <div class="contact-picture distribution-list" aria-hidden="true"><i class="fa fa-align-justify"></i></div>' +
-                '    <% } else if (item.label) { %>' +
-                '      <div class="contact-picture label" aria-hidden="true"><i class="fa fa-users"></i></div>' +
-                '    <% } else if (item.image) { %>' +
-                '      <div class="contact-picture image" data-original="<%= item.image %>" aria-hidden="true"></div>' +
-                '    <% } else { %>' +
-                '      <div class="contact-picture initials <%= item.initial_color %>" aria-hidden="true"><%- item.initials %></div>' +
-                '    <% } %>' +
-                '    <div class="name">' +
-                '       <%= item.full_name_html || item.email || "\u00A0" %>' +
-                '       <% if (item.department) { %><span class="gray">(<%- item.department %>)</span><% } %>' +
-                '    </div>' +
-                '    <div class="email gray"><%- item.caption || "\u00A0" %></div>' +
-                '  </div>' +
-                '</li>' +
-                '<% }); %>'
-            );
-
-            this.$el.on('appear', function (e) {
-                // track contact pictures that appear; we assume they get cached
-                appeared[$(e.target).attr('data-original')] = true;
-            });
+            this.$el.on('appear', onAppear);
 
             this.renderItems = function (list, options) {
-                // avoid duplicates (name + email address; see bug 56040)
-                list = _(list).filter(function (item) {
-                    if (item.label) return true;
-                    var cid = item.full_name + ' ' + item.email;
-                    if (this[cid]) return false; return (this[cid] = true);
-                }, {});
-                // get defaults
-                options = _.extend({
-                    limit: options.isSearch ? LIMITS.search : LIMITS.render,
-                    offset: 0
-                }, options);
-                // empty?
-                if (!list.length) return this.renderEmpty(options);
-                // get subset; don't draw more than n items by default
-                var subset = list.slice(options.offset, options.limit),
-                    $el = this.$('.list-view');
-                // clear if offset is zero
-                if (options.offset === 0) $el[0].innerHTML = '';
-                $el[0].innerHTML += template({ list: subset });
-                if (options.offset === 0) $el.scrollTop(0);
-                $el.data({ list: list, options: options });
-                this.$('.contact-picture[data-original]').each(function () {
-                    // appeared before? show now; no lazyload; better experience
-                    var node = $(this), url = node.attr('data-original');
-                    if (appeared[url]) node.css('background-image', 'url(' + url + ')'); else node.lazyload();
-                });
+                options.renderEmpty = this.renderEmpty.bind(this, options);
+                renderItems.call(this.$('.list-view'), list, options);
                 // restore selection
                 var ids = this.store.getIds();
                 this.listView.selection.set(ids);
@@ -809,11 +765,7 @@ define('io.ox/contacts/addressbook/popup', [
             });
 
             this.resolveItems = function (ids) {
-                return _(ids)
-                    .chain()
-                    .map(function (cid) { return this.store.resolve(cid); }, this)
-                    .compact()
-                    .value();
+                return resolveItems(this.store.getHash(), ids);
             };
 
             this.flattenItems = function (ids, options) {
@@ -845,7 +797,9 @@ define('io.ox/contacts/addressbook/popup', [
                             id: item.id,
                             folder_id: item.folder_id,
                             email: mail,
-                            field: item.field
+                            // mail_field is used in distribution lists
+                            field: item.mail_field ? 'email' + item.mail_field : item.field,
+                            user_id: item.user_id
                         };
                     }, this)
                     .flatten()
@@ -855,6 +809,8 @@ define('io.ox/contacts/addressbook/popup', [
         })
         .on({
             'close': function () {
+                // reset folder to default
+                folder = 'all';
                 isOpen = false;
             },
             'error': function (e) {
@@ -872,6 +828,85 @@ define('io.ox/contacts/addressbook/popup', [
         .open();
     }
 
+    function search(query, index, hash, ranked) {
+        // split query into single words (without leading @; covers edge-case)
+        var words = query.replace(/^@/, '').split(regSplitWords), firstWord = words[0], result;
+        // use first word for the index-based lookup
+        result = searchIndex(index, firstWord);
+        result = resolveItems(hash, result).sort(ranked ? rankSorter : sorter);
+        // final filter to match all words
+        return matchAllWords(result, words.slice(1));
+    }
+
+    // use a template for maximum performance
+    // yep, no extensions here; too slow for find-as-you-type
+    var template = _.template(
+        '<% _(list).each(function (item) { %>' +
+        '<li class="list-item selectable" aria-selected="false" role="option" tabindex="-1" data-cid="<%- item.cid %>">' +
+        '  <div class="list-item-checkmark"><i class="fa fa-checkmark" aria-hidden="true"></i></div>' +
+        '  <div class="list-item-content">' +
+        '    <% if (item.list) { %>' +
+        '      <div class="contact-picture distribution-list" aria-hidden="true"><i class="fa fa-align-justify" aria-hidden="true"></i></div>' +
+        '    <% } else if (item.label) { %>' +
+        '      <div class="contact-picture label" aria-hidden="true"><i class="fa fa-users" aria-hidden="true"></i></div>' +
+        '    <% } else if (item.image) { %>' +
+        '      <div class="contact-picture image" data-original="<%= item.image %>" aria-hidden="true"></div>' +
+        '    <% } else { %>' +
+        '      <div class="contact-picture initials <%= item.initial_color %>" aria-hidden="true"><%- item.initials %></div>' +
+        '    <% } %>' +
+        '    <div class="name">' +
+        '       <%= item.full_name_html || item.email || "\u00A0" %>' +
+        '       <% if (item.department) { %><span class="gray">(<%- item.department %>)</span><% } %>' +
+        '    </div>' +
+        '    <div class="email gray"><%- item.caption || "\u00A0" %></div>' +
+        '  </div>' +
+        '</li>' +
+        '<% }); %>'
+    );
+
+    function onAppear(e) {
+        // track contact pictures that appear; we assume they get cached
+        appeared[$(e.target).attr('data-original')] = true;
+    }
+
+    function renderItems(list, options) {
+        // avoid duplicates (name + email address; see bug 56040)
+        list = _(list).filter(function (item) {
+            if (item.label) return true;
+            var cid = item.full_name + ' ' + item.email;
+            if (this[cid]) return false; return (this[cid] = true);
+        }, {});
+        // get defaults
+        options = _.extend({
+            limit: options.isSearch ? LIMITS.search : LIMITS.render,
+            offset: 0
+        }, options);
+        // empty?
+        if (!list.length) {
+            if (options.renderEmpty) options.renderEmpty(options);
+        }
+        // get subset; don't draw more than n items by default
+        var subset = list.slice(options.offset, options.limit);
+        // clear if offset is zero
+        if (options.offset === 0) this[0].innerHTML = '';
+        this[0].innerHTML += template({ list: subset });
+        if (options.offset === 0) this.scrollTop(0);
+        this.data({ list: list, options: options });
+        this.find('.contact-picture[data-original]').each(function () {
+            // appeared before? show now; no lazyload; better experience
+            var node = $(this), url = node.attr('data-original');
+            if (appeared[url]) node.css('background-image', 'url(' + url + ')'); else node.lazyload();
+        });
+    }
+
+    function resolveItems(hash, ids) {
+        return _(ids)
+            .chain()
+            .map(function (cid) { return hash[cid]; })
+            .compact()
+            .value();
+    }
+
     /* Debug lines
 
     require(['io.ox/contacts/addressbook/popup'], function (popup) { popup.getAllMailAddresses().always(_.inspect); });
@@ -1001,7 +1036,7 @@ define('io.ox/contacts/addressbook/popup', [
                     $('<a href="#" class="pull-right clear" role="button">').text(gt('Clear selection'))
                 ),
                 // list
-                $('<div aria-live="polite" aria-relevant="removals" aria-hidden="false">').attr('aria-label', description).append(
+                $('<div aria-live="polite" aria-relevant="removals">').attr('aria-label', description).append(
                     $('<ul class="addresses unstyled listbox" tabindex="0" role="listbox">')
                         .append(_(list).map(addToken))
                 )
@@ -1057,6 +1092,10 @@ define('io.ox/contacts/addressbook/popup', [
         buildIndex: buildIndex,
         searchIndex: searchIndex,
         getAllMailAddresses: getAllMailAddresses,
+        sorter: sorter,
+        onAppear: onAppear,
+        renderItems: renderItems,
+        search: search,
         TokenView: TokenView,
         open: open
     };
