@@ -304,19 +304,13 @@ define('io.ox/contacts/api', [
      * @returns defered
      */
     function clearUserApiCache(data) {
-        var def = $.Deferred();
-        require(['io.ox/core/api/user'], function (userApi) {
-            $.when(
-                    userApi.caches.get.remove({ id: data.user_id }),
-                    userApi.caches.all.clear(),
-                    userApi.caches.list.remove({ id: data.user_id })
-                ).then(function () {
-                    def.resolve();
-                }, function () {
-                    def.reject();
-                });
+        return require(['io.ox/core/api/user']).then(function (userApi) {
+            return $.when(
+                userApi.caches.get.remove({ id: data.user_id }),
+                userApi.caches.all.clear(),
+                userApi.caches.list.remove({ id: data.user_id })
+            );
         });
-        return def;
     }
 
     /**
@@ -476,6 +470,12 @@ define('io.ox/contacts/api', [
                     api.trigger('update', data);
                     // trigger refresh.all, since position might have changed
                     api.trigger('refresh.all');
+                    // reset image?
+                    if (o.data.image1 === '') {
+                        // to clear picture halo's cache
+                        api.trigger('update:image', data);
+                        api.trigger('reset:image reset:image:' + _.ecid(data), data);
+                    }
                 });
             });
         });
@@ -650,7 +650,7 @@ define('io.ox/contacts/api', [
                     // remove host
                     if (data.image1_url) {
                         data.image1_url = data.image1_url
-                            .replace(/^https?\:\/\/[^\/]+/i, '');
+                            .replace(/^https?:\/\/[^/]+/i, '');
                         data.image1_url = coreUtil.replacePrefix(data.image1_url);
                         data.image1_url = coreUtil.getShardingRoot(data.image1_url);
                     }
@@ -681,7 +681,7 @@ define('io.ox/contacts/api', [
     api.pictureHalo = (function () {
 
         // local hash to recognize URLs that have been fetched already
-        var cachesURLs = {},
+        var cachedURLs = {},
             uniq = ox.t0,
             fallback = api.getFallbackImage();
 
@@ -695,13 +695,17 @@ define('io.ox/contacts/api', [
                 // use lazyload?
                 opt.container = opt.container || _.first(node.closest('.scrollpane, .scrollable, .scrollpane-lazyload'));
                 if (opt.lazyload || opt.container) {
-                    node.css('background-image', 'url(' + fallback + ')')
-                        .attr('data-original', url)
+                    if (opt.fallback) node.css('background-image', 'url(' + fallback + ')');
+                    node.attr('data-original', url)
                         .on('load.lazyload error.lazyload', function (e, image) {
-                            if (image.width === 1) url = fallback;
-                            else cachesURLs[url] = url;
-                            node.attr('data-original', url)
-                                .css('background-image', 'url(' + url + ')');
+                            if (image.width === 1 || e.type === 'error') {
+                                url = opt.fallback ? fallback : null;
+                            } else {
+                                cachedURLs[url] = url;
+                            }
+                            if (url) {
+                                node.text('').attr('data-original', url).css('background-image', 'url(' + url + ')');
+                            }
                             node = url = opt = null;
                             $(this).off('.lazyload');
                         })
@@ -709,8 +713,8 @@ define('io.ox/contacts/api', [
                 } else {
                     $(new Image()).on('load error', function (e) {
                         var fail = this.width === 1 || e.type === 'error';
-                        if (!fail) cachesURLs[url] = url;
-                        node.css('background-image', 'url(' + (fail ? fallback : url) + ')');
+                        if (!fail) cachedURLs[url] = url;
+                        if (!fail || opt.fallback) node.text('').css('background-image', 'url(' + (fail ? fallback : url) + ')');
                         node = null;
                         $(this).off();
                     })
@@ -723,7 +727,6 @@ define('io.ox/contacts/api', [
         return function (node, data, options) {
 
             var params,
-                useApi = options.api || 'contact',
                 url,
                 opt = _.extend({
                     width: 48,
@@ -732,7 +735,8 @@ define('io.ox/contacts/api', [
                     // lazy load block
                     lazyload: false,
                     effect: 'show',
-                    urlOnly: false
+                    urlOnly: false,
+                    fallback: true
                 }, options);
             delete opt.api;
             // use copy of data object because of delete-statements
@@ -773,7 +777,7 @@ define('io.ox/contacts/api', [
                 url = data.image1_url = coreUtil.replacePrefix(data.image1_url) + '&' + $.param(params);
                 url = coreUtil.getShardingRoot(url);
 
-            } else if (!data.email && !data.email1 && !data.mail && !data.contact_id && !data.id && !data.internal_userid) {
+            } else if (opt.fallback && !data.email && !data.email1 && !data.mail && !data.contact_id && !data.id && !data.internal_userid) {
                 url = fallback;
             }
 
@@ -819,11 +823,11 @@ define('io.ox/contacts/api', [
                 }
             }
 
-            url = coreUtil.getShardingRoot((useApi === 'user' ? '/image/user/picture?' : '/halo/contact/picture?') + $.param(params));
+            url = coreUtil.getShardingRoot('/halo/contact/picture?' + $.param(params));
 
             // cached?
-            if (cachesURLs[url]) {
-                return opt.urlOnly ? cachesURLs[url] : node.css('background-image', 'url(' + cachesURLs[url] + ')');
+            if (cachedURLs[url]) {
+                return opt.urlOnly ? cachedURLs[url] : node.text('').css('background-image', 'url(' + cachedURLs[url] + ')');
             }
 
             try {
@@ -855,7 +859,7 @@ define('io.ox/contacts/api', [
 
         // set node content
         set = function (name) {
-            if (options.halo && /\@/.test(data.email) && capabilities.has('contacts')) {
+            if (options.halo && /@/.test(data.email) && capabilities.has('contacts')) {
                 node
                 .addClass('halo-link')
                 .attr('href', '#')
@@ -864,7 +868,7 @@ define('io.ox/contacts/api', [
                     email1: email
                 });
             }
-            node.text(_.noI18n(name + '\u00A0'));
+            node.text(name + '\u00A0');
         };
 
         // clear vars after call stack has cleared
@@ -1005,11 +1009,11 @@ define('io.ox/contacts/api', [
 
     /**
      * is ressource (duck check)
-     * @param  {object} obj (contact)
+     * @param  {object} obj (contact) or calendar event attendee
      * @return {boolean}
      */
     api.looksLikeResource = function (obj) {
-        return 'mailaddress' in obj && 'description' in obj;
+        return ('mailaddress' in obj && 'description' in obj) || ('cuType' in obj && obj.cuType === 'RESOURCE');
     };
 
     /**
@@ -1072,6 +1076,8 @@ define('io.ox/contacts/api', [
             // use these fields for local lookups
             fields = settings.get('search/autocompleteFields', 'display_name,email1,email2,email3,first_name,last_name').split(',');
 
+        if (settings.get('showDepartment')) fields.push('department');
+
         // check for minimum length
         function hasMinLength(str) {
             return str.length >= minLength;
@@ -1094,9 +1100,10 @@ define('io.ox/contacts/api', [
             return def.then(function (data) {
                 return _(data).filter(function (item) {
                     return _(words).every(function (word) {
+                        var regexWord = new RegExp('\\b' + escape(word));
                         return _(item.fulltext).some(function (str) {
-                            // server also uses startsWith() / not contains()
-                            return str.indexOf(word) === 0 || str.indexOf(query) === 0;
+                            // server might use startsWith() or contains() depending whether DB uses a fulltext index
+                            return regexWord.test(str) || str.indexOf(query) > -1;
                         });
                     });
                 });
@@ -1119,6 +1126,11 @@ define('io.ox/contacts/api', [
             });
         }
 
+        // escape words for regex
+        function escape(str) {
+            return str.replace(/[-/\\^$*+?.()|[\]{}]/g, '\\$&');
+        }
+
         function search(query, options) {
 
             // always work with trimmed lower-case variant
@@ -1176,7 +1188,6 @@ define('io.ox/contacts/api', [
     });
 
     api.on('maybeNewContact', function () {
-        if (ox.debug) console.info('Clearing autocomplete cache');
         api.autocomplete.cache = {};
     });
 
