@@ -88,9 +88,9 @@ define('io.ox/contacts/distrib/create-dist-view', [
         render: function () {
             var self = this;
             // define collection
-            this.baton.member = new pModel.Participants(this.baton.model.get('distribution_list'));
+            this.baton.member = new pModel.Participants(this.baton.model.get('distribution_list'), { silent: false });
 
-            this.listenTo(this.baton.member, 'add remove reset', function (ctx, col) {
+            this.listenTo(this.baton.member, 'add remove', function (ctx, col) {
                 var all = col.map(function (m) {
                     if (_.isNumber(m.getContactID())) {
                         return {
@@ -114,6 +114,7 @@ define('io.ox/contacts/distrib/create-dist-view', [
                 collection: this.baton.member,
                 baton: this.baton,
                 isMail: true,
+                strict: true,
                 empty: gt('This list has no members yet')
             }).render().$el);
         }
