@@ -13,12 +13,32 @@
 
 define('io.ox/contacts/util', [
     'io.ox/core/util',
+    'io.ox/core/extensions',
     'settings!io.ox/contacts',
     'gettext!io.ox/contacts'
-], function (util, settings, gt) {
+], function (util, ext, settings, gt) {
 
     'use strict';
 
+    require(['settings!io.ox/contacts']).then(function (settings) {
+        if (!settings.get('showDepartment')) return;
+
+        $('html').addClass('showDepartment');
+        ext.point('io.ox/core/person').extend({
+            index: 'last',
+            id: 'department',
+            draw: function (baton) {
+                if (baton.data.folder_id === 6 &&
+                    !!baton.data.department
+                ) {
+                    this.append(
+                        $('<span class="department">').text(gt.format(' (%1$s) ', baton.data.department))
+                    );
+                }
+            }
+        });
+    });
+
     /**
      * Creates a result for get*Format functions which consists of a single
      * value.
@@ -29,8 +49,8 @@ define('io.ox/contacts/util', [
      */
     function single(index, value) {
         var params = new Array(index);
-        params[index - 1] = _.noI18n(value);
-        return { format: _.noI18n('%' + index + '$s'), params: params };
+        params[index - 1] = value;
+        return { format: '%' + index + '$s', params: params };
     }
 
     // vanity fix
@@ -60,7 +80,7 @@ define('io.ox/contacts/util', [
         var copy = obj;
         if (htmlOutput === true) {
             copy = {};
-            _(['title', 'first_name', 'last_name', 'display_name']).each(function (id) {
+            _(['title', 'first_name', 'last_name', 'display_name', 'cn']).each(function (id) {
                 var text = $.trim(obj[id]);
                 if (!text) {
                     // yomi as fallback
@@ -84,7 +104,7 @@ define('io.ox/contacts/util', [
         // variant of getFullName without title, all lowercase
         getSortName: function (obj) {
             // use a copy without title
-            obj = _.pick(obj, 'first_name', 'last_name', 'display_name');
+            obj = _.pick(obj, 'first_name', 'last_name', 'display_name', 'cn');
             return this.getFullName(obj).toLowerCase();
         },
 
@@ -93,7 +113,7 @@ define('io.ox/contacts/util', [
          * @param obj {Object} A contact object.
          * @type {
          *     format: string,
-         *     params: [first_name, last_name, title, display_name]
+         *     params: [first_name, last_name, title, display_name, cn]
          * }
          * @returns An object with a format
          * string and an array of replacements which can be used e.g. as
@@ -103,18 +123,18 @@ define('io.ox/contacts/util', [
 
             var first_name = $.trim(obj.first_name),
                 last_name = $.trim(obj.last_name),
-                display_name = $.trim(obj.display_name),
+                display_name = $.trim(obj.display_name || obj.cn),
                 title = $.trim(obj.title);
 
             // combine title, last_name, and first_name
             if (first_name && last_name) {
 
                 var preference = settings.get('fullNameFormat', 'auto'),
-                    params = [_.noI18n(first_name), _.noI18n(last_name)],
+                    params = [first_name, last_name],
                     format;
 
                 title = getTitle(title);
-                if (title) params.push(_.noI18n(title));
+                if (title) params.push(title);
 
                 if (preference === 'firstname lastname') {
                     format = title ? '%3$s %1$s %2$s' : '%1$s %2$s';
@@ -149,7 +169,7 @@ define('io.ox/contacts/util', [
             // fallback #3: use existing display name?
             if (display_name) return single(4, util.unescapeDisplayName(display_name));
 
-            return { format: _.noI18n(''), params: [] };
+            return { format: '', params: [] };
         },
 
         getFullName: function (obj, htmlOutput) {
@@ -196,7 +216,7 @@ define('io.ox/contacts/util', [
                         //#. %1$s is the first name
                         //#. %2$s is the last name
                         gt.pgettext('mail address', '%1$s %2$s'),
-                    params: [_.noI18n(first_name), _.noI18n(last_name)]
+                    params: [first_name, last_name]
                 };
             }
 
@@ -215,7 +235,7 @@ define('io.ox/contacts/util', [
                 return single(4, util.unescapeDisplayName(display_name));
             }
 
-            return { format: _.noI18n(''), params: [] };
+            return { format: '', params: [] };
         },
 
         getMailFullName: function (obj, htmlOutput) {
@@ -238,7 +258,7 @@ define('io.ox/contacts/util', [
             if (obj.email1) return single(1, obj.email1);
             if (obj.email2) return single(2, obj.email2);
             if (obj.email3) return single(3, obj.email3);
-            return { format: _.noI18n(''), params: [] };
+            return { format: '', params: [] };
         },
 
         getMail: function (obj) {
@@ -301,13 +321,13 @@ define('io.ox/contacts/util', [
         getBirthday: function (birthday) {
             // ensure instance of moment
             birthday = moment.utc(birthday);
-            // Year 0 is special for birthdays without year (backend changes this to 1, however ...)
+            // Year 1 and year 1604 are  special for birthdays without year
             // therefore, return full date if year is not 1
-            if (birthday.year() > 1) return birthday.format('l');
+            if (birthday.year() > 1 && birthday.year() !== 1604) return birthday.format('l');
             // get localized format without the year otherwise
             // i.e. remove dashes and slashes but keep dots
             return birthday.format(
-                moment.localeData().longDateFormat('l').replace(/[\/\-]*Y+[\/\-]*/, '')
+                moment.localeData().longDateFormat('l').replace(/[/-]*Y+[/-]*/, '')
             );
         },
 
@@ -325,7 +345,7 @@ define('io.ox/contacts/util', [
                 options.height *= 2;
             }
 
-            var url = arg.replace(/^https?\:\/\/[^\/]+/i, '');
+            var url = arg.replace(/^https?:\/\/[^/]+/i, '');
             url = util.replacePrefix(url);
 
             return util.getShardingRoot(url + '&' + $.param(options));
