@@ -77,7 +77,7 @@ define.async('io.ox/core/boot/main', [
 
             // set page title now
             ox.on('language', function (lang, gt) {
-                util.setPageTitle(ox.serverConfig.pageTitle + ' ' + gt.pgettext('word', 'Sign in'));
+                ox.trigger('change:document:title', gt.pgettext('word', 'Sign in'));
             });
 
             gettext.setLanguage('en_US');
@@ -166,6 +166,9 @@ define.async('io.ox/core/boot/main', [
             index: 1000000000000,
             login: function (baton) {
                 baton.logins.useForm();
+            },
+            relogin: function () {
+                util.gotoSignin('login_type=useForm');
             }
         }
     );
@@ -187,7 +190,7 @@ define.async('io.ox/core/boot/main', [
             config.user().done(function () {
                 // apply session data (again) & page title
                 if (data) session.set(data);
-                util.setPageTitle(ox.serverConfig.pageTitle);
+                ox.trigger('change:document:title');
                 // load UI
                 exports.loadUI();
             });
@@ -199,7 +202,8 @@ define.async('io.ox/core/boot/main', [
             } // Otherwise continue thru the other login stages
         },
 
-        'login:fail:session-based': function () {
+        'login:fail:session-based': function (baton) {
+            baton.stopPropagation();
             $('.throbber').hide();
             $('#showstopper, #showstopper .session').show();
         }
