@@ -35,6 +35,26 @@ define('io.ox/core/boot/util', [], function () {
 
     ox.on('language', displayFeedback);
 
+    ox.on('change:document:title', function (arg) {
+        var elements = [].concat(arg),
+            change = _.lfo(changeDocumentTitle);
+
+        // skip if we don't have a session (i.e. during signin) because there is no way to get anything via user api
+        if (ox.signin) return change(elements);
+
+        require(['io.ox/core/api/user', 'io.ox/contacts/util'], function (api, util) {
+            api.get({ id: ox.user_id }).done(function (data) {
+                var user = util.getMailFullName(data) || ox.user;
+                elements.push(user);
+                change(elements);
+            });
+        });
+    });
+
+    function changeDocumentTitle(elements) {
+        document.title = document.customTitle = _.compact(_.uniq(elements)).concat(ox.serverConfig.productName).join(' - ');
+    }
+
     var exports = {
 
         DURATION: 250,
@@ -44,7 +64,8 @@ define('io.ox/core/boot/util', [], function () {
         gt: _.identity,
 
         setPageTitle: function (title) {
-            document.title = title || '';
+            ox.trigger('change:document:title', title);
+            // document.title = title || '';
             $('[name="apple-mobile-web-app-title"]').attr('content', title);
         },
 
@@ -122,7 +143,7 @@ define('io.ox/core/boot/util', [], function () {
             $('#io-ox-login-form')
                 // visual response (shake sucks on touch devices)
                 .css('opacity', '')
-                .find('input').removeAttr('disabled');
+                .find('input').prop('disabled', false);
             $('#io-ox-login-blocker').hide();
             //$('#io-ox-login-feedback').idle();
         },
@@ -131,7 +152,7 @@ define('io.ox/core/boot/util', [], function () {
             // be busy
             $('#io-ox-login-form')
                 .css('opacity', 0.5)
-                .find('input').attr('disabled', 'disabled');
+                .find('input').prop('disabled', true);
             $('#io-ox-login-blocker').show();
             //$('#io-ox-login-feedback').busy().empty();
         }
@@ -143,7 +164,8 @@ define('io.ox/core/boot/util', [], function () {
     //
 
     ox.relogin = function () {
-        exports.gotoSignin('login_type=useForm');
+        var Stage = require('io.ox/core/extPatterns/stage');
+        Stage.run('io.ox/core/boot/login', {}, { methodName: 'relogin' });
     };
 
     ox.on('relogin:required', ox.relogin);
