@@ -53,10 +53,12 @@ define('io.ox/core/extPatterns/links', [
                     href: '#',
                     'data-action': self.id,
                     'draggable': options.draggable || false,
-                    'role': 'menuitem',
+                    'role': self.role || 'menuitem',
                     'data-section': self.section || 'default',
+                    'data-section-description': self.sectionDescription,
                     'data-prio': _.device('smartphone') ? (self.mobile || 'none') : (self.prio || 'lo'),
-                    'data-ref': self.ref
+                    'data-ref': self.ref,
+                    'tabindex': -1
                 };
                 var a = preRendered.a.clone()
                     .addClass(self.cssClasses || 'io-ox-action-link');
@@ -68,7 +70,7 @@ define('io.ox/core/extPatterns/links', [
                 // add icon or text? (icons are prefered over labels)
                 if (icons && prio === 'hi') {
                     // add icon and title attribut
-                    a.append(preRendered.i.clone().addClass(self.icon));
+                    a.append(preRendered.i.clone().addClass(self.icon).attr('aria-hidden', 'true'));
                     attr.title = self.title || self.label || '';
                 } else if (self.label) {
                     // add text. add title unless it matches content
@@ -99,8 +101,8 @@ define('io.ox/core/extPatterns/links', [
             };
 
         this.draw = this.draw || function (baton) {
-
-            baton = ext.Baton.ensure(baton);
+            // clone was introduced as a fix for b54827
+            baton = _.clone(ext.Baton.ensure(baton));
             var link = drawDefault(baton);
 
             this.append(
@@ -119,7 +121,6 @@ define('io.ox/core/extPatterns/links', [
                     .tooltip('destroy')
                     .addClass('disabled')
                     .attr('aria-disabled', true)
-                    .removeAttr('href')
                 );
                 // call customize? (call after append; must be self - not this)
                 if (self.customize) self.customize.call(link, baton);
@@ -261,10 +262,13 @@ define('io.ox/core/extPatterns/links', [
                         count++;
                     }
                 });
+                nav.find('li > a').attr('tabindex', -1);
+                nav.find('li > a:first').attr('tabindex', 0);
                 // empty?
                 if (count === 0) nav.addClass('empty').removeAttr('role');
             })
-            .then(function () {
+            // pipe vs then
+            .pipe(function () {
                 return nav;
             });
     };
@@ -357,13 +361,15 @@ define('io.ox/core/extPatterns/links', [
     function injectDividers(node) {
         // loop over all items and visually group by "section"
         var currentSection = '',
-            $li = $('<li class="divider" role="separator">');
+            $li = $('<li class="divider" role="separator">'),
+            $section = $('<li class="dropdown-header">');
         node.children('li').each(function () {
-            var node = $(this), section = node.children('a').attr('data-section');
+            var node = $(this), link = node.children('a'), section = link.attr('data-section'), description = link.attr('data-section-description');
             // add divider?
             if (section === undefined) return;
             if (currentSection !== '' && currentSection !== section) {
                 node.before($li.clone());
+                if (description) node.before($section.clone().text(description));
             }
             currentSection = section;
         });
@@ -401,12 +407,13 @@ define('io.ox/core/extPatterns/links', [
             if (isSmartphone) all.children().filter('[data-prio="none"]').parent().remove();
 
             if (lo.length > 1 && !allDisabled && (!multiple || extension.dropdown === true) && extension.dropdown !== false) {
-                var dd = $('<a href="#" class="io-ox-action-link" draggable="false" role="button" data-toggle="dropdown" data-action="more" aria-haspopup="true">')
-                            .attr('data-original-title', isSmartphone ? gt('Actions') : gt('More actions')).append(
-                                isSmartphone && !extension.compactDropdown ?
-                                    $().add($.txt(gt('Actions'))).add($('<i aria-hidden="true" class="fa fa-caret-down">')) :
-                                    $('<span class="sr-only">').text(gt('Actions')).add($('<i aria-hidden="true" class="fa fa-bars">'))
-                        ),
+                var dd = $('<a href="#" class="io-ox-action-link" draggable="false" role="button" data-toggle="dropdown" data-action="more" aria-haspopup="true" tabindex="-1">')
+                    .attr('data-original-title', isSmartphone ? gt('Actions') : gt('More actions'))
+                    .append(
+                        isSmartphone && !extension.compactDropdown ?
+                            $().add($.txt(gt('Actions'))).add($('<i class="fa fa-caret-down" aria-hidden="true">')) :
+                            $('<span class="sr-only">').text(gt('Actions')).add($('<i class="fa fa-bars" aria-hidden="true">'))
+                    ),
                     node = $('<ul class="dropdown-menu pull-right" role="menu">')
                         .attr('aria-label', isSmartphone ? gt('Actions') : gt('More'))
                         .append(lo);
@@ -522,6 +529,8 @@ define('io.ox/core/extPatterns/links', [
             // remove items with 'none' prio
             if (_.device('smartphone')) baton.$el.find('[data-prio="none"]').closest('li').remove();
             baton.$el.parent().trigger('ready');
+            // make sure the closer is at the last position
+            if (closer) baton.$el.append(closer);
             delete baton.$el;
         });
     };
@@ -585,7 +594,7 @@ define('io.ox/core/extPatterns/links', [
         options = options || {};
         baton.$el = $('<ul class="dropdown-menu" role="menu">');
         wrap = !!_.defaultValue(options.wrap, true);
-        drawLinks(options || {}, new Collection(baton.data), null, baton, [], wrap).done(function () {
+        drawLinks(options, new Collection(baton.data), null, baton, [], wrap).done(function () {
             // if dropdown is emtpy and we have an empty-callback, execute it(some async drawing methods use this)
             if (!baton.$el) return;
             if (options.emptyCallback && baton.$el.hasClass('empty')) options.emptyCallback();
@@ -688,14 +697,14 @@ define('io.ox/core/extPatterns/links', [
                                 a.tooltip({ trigger: 'hover' });
                             }
                         } else {
-                            a.addClass('disabled').attr({ 'aria-disabled': true }).on('click', preventDefault);
+                            a.addClass('disabled').attr('aria-disabled', true).on('click', preventDefault);
                         }
                     }
                 });
         }
 
         function icon() {
-            return $('<i class="fa fa-magic">');
+            return $('<i class="fa fa-magic" aria-hidden="true">');
         }
 
         return function ActionGroup(id, extension) {
