@@ -72,7 +72,7 @@ define('io.ox/core/folder/actions/imap-subscription', [
         }
 
         picker({
-
+            async: true,
             all: true,
             addClass: 'zero-padding subscribe-imap-folder',
             button: gt('Save'),
@@ -80,9 +80,10 @@ define('io.ox/core/folder/actions/imap-subscription', [
             height: 300,
             module: 'mail',
             selection: false,
-            title: gt('Subscribe IMAP folders'),
+            title: gt('Subscribe to IMAP folders'),
+            help: 'ox.appsuite.user.sect.email.teamwork.subscribe.html',
 
-            always: function () {
+            always: function (dialog) {
 
                 http.pause();
 
@@ -117,6 +118,7 @@ define('io.ox/core/folder/actions/imap-subscription', [
                 http.resume().done(function () {
                     // refresh all virtual folders to be safe
                     api.virtual.refresh();
+                    dialog.close();
                 });
             },
 
