@@ -16,9 +16,8 @@ define('io.ox/core/folder/actions/move', [
     'io.ox/core/folder/picker',
     'io.ox/core/notifications',
     'gettext!io.ox/core',
-    'io.ox/mail/api',
-    'io.ox/core/api/account'
-], function (api, picker, notifications, gt, mailAPI, accountAPI) {
+    'io.ox/mail/api'
+], function (api, picker, notifications, gt, mailAPI) {
 
     'use strict';
 
@@ -26,6 +25,28 @@ define('io.ox/core/folder/actions/move', [
         'virtual/myfolders': api.altnamespace ? 'default0' : 'default0' + mailAPI.separator + 'INBOX'
     };
 
+    function canMoveFolder(target, input) {
+        var canMoveState = 'ok';
+
+        _.all(input, function (inputItem) {
+            var currentFolderId = target;
+
+            // do not check files
+            if (inputItem.folder_id !== 'folder') return true;
+            // check if folder is moved into itself
+            if (currentFolderId === inputItem.id) { canMoveState = 'error:self'; return false; }
+
+            // check if folder is moved into own subfolder
+            while (currentFolderId) {
+                if (String(currentFolderId) === '1') return true;
+                if (currentFolderId === inputItem.id) { canMoveState = 'error:subfld'; return false; }
+                // move on level up in the folder tree
+                currentFolderId = api.pool.getModel(currentFolderId).get('folder_id');
+            }
+        });
+        return canMoveState;
+    }
+
     return {
 
         //
@@ -70,11 +91,23 @@ define('io.ox/core/folder/actions/move', [
                     return notifications.yell('error', gt('You cannot move items to virtual folders'));
                 }
 
-                // final check for write privileges
-                if (!api.pool.getModel(target).can('create')) {
+                // final check for write privileges; if it's only folders the server check the privilegs.
+                if (!onlyFolder && !api.pool.getModel(target).can('create')) {
                     return notifications.yell('error', gt('You cannot move items to this folder'));
                 }
 
+                if (type === 'move' && options.module === 'infostore') {
+                    switch (canMoveFolder(target, input)) {
+                        case 'ok':
+                            break;
+                        case 'error:self':
+                            return notifications.yell('error', gt('A folder cannot be moved into itself'));
+                        case 'error:subfld':
+                            return notifications.yell('error', gt('A folder cannot be moved to one of its subfolders'));
+                        // no default
+                    }
+                }
+
                 // support for move, moveAll, and copy
                 options.api[type](input, target, options.all).then(
                     function (response) {
@@ -105,11 +138,6 @@ define('io.ox/core/folder/actions/move', [
                 );
             }
 
-            if (options.target) {
-                if (current !== options.target) commit(options.target);
-                return;
-            }
-
             if (type !== 'moveAll') {
                 onlyFolder = true;
                 _(options.list).each(function (item) {
@@ -117,8 +145,14 @@ define('io.ox/core/folder/actions/move', [
                     onlyFolder = item.folder_id === 'folder';
                 });
             }
-            picker({
 
+            if (options.target) {
+                if (current !== options.target) commit(options.target);
+                return;
+            }
+
+            picker({
+                async: true,
                 button: options.button,
                 filter: options.filter,
                 flat: !!options.flat,
@@ -133,8 +167,9 @@ define('io.ox/core/folder/actions/move', [
                 initialize: options.pickerInit || $.noop,
                 close: options.pickerClose || $.noop,
 
-                done: function (id) {
+                done: function (id, dialog) {
                     if (type === 'copy' || id !== current) commit(id);
+                    if (dialog) dialog.close();
                 },
 
                 disable: function (data, options) {
@@ -155,11 +190,12 @@ define('io.ox/core/folder/actions/move', [
             var model = api.pool.getModel(id),
                 module = model.get('module'),
                 flat = api.isFlat(module),
-                context = accountAPI.isDSC(id) ? 'dsc' : 'popup';
+                context = 'popup';
             picker({
                 async: true,
                 addClass: 'zero-padding',
                 done: function (target, dialog, tree) {
+                    dialog.busy(true);
                     if (!!virtualMapping[target]) target = virtualMapping[target];
                     function preselect() {
                         tree.preselect(target);
@@ -186,7 +222,6 @@ define('io.ox/core/folder/actions/move', [
                 root: module === 'infostore' ? '9' : '1',
                 title: gt('Move folder') + ': ' + model.get('title'),
                 context: context,
-                folderBase: accountAPI.getDSCRootFolderForId(accountAPI.getIdForDSCFolder(id)) + mailAPI.separator + 'INBOX',
                 persistent: 'folderpopup',
                 settings: settings
             });
