@@ -36,8 +36,8 @@ define('io.ox/core/folder/actions/remove', [
 
         var model = api.pool.getModel(id),
             dialog = new dialogs.ModalDialog(),
-            deleteNotice = gt('Do you really want to delete folder "%s"?', model.get('title')),
-            shareNotice = gt('This folder is shared with others. It won\'t be available for them any more.');
+            deleteNotice = model.get('module') === 'calendar' ? gt('Do you really want to delete calendar "%s"?', model.get('title')) : gt('Do you really want to delete folder "%s"?', model.get('title')),
+            shareNotice = model.get('module') === 'calendar' ? gt('This calendar is shared with others. It won\'t be available for them any more.') : gt('This folder is shared with others. It won\'t be available for them any more.');
 
         function isShared() {
             if (model.get('permissions').length > 1) return true;
