@@ -11,14 +11,19 @@
  * @author Kai Ahrens <kai.ahrens@open-xchange.com>
  */
 
+/* global Promise */
+
 define('io.ox/core/pdf/pdfdocument', [
     'io.ox/core/pdf/pdfview',
+    'io.ox/core/viewer/util',
     'pdfjs-dist/build/pdf',
     'settings!io.ox/core'
-], function (PDFView, PDFJSLib, Settings) {
+], function (PDFView, Util, PDFJSLib, Settings) {
 
     'use strict';
 
+    var PDFJS = PDFJSLib.PDFJS;
+
     // class PDFDocument =======================================================
 
     /**
@@ -34,43 +39,55 @@ define('io.ox/core/pdf/pdfdocument', [
      */
     function PDFDocument(pdfConverterURL) {
 
-        var self = this;
+        var self = this,
 
-        var loadDef = $.Deferred();
+            loadDef = $.Deferred(),
 
-        // the resulting PDF.js document after loading
-        var pdfjsDocument = null;
+            // the resulting PDF.js document after loading
+            pdfjsDocument = null,
 
-        // the total page count of the document {Number}
-        var pageCount = 0;
+            // the total page count of the document {Number}
+            pageCount = 0,
 
-        // the size of the first page is treated as default page size {width, height}
-        var defaultPageSize = null;
+            // the size of the first page is treated as default page size {width, height}
+            defaultPageSize = null,
 
-        // the size of the first page is treated as default page size {[{width, height}, ...]}
-        var pageSizes = [];
+            // the size of the first page is treated as default page size {[{width, height}, ...]}
+            pageSizes = [],
 
-        // whether to enable range requests support, if not present the default is true
-        var enableRangeRequests = (Settings.get('pdf/enableRangeRequests') !== false);
+            // whether to enable range requests support
+            enableRangeRequests = Settings.get('pdf/enableRangeRequests');
 
-        // Document initialization / loading parameters object
-        var params = {
-            // The URL of the PDF.
-            url: pdfConverterURL,
+        /**
+         * Range request support. If the server supports range requests the PDF will be fetched in chunks.
+         */
+        PDFJS.disableRange = !enableRangeRequests;
 
-            // Range request support. If the server supports range requests the PDF will be fetched in chunks.
-            disableRange: !enableRangeRequests,
+        /**
+         * Streaming of PDF file data.
+         */
+        PDFJS.disableStream = !enableRangeRequests;
 
-            // Streaming of PDF file data.
-            disableStream: !enableRangeRequests,
+        /**
+         * Pre-fetching of PDF file data. PDF.js will automatically keep fetching more data even if it isn't needed to display the current page.
+         * NOTE: It is also necessary to disable streaming, see above, in order for disabling of pre-fetching to work correctly.
+         */
+        PDFJS.disableAutoFetch = !enableRangeRequests;
 
-            // Pre-fetching of PDF file data. PDF.js will automatically keep fetching more data even if it isn't needed to display the current page.
-            // NOTE: It is also necessary to disable streaming, see above, in order for disabling of pre-fetching to work correctly.
-            disableAutoFetch: !enableRangeRequests,
+        /**
+         * set verbosity level for PDF.js to errors only
+         */
+        PDFJS.verbosity = PDFJS.VERBOSITY_LEVELS.errors;
 
-            // set verbosity level for PDF.js to errors only
-            verbosity: PDFJSLib.VerbosityLevel.ERRORS
-        };
+        /**
+         * Open external links in a new window
+         */
+        PDFJS.externalLinkTarget = PDFJS.LinkTarget.BLANK;
+
+        /**
+         * Path for image resources, mainly for annotation icons. Include trailing slash.
+         */
+        PDFJS.imageResourcesPath = ox.base + '/apps/pdfjs-dist/web/images/';
 
         // ---------------------------------------------------------------------
 
@@ -79,7 +96,7 @@ define('io.ox/core/pdf/pdfdocument', [
 
             if (_.isNumber(pageNumber) && (pageNumber > 0) && (pageNumber <= pageCount)) {
                 self.getPDFJSPage(pageNumber).then(function (pdfjsPage) {
-                    var viewport = pdfjsPage.getViewport({ scale: PDFView.getAdjustedZoom(1.0) });
+                    var viewport = pdfjsPage.getViewport(PDFView.getAdjustedZoom(1.0));
                     return def.resolve(PDFView.getNormalizedSize({ width: viewport.width, height: viewport.height }));
                 });
             }
@@ -188,38 +205,27 @@ define('io.ox/core/pdf/pdfdocument', [
 
         // ---------------------------------------------------------------------
 
-        /**
-         * Convert document to PDF
-         *
-         * @param {Object} params
-         *  @param {String} params.url
-         *   The URL of the PDF.
-         *
-         *  @param {Boolean} params.disableRange
-         *   Disable range request support. When enabled, and if the server supports
-         *   partial content requests, then the PDF will be fetched in chunks.
-         *
-         *  @param {Boolean} params.disableStream
-         *   Disable streaming of PDF file data.
-         *
-         *  @param {Boolean} params.disableAutoFetch
-         *   Disable pre-fetching of PDF file data. When range requests are enabled
-         *   PDF.js will automatically keep fetching more data even if it isn't
-         *   needed to display the current page.
-         *   NOTE: It is also necessary to disable streaming, see above,
-         *   in order for disabling of pre-fetching to work correctly.
-         *
-         *  @param {Number} params.verbosity
-         *   Controls the logging level; the constants from {VerbosityLevel} should be used.
-         *
-         *  @param {String} params.cMapUrl
-         *   The URL to the predefined Adobe CMaps. Include trailing slash.
-         *
-         *  @param {Boolean} params.cMapPacked
-         *   Specifies if the Adobe CMaps are binary packed.
-         */
-        PDFJSLib.getDocument(params).promise.then(function (document) {
+        // convert document to PDF
+        PDFJS.getDocument(pdfConverterURL).promise.then(function (document) {
             var error = true;
+            // the original getPage() function
+            var origGetPageFunction = document && document.transport && document.transport.getPage;
+
+            Util.logPerformanceTimer('PDFDocument:PDFJs_getDocument_then_handler'); // after first long running process
+
+            // wrap around original getPage() function
+            // to fix an exception which occurs when rapidly switching documents
+            // and causes PDFjs to stop working and to render white pages only
+            if (origGetPageFunction) {
+                document.transport.getPage = function WorkerTransport_getPage(pageNumber, capability) {
+                    // return rejected promise if no message handler is present
+                    if (!document.transport.messageHandler) {
+                        return Promise.reject();
+                    }
+                    // call original getPage() function
+                    return origGetPageFunction.call(this, pageNumber, capability);
+                };
+            }
 
             if (document) {
                 pdfjsDocument = document;
@@ -247,12 +253,15 @@ define('io.ox/core/pdf/pdfdocument', [
             // a given PDF file and set the password error response accordingly
             var encTestPDFConverterURL = pdfConverterURL + '&enctest=pdf';
 
-            $.get(encTestPDFConverterURL).always(function (data) {
-                loadDef.resolve(
-                  (_.isObject(data) && _.isString(data.responseText)) ?
-                      $.parseJSON(data.responseText) :
-                          { cause: 'filterError' });
+            $.ajax({
+                url: encTestPDFConverterURL,
+                dataType: 'json'
 
+            }).always(function (data) {
+                loadDef.resolve(
+                    (_.isObject(data) && _.isString(data.cause)) ?
+                        data :
+                        { cause: 'filterError' });
             });
         });
 
