@@ -20,6 +20,7 @@ define('io.ox/core/pdf/pdftextlayerbuilder', [
     'pdfjs-dist/build/pdf',
     'pdfjs-dist/build/pdf.worker'
 ], function (Polyfill, CustomStyle, PDFJSLib) {
+
     'use strict';
 
     /*
@@ -208,6 +209,7 @@ define('io.ox/core/pdf/pdftextlayerbuilder', [
     // --------------------------
     // - PDFTextLayerBuilder.js -
     // --------------------------
+    var PDFJS = PDFJSLib.PDFJS;
 
     var MAX_TEXT_DIVS_TO_RENDER = 100000;
 
@@ -348,8 +350,7 @@ define('io.ox/core/pdf/pdftextlayerbuilder', [
                 }
             },
 
-            appendText: function TextLayerBuilder_appendText(geom,
-                    styles) {
+            appendText: function TextLayerBuilder_appendText(geom, styles) {
                 var style = styles[geom.fontName];
                 var textDiv = document.createElement('div');
                 this.textDivs.push(textDiv);
@@ -357,7 +358,7 @@ define('io.ox/core/pdf/pdftextlayerbuilder', [
                     textDiv.dataset.isWhitespace = true;
                     return;
                 }
-                var tx = PDFJSLib.Util.transform(this.viewport.transform, geom.transform);
+                var tx = PDFJS.Util.transform(this.viewport.transform, geom.transform);
                 var angle = Math.atan2(tx[1], tx[0]);
                 if (style.vertical) {
                     angle += Math.PI / 2;
@@ -390,7 +391,7 @@ define('io.ox/core/pdf/pdftextlayerbuilder', [
                 // when e.g. the Font Inspector is off but the Stepper
                 // is on, but it's
                 // not worth the effort to do a more accurate test.
-                if (PDFJSLib.pdfBug) {
+                if (PDFJS.pdfBug) {
                     textDiv.dataset.fontName = geom.fontName;
                 }
                 // Storing into dataset will convert number into string.
@@ -421,14 +422,13 @@ define('io.ox/core/pdf/pdftextlayerbuilder', [
                 this.divContentDone = true;
             },
 
-            convertMatches: function TextLayerBuilder_convertMatches(
-                    matches) {
+            convertMatches: function TextLayerBuilder_convertMatches(matches) {
                 var i = 0;
                 var iIndex = 0;
                 var bidiTexts = this.textContent.items;
                 var end = bidiTexts.length - 1;
                 var queryLen = (this.findController === null ? 0
-                        : this.findController.state.query.length);
+                    : this.findController.state.query.length);
                 var ret = [];
 
                 for (var m = 0, len = matches.length; m < len; m++) {
@@ -473,8 +473,7 @@ define('io.ox/core/pdf/pdftextlayerbuilder', [
                 return ret;
             },
 
-            renderMatches: function TextLayerBuilder_renderMatches(
-                    matches) {
+            renderMatches: function TextLayerBuilder_renderMatches(matches) {
                 // Early exit if there is nothing to render.
                 if (matches.length === 0) {
                     return;
@@ -485,11 +484,11 @@ define('io.ox/core/pdf/pdftextlayerbuilder', [
                 var prevEnd = null;
                 var pageIdx = this.pageIdx;
                 var isSelectedPage = (this.findController === null ? false
-                        : (pageIdx === this.findController.selected.pageIdx));
+                    : (pageIdx === this.findController.selected.pageIdx));
                 var selectedMatchIdx = (this.findController === null ? -1
-                        : this.findController.selected.matchIdx);
+                    : this.findController.selected.matchIdx);
                 var highlightAll = (this.findController === null ? false
-                        : this.findController.state.highlightAll);
+                    : this.findController.state.highlightAll);
                 var infinity = {
                     divIdx: -1,
                     offset: undefined
@@ -501,11 +500,10 @@ define('io.ox/core/pdf/pdftextlayerbuilder', [
                     appendTextToDiv(divIdx, 0, begin.offset, className);
                 }
 
-                function appendTextToDiv(divIdx, fromOffset, toOffset,
-                        className) {
+                function appendTextToDiv(divIdx, fromOffset, toOffset, className) {
                     var div = textDivs[divIdx];
                     var content = bidiTexts[divIdx].str.substring(
-                            fromOffset, toOffset);
+                        fromOffset, toOffset);
                     var node = document.createTextNode(content);
                     if (className) {
                         var span = document.createElement('span');
@@ -533,12 +531,12 @@ define('io.ox/core/pdf/pdftextlayerbuilder', [
                     var end = match.end;
                     var isSelected = (isSelectedPage && i === selectedMatchIdx);
                     var highlightSuffix = (isSelected ? ' selected'
-                            : '');
+                        : '');
 
                     if (this.findController) {
                         this.findController.updateMatchPosition(
-                                pageIdx, i, textDivs, begin.divIdx,
-                                end.divIdx);
+                            pageIdx, i, textDivs, begin.divIdx,
+                            end.divIdx);
                     }
 
                     // Match inside new div.
@@ -547,22 +545,22 @@ define('io.ox/core/pdf/pdftextlayerbuilder', [
                         // text at the end.
                         if (prevEnd !== null) {
                             appendTextToDiv(prevEnd.divIdx,
-                                    prevEnd.offset, infinity.offset);
+                                prevEnd.offset, infinity.offset);
                         }
                         // Clear the divs and set the content until the
                         // starting point.
                         beginText(begin);
                     } else {
                         appendTextToDiv(prevEnd.divIdx, prevEnd.offset,
-                                begin.offset);
+                            begin.offset);
                     }
 
                     if (begin.divIdx === end.divIdx) {
                         appendTextToDiv(begin.divIdx, begin.offset,
-                                end.offset, 'highlight' + highlightSuffix);
+                            end.offset, 'highlight' + highlightSuffix);
                     } else {
                         appendTextToDiv(begin.divIdx, begin.offset,
-                                infinity.offset, 'highlight begin' + highlightSuffix);
+                            infinity.offset, 'highlight begin' + highlightSuffix);
                         for (var n0 = begin.divIdx + 1, n1 = end.divIdx; n0 < n1; n0++) {
                             textDivs[n0].className = 'highlight middle' + highlightSuffix;
                         }
@@ -607,8 +605,7 @@ define('io.ox/core/pdf/pdftextlayerbuilder', [
                 // Convert the matches on the page controller into the
                 // match format
                 // used for the textLayer.
-                this.matches = this.convertMatches(this.findController === null ? []
-                                : (this.findController.pageMatches[this.pageIdx] || []));
+                this.matches = this.convertMatches(this.findController.pageMatches[this.pageIdx] || []);
                 this.renderMatches(this.matches);
             }
         };
