@@ -30,7 +30,7 @@ define('io.ox/core/print', [
         callbacks = {};
 
     function escapeTitle(str) {
-        return (str || '').replace(/[#%&§\/$*!`´'"=:@+\^\\.+?{}|]/g, '_');
+        return (str || '').replace(/[#%&§/$*!`´'"=:@+^\\.+?{}|]/g, '_');
     }
 
     function addCallback(options, it) {
@@ -45,7 +45,7 @@ define('io.ox/core/print', [
                 // edge has problems if the content is not trimmed and there is more than one node. So trim and put a wrapper around it.
                 $(document.body).html('<div class="print-wrapper">' + $.trim(_.template(template)(it)) + '</div>');
                 //hint: in case title contains a '.' chrome will cut off at this char when suggesting a filename
-                document.title = escapeTitle(ox.serverConfig.pageTitle) + escapeTitle(title.length ? ' ' + title : '') + ' ' + gt('Printout');
+                document.title = escapeTitle(ox.serverConfig.pageTitle || '') + escapeTitle(title.length ? ' ' + title : '') + ' ' + gt('Printout');
             } catch (e) {
                 console.error(e);
             }
