@@ -382,11 +382,12 @@ define('io.ox/core/tk/dialogs', [
         };
 
         this.addCheckbox = function (label, action, status) {
+            var guid = _.uniqueId('form-control-label-');
             nodes.footer.prepend(
                 $('<div class="checkbox">').append(
                     $('<div class="controls">'),
-                    $('<label>').text(label).prepend(
-                        $('<input type="checkbox">').attr({ 'data-action': action, 'checked': status })
+                    $('<label>').attr('for', guid).text(label).prepend(
+                        $('<input type="checkbox">').attr({ 'id': guid, 'data-action': action }).prop('checked', status)
                     )
                 )
             );
@@ -618,8 +619,8 @@ define('io.ox/core/tk/dialogs', [
         }
 
         if (popups.length === 0) return;
-        //check if we are inside a modal dialog or pressed a button in the footer (footer buttons usually close the dialog so check with .io-ox-dialog-popup would fail)
-        if (target.closest('.io-ox-dialog-popup, .io-ox-dialog-underlay, .modal-footer').length > 0) return;
+        //check if we are inside a floating-window, amodal dialog or pressed a button in the footer (footer buttons usually close the dialog so check with .io-ox-dialog-popup would fail)
+        if (target.closest('.io-ox-dialog-popup, .io-ox-dialog-underlay, .modal-footer, .floating-window').length > 0) return;
         // see bug 41822
         if (target.closest('.io-ox-dialog-sidepopup-toggle').length > 0) return;
 
@@ -795,7 +796,7 @@ define('io.ox/core/tk/dialogs', [
             self.nodes = {
                 closest: target || my.parents('.io-ox-sidepopup-pane, .window-content, .window-container-center, .io-ox-dialog-popup, .notifications-overlay, body').first(),
                 click: my.parents('.io-ox-sidepopup-pane, .io-ox-dialog-popup, .notifications-overlay, body').first(),
-                target: target || my.parents('.simple-window, .window-container-center, .notifications-overlay, body').first(),
+                target: target || my.parents('.simple-window, .window-container-center, .notifications-overlay, #io-ox-notifications-sidepopup, body').first(),
                 simple: my.closest('.simple-window')
             };
 
