@@ -231,10 +231,10 @@ define('io.ox/core/tk/doc-converter-utils', [
      */
     Utils.getProprietaryParams = function (model) {
 
-        var // the original mail and PIM attachment model data
-            originalModel = model.get('origData'),
-            // the PIM module id
-            moduleId = model.get('module');
+        // the original mail and PIM attachment model data
+        var originalModel = model.get('origData');
+        // the PIM module id
+        var moduleId = model.get('module');
 
         if (model.isMailAttachment()) {
             return {
@@ -253,6 +253,7 @@ define('io.ox/core/tk/doc-converter-utils', [
             };
 
         } else if (model.isEncrypted()) {
+            // the Guard parameters
             var file_options = model.get('file_options');
             var file_options_params = file_options ? file_options.params : null;
             return {
