@@ -13,8 +13,8 @@
 
 define('io.ox/core/tk/mobiscroll', [
     'gettext!io.ox/core',
-    'static/3rd.party/mobiscroll/mobiscroll.js',
-    'css!3rd.party/mobiscroll/mobiscroll.css'
+    'static/3rd.party/mobiscroll.js',
+    'css!3rd.party/mobiscroll.css'
 ], function (gt) {
 
     'use strict';
@@ -26,12 +26,12 @@ define('io.ox/core/tk/mobiscroll', [
         settings = {
             cancelText: gt('Cancel'),
             clearText: gt('Clear'),
-            dayText: gt('Days'),
+            dayText: gt('Day'),
             hourText: gt('Hours'),
             minuteText: gt('Minutes'),
-            monthText: gt('Months'),
+            monthText: gt('Month'),
             setText: gt('Ok'),
-            yearText: gt('Years'),
+            yearText: gt('Year'),
             display: 'bottom',
             preset: 'date',
             theme: 'ios',
