@@ -12,8 +12,9 @@
  */
 
 define('io.ox/core/tk/text-editor', [
-    'io.ox/core/tk/textproc'
-], function (textproc) {
+    'io.ox/core/tk/textproc',
+    'settings!io.ox/mail'
+], function (textproc, mailSettings) {
 
     'use strict';
 
@@ -165,13 +166,16 @@ define('io.ox/core/tk/text-editor', [
         // hint: does not detects the cite block
         this.getContentParts = function () {
             var content = this.getContent(),
-                index = content.indexOf('\n> ');
+                isForwardUnquoted = opt.view.model.get('mode') === 'forward' && mailSettings.get('forwardunquoted', false),
+                index = content.indexOf(isForwardUnquoted ? '----' : '\n> ');
+            // make sure that the quote part does not start with \n
+            if (index >= 0) index++;
             // special case: initial reply/forward
             if (content.substring(0, 2) === '> ') index = 0;
             if (index < 0) return { content: content };
             return {
                 // content without trailing whitespace
-                content: content.substring(0, index).replace(/\s+$/g, ''),
+                content: content.substring(0, index - 1).replace(/\s+$/g, ''),
                 quote: content.substring(index),
                 cite: undefined
             };
@@ -184,6 +188,13 @@ define('io.ox/core/tk/text-editor', [
             this.setContentParts(data, 'above');
         };
 
+        this.insertPostCite = function (str) {
+            var data = this.getContentParts();
+            // add cite
+            data.cite = str;
+            this.setContentParts(data, 'below');
+        };
+
         this.replaceParagraph = function (str, rep) {
             var content = this.getContent(), top,
                 length = content.length,
@@ -203,7 +214,7 @@ define('io.ox/core/tk/text-editor', [
         this.show = function () {
             function resizeEditor() {
                 var toolbarHeight = (textarea.closest('.io-ox-mail-compose-window').hasClass('header-top') ? 0 : $('[data-extension-id="header"]').parent().outerHeight());
-                textarea.css('minHeight', Math.max(300, ($(window).height() - textarea.offset().top - $('#io-ox-topbar').height() - toolbarHeight)));
+                textarea.css('minHeight', Math.max(300, ($(window).height() - textarea.offset().top - toolbarHeight)));
             }
             textarea.prop('disabled', false).show();
 
