@@ -13,8 +13,11 @@
  */
 
 define('io.ox/core/viewer/main', [
-    'gettext!io.ox/core'
-], function (gt) {
+    'io.ox/core/extensions',
+    'io.ox/core/capabilities',
+    'gettext!io.ox/core',
+    'io.ox/core/viewer/util'
+], function (ext, Capabilities, gt, Util) {
 
     'use strict';
 
@@ -47,12 +50,13 @@ define('io.ox/core/viewer/main', [
          */
         this.launch = function (data) {
 
+            Util.startPerformanceTimer();
+
             if (!data) return console.error('Core.Viewer.main.launch(): no data supplied');
-            if (!_.isArray(data.files) || data.files.length === 0) return console.error('Core.Viewer.main.launch(): no files to preview.');
+            if (!hasFiles() && !hasFolder()) return console.error('Core.Viewer.main.launch(): no files to preview.');
 
             var self = this,
                 el = $('<div class="io-ox-viewer abs">'),
-                fileList = [].concat(data.files),
                 container = data.container || $('#io-ox-core'),
                 printOverlay = $('<div class="viewer-print-overlay">').append(
                     $('<div class="print-content">').append(
@@ -70,55 +74,102 @@ define('io.ox/core/viewer/main', [
                 $this.data('ox-restore-aria-hidden', el.attr('aria-hidden'));
             }).attr('aria-hidden', true);
 
+            function hasFolder() {
+                // Bug 50839 - Viewer opens arbitrary document -> don't expand folder for sharing
+                return (!_.isEmpty(data.folder) && (data.folder !== '10'));
+            }
+
+            function hasFiles() {
+                return (_.isArray(data.files) && (data.files.length > 0));
+            }
+
             function cont() {
+
+                Util.logPerformanceTimer('launchContStart');
+
+                // whether the files to display are shared
+                function isSharing() {
+                    // check if the user is guest or anonymous guest
+                    if (Capabilities.has('guest')) { return true; }
+                    // check for sharing folder
+                    if (data.folder === '10') { return true; }
+                    if (self.fileCollection.first() && self.fileCollection.first().get('folder_id') === '10') { return true; }
+
+                    return false;
+                }
+
                 // resolve dependencies now for an instant response
                 require(['io.ox/core/viewer/backbone', 'io.ox/core/viewer/views/mainview'], function (backbone, MainView) {
                     // create file collection and populate it with file models
                     self.fileCollection = new backbone.Collection();
-                    self.fileCollection.reset(fileList, { parse: true });
+                    self.fileCollection.reset(data.fileList, { parse: true });
                     // set the index of the selected file (Drive only)
                     if (data.selection) {
                         self.fileCollection.setStartIndex(data.selection);
+                    } else if (hasFolder() && hasFiles()) {
+                        // workaround to set correct start file for deep linking, #58378
+                        self.fileCollection.setStartIndex(data.files[0]);
                     }
                     // create main view and append main view to core
-                    self.mainView = new MainView({ collection: self.fileCollection, el: el, app: data.app, standalone: data.standalone, opt: data.opt || {}, openedBy: data.openedBy });
+                    self.mainView = new MainView({ collection: self.fileCollection, el: el, app: data.app, standalone: data.standalone, opt: data.opt || {}, openedBy: data.openedBy, isSharing: isSharing() });
 
-                    self.mainView.on('dispose', function () {
-                        siblings.removeAttr('aria-hidden').each(function () {
-                            var el = $(this);
-                            if (el.data('ox-restore-aria-hidden')) el.attr('aria-hidden', el.data('ox-restore-aria-hidden'));
-                            el.removeData('ox-restore-aria-hidden');
-                        });
-                        // remove id form URL hash (see bug 43410)
-                        // use-case: viewer was opened via deep-link; a page-reload might surprise the user
-                        // but don't remove the id from an OX Presenter URL
-                        if (_.url.hash('app') !== 'io.ox/office/presenter') {
-                            _.url.hash('id', null);
-                        }
+                    self.mainView.on('dispose', close);
 
-                        if (data.restoreFocus && _.isFunction(data.restoreFocus.focus)) {
-                            data.restoreFocus.focus();
-                        }
-                    });
                 });
             }
 
-            // Bug 50839 - Viewer opens arbitrary document -> don't expand folder for sharing
-            if (data.folder && data.folder !== '10') {
-                require(['io.ox/files/api'], function (api) {
-                    api.getAll(data.folder).then(function success(files) {
-                        data.selection = data.files[0];
+            // Cleanup, remove hidden attributes
+            function close() {
+
+                Util.savePerformanceTimer(data);
+
+                siblings.removeAttr('aria-hidden').each(function () {
+                    var el = $(this);
+                    if (el.data('ox-restore-aria-hidden')) el.attr('aria-hidden', el.data('ox-restore-aria-hidden'));
+                    el.removeData('ox-restore-aria-hidden');
+                });
+                // remove id form URL hash (see bug 43410)
+                // use-case: viewer was opened via deep-link; a page-reload might surprise the user
+                // but don't remove the id from an OX Presenter URL
+                if (_.url.hash('app') !== 'io.ox/office/presenter') {
+                    _.url.hash('id', null);
+                }
+
+                if (data.restoreFocus && _.isFunction(data.restoreFocus.focus)) {
+                    data.restoreFocus.focus();
+                }
+
+                if (!self.mainView) {
+                    $(el).remove();  // Aborted Guard Authentication. Remove element since the MainView hasn't been initialized and won't remove it on dispose.
+                }
+            }
+
+            function getFileListFromFiles() {
+                return $.when([].concat(data.files));
+            }
+
+            function getFileListFromFolder() {
+                return require(['io.ox/files/api']).then(function (FilesAPI) {
+                    return FilesAPI.getAll(data.folder).then(function success(files) {
                         function getter(item) {
                             return this.get(_.cid(item));
                         }
                         // the viewer has listeners that work directly on the model
                         // so we need to get the pool models instead of creating own models
-                        fileList = _(files).map(getter, api.pool.get('detail'));
-                    }).always(cont);
+                        return _.map(files, getter, FilesAPI.pool.get('detail'));
+                    });
                 });
-            } else {
-                cont();
             }
+
+            // fix for #58378
+            (hasFolder() ? getFileListFromFolder() : getFileListFromFiles()).then(function (fileList) {
+                // add file list to baton data
+                data.fileList = fileList;
+                // Call extension point for any required performs, e.g. Guard authentication
+                return ext.point('io.ox/core/viewer/main').cascade(this, new ext.Baton({ data: data }));
+
+            }).then(cont, close);
+
         };
     };
 
