@@ -15,10 +15,10 @@ define('io.ox/core/viewer/views/displayerview', [
     'io.ox/core/viewer/views/types/typesregistry',
     'io.ox/backbone/disposable',
     'io.ox/core/viewer/util',
-    'static/3rd.party/bigscreen/bigscreen.min.js',
+    'static/3rd.party/bigscreen.min.js',
     'settings!io.ox/files',
     'gettext!io.ox/core',
-    'static/3rd.party/swiper/swiper.jquery.js',
+    'static/3rd.party/swiper.jquery.js',
     'css!3rd.party/swiper/swiper.css'
 ], function (FilesAPI, TypesRegistry, DisposableView, Util, BigScreen, filesSettings, gt) {
 
@@ -108,7 +108,7 @@ define('io.ox/core/viewer/views/displayerview', [
             }
             displayerView.toggleSwiperOnlyExternalState(true);
 
-          //displayerView.carouselRoot.find('.fullscreen-button').focus();
+            //displayerView.carouselRoot.find('.fullscreen-button').focus();
             displayerView.$el.focus();
             displayerView.carouselRoot.removeClass('autoplay-controls-visible');
         }
@@ -180,14 +180,13 @@ define('io.ox/core/viewer/views/displayerview', [
     }
 
     function createDisplayNextAutoplaySlide(swiper) {
-        return function () {
-                                              // - for [s.slideNext] see "swiper.js" line 1586.
+        return function () {                  // - for [s.slideNext] see "swiper.js" line 1586.
             swiper.slideNext(true, 0, false); // - params{runCallbacks, speed, internal} ... for what {internal} does see "swiper.js" line 1513.
         };
     }
     function createKeepAutoplayAlive(displayerView) {
         return function () {
-          //displayerView.autoplayOverdriveSlideCount = null;
+            //displayerView.autoplayOverdriveSlideCount = null;
             displayerView.autoplaySlideCount = 0;
 
             displayerView.swiper.slideNext(true, 0, false);
@@ -245,9 +244,9 @@ define('io.ox/core/viewer/views/displayerview', [
         $carouselInner.on('mouseenter', '.viewer-displayer-item-container', enterHandler);
         $carouselInner.on('mouseleave', '.viewer-displayer-item-container', leaveHandler);
 
-      // - see line 361 - gets already handled there
-      // - the commented block above and also the next commented line are for another, more complex blending behavior of both navigation arrows.
-      //$carouselInner.on('mousemove click', '.viewer-displayer-item-container', displayerView.displayerviewMousemoveClickHandler);
+        // - see line 361 - gets already handled there
+        // - the commented block above and also the next commented line are for another, more complex blending behavior of both navigation arrows.
+        //$carouselInner.on('mousemove click', '.viewer-displayer-item-container', displayerView.displayerviewMousemoveClickHandler);
     }
 
     function registerAutoplayEventHandlingForPreviousNextControl(displayerView) {
@@ -281,16 +280,16 @@ define('io.ox/core/viewer/views/displayerview', [
         if (displayerView.hasAutoplayStartAlreadyBeenTriggered()) { // only in case of autoplay start has already been triggered.
 
             window.clearTimeout(displayerView.captionTimeoutId);
-          //window.clearTimeout(displayerView.navigationTimeoutId);
+            //window.clearTimeout(displayerView.navigationTimeoutId);
 
             var
                 $viewElement = displayerView.$el,
 
                 $slideCaption = $viewElement.find('.viewer-displayer-caption');
-              //$navigationArrows = $viewElement.find('.swiper-button-control');
+                //$navigationArrows = $viewElement.find('.swiper-button-control');
 
             $slideCaption.hide();
-          //$navigationArrows.hide();
+            //$navigationArrows.hide();
         }
     }
 
@@ -582,7 +581,7 @@ define('io.ox/core/viewer/views/displayerview', [
                 last = this.$el.find('.swiper-slide-duplicate[data-index="' + (this.collection.length - 1) + '"]');
 
             function handle(el, model) {
-                self.createDummy(el.get[0], model);
+                self.createDummy(el, model);
             }
             if (first.length > 0) handle(first, this.collection.first());
             if (last.length > 0) handle(last, this.collection.last());
@@ -642,6 +641,7 @@ define('io.ox/core/viewer/views/displayerview', [
 
                 return TypesRegistry.getModelType(model).then(function success(ModelTypeView) {
                     var view = new ModelTypeView({
+                        app: self.app,
                         model: model,
                         collection: collection,
                         viewerEvents: self.viewerEvents
@@ -654,11 +654,11 @@ define('io.ox/core/viewer/views/displayerview', [
                         var active = false;
                         if (self.swiper) {
                             var additionalClasses = '';
-                            if (self.swiper.wrapper.find('*[data-index=' + index + '].swiper-slide-active').length) {
+                            if (self.swiper.wrapper.find('*.swiper-slide[data-index=' + index + '].swiper-slide-active').length) {
                                 additionalClasses = 'swiper-slide-active';
                                 active = true;
                             }
-                            var slide = self.swiper.wrapper.find('*[data-index=' + index + ']:not(.swiper-slide-duplicate)'),
+                            var slide = self.swiper.wrapper.find('*.swiper-slide[data-index=' + index + ']:not(.swiper-slide-duplicate)'),
                                 swiperIndex = slide.data('swiper-slide-index');
                             if (slide.hasClass('swiper-slide-prev')) {
                                 additionalClasses = additionalClasses + 'swiper-slide-prev';
@@ -666,17 +666,17 @@ define('io.ox/core/viewer/views/displayerview', [
                             if (slide.hasClass('swiper-slide-next')) {
                                 additionalClasses = additionalClasses + 'swiper-slide-next';
                             }
-                            self.swiper.wrapper.find('*[data-index=' + index + ']:not(.swiper-slide-duplicate)').replaceWith(view.$el);
+                            self.swiper.wrapper.find('*.swiper-slide[data-index=' + index + ']:not(.swiper-slide-duplicate)').replaceWith(view.$el);
                             view.$el.attr('data-swiper-slide-index', swiperIndex);
                             view.$el.addClass(additionalClasses);
                             if (active) {
                                 view.$el.attr('tabindex', 0).focus();
                             }
 
-                            if (self.swiper.wrapper.find('*[data-index=' + index + '].swiper-slide-duplicate').length) {
+                            if (self.swiper.wrapper.find('*.swiper-slide[data-index=' + index + '].swiper-slide-duplicate').length) {
                                 // there is a swiper duplicate of this. let's replace this as well.
                                 var duplicateView = new ModelTypeView({
-                                    el: self.swiper.wrapper.find('*[data-index=' + index + '].swiper-slide-duplicate').removeClass('dummy-slide').get(0),
+                                    el: (self.swiper.wrapper.find('*.swiper-slide[data-index=' + index + '].swiper-slide-duplicate').removeClass('dummy-slide')).get(0),
                                     model: model,
                                     collection: collection,
                                     viewerEvents: self.viewerEvents
@@ -830,7 +830,7 @@ define('io.ox/core/viewer/views/displayerview', [
                                 self.swiper.updateSlidesSize();
                             }
                             if (self.delayedRemove[index]) {
-                                self.delayedRemove[index].view.unload(index).dispose();
+                                self.delayedRemove[index].view.unload().dispose();
                                 self.delayedRemove[index].node.remove();
                             } else if (view.$el.hasClass('swiper-slide-active')) {
                                 // show if active
@@ -866,17 +866,17 @@ define('io.ox/core/viewer/views/displayerview', [
                     // remove old slide
                     if (self.loadingSlides[removeIndex]) {
                         //don't remove currently loading files to prevent errors
-                        self.delayedRemove[removeIndex] = { view: self.slideViews[removeIndex], node: swiper.wrapper.find('*[data-index=' + removeIndex + ']') };
-                        swiper.wrapper.find('*[data-index=' + removeIndex + ']').detach();
+                        self.delayedRemove[removeIndex] = { view: self.slideViews[removeIndex], node: swiper.wrapper.find('*.swiper-slide[data-index=' + removeIndex + ']') };
+                        swiper.wrapper.find('*.swiper-slide[data-index=' + removeIndex + ']').detach();
                     } else {
-                        self.slideViews[removeIndex].unload(removeIndex).dispose();
-                        swiper.wrapper.find('*[data-index=' + removeIndex + ']').remove();
+                        self.slideViews[removeIndex].unload().dispose();
+                        swiper.wrapper.find('*.swiper-slide[data-index=' + removeIndex + ']').remove();
                     }
                     delete self.slideViews[removeIndex];
 
                     // add new slide at correct position
                     if (direction === 'right') {
-                        neighbour = swiper.wrapper.find('*[data-index=' + (insertIndex - 1) + ']');
+                        neighbour = swiper.wrapper.find('*.swiper-slide[data-index=' + (insertIndex - 1) + ']');
 
                         if (neighbour.length > 0) {
                             neighbour.after(view.$el);
@@ -884,7 +884,7 @@ define('io.ox/core/viewer/views/displayerview', [
                             swiper.wrapper.prepend(view.$el);
                         }
                     } else if (direction === 'left') {
-                        neighbour = swiper.wrapper.find('*[data-index=' + (insertIndex + 1) + ']');
+                        neighbour = swiper.wrapper.find('*.swiper-slide[data-index=' + (insertIndex + 1) + ']');
 
                         if (neighbour.length > 0) {
                             neighbour.before(view.$el);
@@ -1294,7 +1294,7 @@ define('io.ox/core/viewer/views/displayerview', [
 
             if (IS_LOOP_ONCE_ONLY) {
                 this.isAutoplayOverdrive = false;
-              //this.autoplayOverdriveSlideCount = null;
+                //this.autoplayOverdriveSlideCount = null;
                 this.autoplaySlideCount = -1;
             }
             this.collectionBackup = this.collection.clone();
@@ -1336,7 +1336,7 @@ define('io.ox/core/viewer/views/displayerview', [
 
             if (IS_LOOP_ONCE_ONLY) {
                 this.isAutoplayOverdrive = false;
-              //this.autoplayOverdriveSlideCount = null;
+                //this.autoplayOverdriveSlideCount = null;
                 this.autoplaySlideCount = null;
             }
             this.collection.reset(this.collectionBackup.models);
@@ -1437,7 +1437,7 @@ define('io.ox/core/viewer/views/displayerview', [
 
             this.collectionBackup = null;
             this.isAutoplayOverdrive = null;
-          //this.autoplayOverdriveSlideCount = null;
+            //this.autoplayOverdriveSlideCount = null;
             this.autoplaySlideCount = null;
 
             this.canAutoplayImages = null;
