@@ -26,7 +26,8 @@ define('io.ox/core/viewer/views/types/defaultview', [
      *
      * interface ViewerType {
      *    function render();
-     *    function load();
+     *    function prefetch();
+     *    function show();
      *    function unload();
      * }
      *
@@ -46,7 +47,7 @@ define('io.ox/core/viewer/views/types/defaultview', [
         render: function () {
 
             this.$el.empty().append(
-                this.createNotificationNode(gt('There is no preview for this file type'))
+                this.displayDownloadNotification(gt('There is no preview for this file type.'))
             );
 
             return this;
