@@ -13,18 +13,49 @@
 
 define('io.ox/files/listview', [
     'io.ox/core/tk/list',
+    'io.ox/backbone/mini-views/contextmenu-utils',
     'io.ox/core/extensions',
     'io.ox/files/common-extensions',
     'io.ox/files/api',
     'settings!io.ox/core',
     'io.ox/files/view-options',
     'less!io.ox/files/style'
-], function (ListView, ext, extensions, filesAPI, settings) {
+], function (ListView, ContextMenuUtils, ext, extensions, filesAPI, settings) {
 
     'use strict';
 
     var LISTVIEW = 'io.ox/files/listview', ITEM = LISTVIEW + '/item';
 
+    function onContextMenu(e) {
+        ContextMenuUtils.checkKeyboardEvent(e);
+        var view = this;
+        var app = view.app;
+        // the link to render the context menu with it's entries.
+        var link = 'io.ox/core/file/contextmenu/default';
+        // context menu when clicked below the list.
+        // var linkOutsideList = link + '/outsideList'; Disabled for now
+
+        // android sends context events on long tap, but currently we don't want a context menu on smartphones and tablets
+        if (_.device('smartphone') || _.device('android')) { return; }
+
+        var list = view.selection.get();
+        if (!list) return;
+        // turn cids into proper objects
+        var cids = list, models = filesAPI.resolve(cids, false);
+        list = _(models).invoke('toJSON');
+        // extract single object if length === 1
+        var data = list.length === 1 ? list[0] : list;
+
+        return require(['io.ox/core/folder/api']).then(function (folderApi) {
+            var folderId = app.folder.get(),
+                model = folderApi.pool.getModel(folderId);
+
+            var baton = new ext.Baton({ data: data, models: models, collection: app.listView.collection, app: app, allIds: [], view: view, linkContextMenu: link/*, linkContextMenuOutsideList: linkOutsideList*/, insideTrash: folderApi.is('trash', model.toJSON()) });
+
+            view.contextMenu.showContextMenu(e, baton);
+        });
+    }
+
     //
     // Extend ListView
     //
@@ -35,7 +66,17 @@ define('io.ox/files/listview', [
 
         initialize: function () {
             ListView.prototype.initialize.apply(this, arguments);
-            this.$el.addClass('file-list-view');
+            var view = this;
+            view.contextMenu = arguments[0].contextMenu;
+
+            view.$el.addClass('file-list-view');
+
+            view.favorites = settings.get('favorites/infostore', []);
+            view.favoriteFiles = settings.get('favoriteFiles/infostore', []);
+            settings.on('change:favorites/infostore', function () {
+                view.favorites = settings.get('favorites/infostore', []);
+                view.favoriteFiles = settings.get('favoriteFiles/infostore', []);
+            });
         },
 
         getCompositeKey: function (model) {
@@ -47,11 +88,13 @@ define('io.ox/files/listview', [
             var relevantChanges = _.intersection(_(model.changed).keys(), FileListView.relevantAttributes);
             if (!relevantChanges.length) return;
             ListView.prototype.onChange.apply(this, arguments);
-        }
+        },
+
+        onContextMenu: onContextMenu
     });
 
     // we redraw only if a relevant attribute changes (to avoid flickering)
-    FileListView.relevantAttributes = ['index', 'id', 'last_modified', 'locked_until', 'filename', 'file_mimetype', 'file_size', 'source', 'title', 'version'];
+    FileListView.relevantAttributes = ['index', 'id', 'last_modified', 'locked_until', 'filename', 'file_mimetype', 'file_size', 'source', 'title', 'version', 'index/virtual/favorites/infostore'];
 
     //
     // Extension for detail sidebar
@@ -198,7 +241,7 @@ define('io.ox/files/listview', [
             draw: function () {
                 extensions.thumbnail.apply(this, arguments);
 
-              //this.prepend($('<div class="thumbnail-effects-box"></div>')); // please do not remove.
+                //this.prepend($('<div class="thumbnail-effects-box"></div>')); // please do not remove.
                 this.prepend($('<div class="thumbnail-masking-box"></div>'));
             }
         },
@@ -244,7 +287,7 @@ define('io.ox/files/listview', [
             draw: function () {
                 extensions.thumbnail.apply(this, arguments);
 
-              //this.prepend($('<div class="thumbnail-effects-box"></div>')); // please do not remove.
+                //this.prepend($('<div class="thumbnail-effects-box"></div>')); // please do not remove.
                 this.prepend($('<div class="thumbnail-masking-box"></div>'));
             }
         },
