@@ -25,30 +25,37 @@ define('io.ox/files/share/toolbar', [
     'use strict';
 
     // define links for classic toolbar
-    var point = ext.point('io.ox/files/share/classic-toolbar/links'),
-
-        meta = {
-            'edit': {
-                prio: 'hi',
-                mobile: 'lo',
-                label: gt('Edit share'),
-                drawDisabled: true,
-                ref: 'io.ox/files/share/edit'
-            },
-            'delete': {
-                prio: 'hi',
-                mobile: 'lo',
-                label: gt('Revoke access'),
-                drawDisabled: true,
-                ref: 'io.ox/files/share/revoke'
-            },
-            'back': {
-                prio: 'lo',
-                mobile: 'hi',
-                label: gt('Folder'),
-                ref: 'io.ox/files/share/back'
-            }
-        };
+    var point = ext.point('io.ox/files/share/classic-toolbar/links');
+    // the link meta data used for desktop and tablets
+    var meta = {
+        'edit': {
+            prio: 'hi',
+            mobile: 'lo',
+            label: gt('Edit share'),
+            ref: 'io.ox/files/actions/editShare'
+        },
+        'delete': {
+            prio: 'hi',
+            mobile: 'lo',
+            label: gt('Revoke access'),
+            ref: 'io.ox/files/share/revoke'
+        },
+        'back': {
+            prio: 'lo',
+            mobile: 'hi',
+            label: gt('Folders'),
+            ref: 'io.ox/files/share/back'
+        }
+    };
+    // the link meta data used for smartphones
+    var metaPhone = {
+        'back': {
+            prio: 'lo',
+            mobile: 'hi',
+            label: gt('Folders'),
+            ref: 'io.ox/files/share/back'
+        }
+    };
 
     new actions.Action('io.ox/files/share/edit', {
         requires: 'one',
@@ -59,20 +66,10 @@ define('io.ox/files/share/toolbar', [
         }
     });
 
-    new actions.Action('io.ox/files/share/revoke', {
-        requires: 'one',
-        action: function (baton) {
-            require(['io.ox/files/share/permissions'], function (permissions) {
-                var collection = new permissions.Permissions();
-                api.revoke(collection, baton.model).then(function () {
-                    yell('success', gt('Revoked access.'));
-                }).fail(yell);
-            });
-        }
-    });
-
     new actions.Action('io.ox/files/share/back', {
-        requires: 'none',
+        requires: function () {
+            return _.device('smartphone');
+        },
         action: function () {
             $('[data-page-id="io.ox/files/main"]').trigger('myshares-folder-back');
         }
@@ -82,7 +79,8 @@ define('io.ox/files/share/toolbar', [
 
     var index = 0;
 
-    _(meta).each(function (extension, id) {
+    // fix for #58808 - use different link meta data on smartphones
+    _(_.device('smartphone') ? metaPhone : meta).each(function (extension, id) {
         extension.id = id;
         extension.index = (index += 100);
         point.extend(new links.Link(extension));
