@@ -32,7 +32,9 @@ define('io.ox/mail/compose/main', ['io.ox/mail/api', 'settings!io.ox/mail', 'get
                 name: 'io.ox/mail/compose',
                 title: gt('Compose'),
                 userContent: true,
-                closable: true
+                closable: true,
+                floating: !_.device('smartphone'),
+                size: 'width-xs height-md'
             }),
             win;
 
@@ -40,7 +42,11 @@ define('io.ox/mail/compose/main', ['io.ox/mail/api', 'settings!io.ox/mail', 'get
             // get window
             app.setWindow(win = ox.ui.createWindow({
                 name: 'io.ox/mail/compose',
-                chromeless: true
+                chromeless: true,
+                // attributes for the floating window
+                floating: !_.device('smartphone'),
+                closable: true,
+                title: gt('Compose')
             }));
 
             // use main role on 'outer' to include actions in header
@@ -55,7 +61,7 @@ define('io.ox/mail/compose/main', ['io.ox/mail/api', 'settings!io.ox/mail', 'get
         };
 
         app.failRestore = function (point) {
-            if (point.restoreById) {
+            if (point.restoreById || !point.mode) {
                 delete point.restoreById;
                 return compose('edit')(point);
             }
@@ -75,7 +81,7 @@ define('io.ox/mail/compose/main', ['io.ox/mail/api', 'settings!io.ox/mail', 'get
             return function (obj) {
 
                 var def = $.Deferred();
-                _.url.hash('app', 'io.ox/mail/compose:' + type);
+                obj = obj || {};
 
                 app.cid = 'io.ox/mail:' + type + '.' + _.cid(obj);
 
@@ -90,10 +96,13 @@ define('io.ox/mail/compose/main', ['io.ox/mail/api', 'settings!io.ox/mail', 'get
                             // in most cases, this should return the mail from pool ('detail')
                             // need circumvent caching, here, because all requests always break data again and we can
                             // never be sure about data being correct
-                            return mailAPI.get(_.pick(obj, 'id', 'folder_id'), { cache: false });
+                            return mailAPI.get(_.extend(_.pick(obj, 'id', 'folder_id'), { view: 'raw' }), { cache: false });
                         }
                         return obj;
                     }).then(function (latestMail) {
+                        if (!_.isArray(latestMail)) latestMail.security = obj.security;  // Fix for Bug 56496 above breaking Guard.  Security lost with reload
+                        else latestMail.forEach(function (m, i) { m.security = obj[i].security; });
+
                         obj = _.extend({ mode: type }, latestMail);
                         return require(['io.ox/mail/compose/view', 'io.ox/mail/compose/model']);
                     })
@@ -114,7 +123,7 @@ define('io.ox/mail/compose/main', ['io.ox/mail/api', 'settings!io.ox/mail', 'get
                         win.nodes.header.removeClass('sr-only');
                         win.nodes.body.removeClass('sr-only').find('.scrollable').scrollTop(0);
                         win.idle();
-                        win.setTitle(gt('Compose'));
+                        win.setTitle(obj.subject || gt('Compose'));
                         def.resolve({ app: app });
                         ox.trigger('mail:' + type + ':ready', obj, app);
                     })
@@ -125,7 +134,7 @@ define('io.ox/mail/compose/main', ['io.ox/mail/api', 'settings!io.ox/mail', 'get
                             app.model.dirty(false);
                             app.view.removeLogoutPoint();
                             app.quit();
-                            def.reject();
+                            def.reject(e);
                         });
                     });
                 });
@@ -156,7 +165,7 @@ define('io.ox/mail/compose/main', ['io.ox/mail/api', 'settings!io.ox/mail', 'get
         getApp: createInstance,
 
         reuse: function (type, data) {
-            //disable reuse if at least one app is sending (depends on type)
+            // disable reuse if at least one app is sending (depends on type)
             var unblocked = function (sendtype) {
                 return blocked[sendtype] === undefined || blocked[sendtype] <= 0;
             };
