@@ -11,7 +11,7 @@
  * @author David Bauer <david.bauer@open-xchange.com>
  */
 
-define.async('io.ox/mail/compose/model', [
+define('io.ox/mail/compose/model', [
     'io.ox/mail/api',
     'io.ox/mail/util',
     'io.ox/core/capabilities',
@@ -25,16 +25,6 @@ define.async('io.ox/mail/compose/model', [
 
     'use strict';
 
-    var emoji = {};
-    //provide initial fake implementation of the API we need.
-    //this will be overwritten by the emoji API if user has the capability
-    emoji.converterFor = function () {
-        return _.identity;
-    };
-    emoji.sendEncoding = function () {
-        return 'unified';
-    };
-
     var MailModel = Backbone.Model.extend({
 
         defaults: function () {
@@ -104,6 +94,7 @@ define.async('io.ox/mail/compose/model', [
                 }
             });
 
+            // special case #1: 'alternative'
             if (this.get('preferredEditorMode') === 'alternative') {
                 this.set('editorMode', 'html', { silent: true });
                 if (this.get('content_type') === 'text/plain') {
@@ -118,7 +109,9 @@ define.async('io.ox/mail/compose/model', [
                     if (settings.get(['customDisplayNames', address[1], 'overwrite'])) {
                         address[0] = settings.get(['customDisplayNames', address[1], 'name'], '');
                     }
-                    address[0] = this.get('sendDisplayName') ? address[0] : null;
+                    if (!settings.get('sendDisplayName', true)) {
+                        address[0] = null;
+                    }
                     this.set('from', [address]);
                 }.bind(this));
             }
@@ -128,6 +121,11 @@ define.async('io.ox/mail/compose/model', [
 
             if (!this.get('signatures')) this.set('signatures', this.getSignatures());
 
+            // update from when custom displayname changes
+            this.updateDisplayName();
+            this.on('change:sendDisplayName', this.updateDisplayName);
+            ox.on('change:customDisplayNames', this.updateDisplayName.bind(this));
+
             this.updateShadow();
         },
 
@@ -143,6 +141,13 @@ define.async('io.ox/mail/compose/model', [
             return ret;
         },
 
+        updateDisplayName: function () {
+            // fix current value
+            var from = this.get('from');
+            if (!from) return;
+            this.set('from', [mailUtil.getSender(from[0], this.get('sendDisplayName'))]);
+        },
+
         updateShadow: function () {
             this._shadowAttributes = this.getCopy();
         },
@@ -210,9 +215,6 @@ define.async('io.ox/mail/compose/model', [
                 content = content.replace(/^<div\sid="ox-\S+">/, '').replace(/<\/div>$/, '');
             }
 
-            // convert different emoji encodings to unified
-            content = this.convertAllToUnified(content);
-
             return content;
         },
 
@@ -251,6 +253,9 @@ define.async('io.ox/mail/compose/model', [
                 }
             });
 
+            // special case #1: 'alternative'
+            if (mail.preferredEditorMode === 'alternative') mail.content_type = mail.editorMode === 'html' ? 'text/html' : 'text/plain';
+
             return {
                 description: gt('Mail') + ': ' + (mail.subject || gt('No subject')),
                 point: mail
@@ -261,17 +266,8 @@ define.async('io.ox/mail/compose/model', [
             this.trigger('needsync');
             var result,
                 attachmentCollection = this.get('attachments'),
-                convert = emoji.converterFor({ to: emoji.sendEncoding() }),
                 content = attachmentCollection.at(0).get('content');
 
-            //convert to target emoji send encoding
-            if (convert && emoji.sendEncoding() !== 'unified') {
-                //convert to send encoding (NOOP, if target encoding is 'unified')
-                this.set('subject', convert(this.get('subject')), { silent: true });
-
-                content = convert(content, this.get('editorMode'));
-            }
-
             // fix inline images
             content = mailUtil.fixInlineImages(content);
 
@@ -347,10 +343,6 @@ define.async('io.ox/mail/compose/model', [
             if (this.get('autosavedAsDraft') && this.get('msgref')) mailAPI.remove([mailUtil.parseMsgref(mailAPI.separator, this.get('msgref'))]);
         },
 
-        convertAllToUnified: emoji.converterFor({
-            from: 'all',
-            to: 'unified'
-        }),
         attachFiles: function attachFiles(files) {
             this.get('attachments').add(files);
         },
@@ -361,15 +353,5 @@ define.async('io.ox/mail/compose/model', [
         }
     });
 
-    var def = $.Deferred();
-
-    if (capabilities.has('emoji')) {
-        require(['io.ox/emoji/bundle']).then(function (e) {
-            emoji = e;
-            def.resolve(MailModel);
-        });
-    } else {
-        def.resolve(MailModel);
-    }
-    return def;
+    return MailModel;
 });
