@@ -26,6 +26,7 @@ define('io.ox/mail/compose/view', [
     'gettext!io.ox/mail',
     'io.ox/mail/actions/attachmentEmpty',
     'io.ox/mail/actions/attachmentQuota',
+    'io.ox/core/attachments/backbone',
     'io.ox/core/tk/dialogs',
     'io.ox/mail/compose/signatures',
     'io.ox/mail/sanitizer',
@@ -34,7 +35,7 @@ define('io.ox/mail/compose/view', [
     'less!io.ox/mail/compose/style',
     'io.ox/mail/compose/actions/send',
     'io.ox/mail/compose/actions/save'
-], function (extensions, Dropdown, ext, mailAPI, mailUtil, textproc, settings, coreSettings, notifications, snippetAPI, accountAPI, gt, attachmentEmpty, attachmentQuota, dialogs, signatureUtil, sanitizer, attachmentModel) {
+], function (extensions, Dropdown, ext, mailAPI, mailUtil, textproc, settings, coreSettings, notifications, snippetAPI, accountAPI, gt, attachmentEmpty, attachmentQuota, Attachments, dialogs, signatureUtil, sanitizer, attachmentModel) {
 
     'use strict';
 
@@ -96,6 +97,11 @@ define('io.ox/mail/compose/view', [
             index: INDEX += 100,
             draw: extensions.sender
         },
+        {
+            id: 'sender-realname',
+            index: INDEX += 100,
+            draw: extensions.senderRealName
+        },
         {
             id: 'to',
             index: INDEX += 100,
@@ -261,7 +267,8 @@ define('io.ox/mail/compose/view', [
             id: 'add_attachments',
             index: 100,
             draw: function (baton) {
-                var node = $('<div data-extension-id="add_attachments" class="col-xs-5 col-md-5 col-md-offset-1">');
+                var node = $('<div data-extension-id="add_attachments" class="mail-input col-xs-3">');
+                if (_.device('!smartphone')) node.addClass('col-xs-offset-2');
                 extensions.attachment.call(node, baton);
                 this.append(node);
             }
@@ -275,7 +282,7 @@ define('io.ox/mail/compose/view', [
                 ext.point(POINT + '/menu').invoke('draw', node, baton);
 
                 this.append(
-                    $('<div data-extension-id="composetoolbar-menu" class="col-xs-7 col-md-6">').append(node)
+                    $('<div data-extension-id="composetoolbar-menu" class="col-xs-7">').append(node)
                 );
             }
         }
@@ -287,6 +294,7 @@ define('io.ox/mail/compose/view', [
         draw: function (baton) {
             var node = $('<div data-extension-id="attachmentPreview" class="col-xs-12">');
             extensions.attachmentPreviewList.call(node, baton);
+            extensions.attachmentSharing.call(node, baton);
             node.appendTo(this);
         }
     });
@@ -423,7 +431,7 @@ define('io.ox/mail/compose/view', [
                             id = base.last(),
                             folder = base.without(id).join(mailAPI.separator),
                             // use JSlob to save the draft ID so it can be used as a restore point.
-                            idSavePoints =  coreSettings.get('savepoints', []);
+                            idSavePoints = coreSettings.get('savepoints', []);
 
                         idSavePoints.push({
                             module: 'io.ox/mail/compose',
@@ -466,7 +474,7 @@ define('io.ox/mail/compose/view', [
             delete obj.mode;
 
             if (obj.initial === false) {
-                obj.attachments = new Backbone.Collection(_.clone(obj.attachments));
+                obj.attachments = new Attachments.Collection(_.clone(obj.attachments));
                 this.model.set(obj);
                 obj = null;
                 return $.when();
@@ -555,6 +563,9 @@ define('io.ox/mail/compose/view', [
                         address[0] = settings.get(['customDisplayNames', address[1], 'name'], address[0]);
                     }
 
+                    // recover notification option (boolean)
+                    if (mode === 'edit') data.disp_notification_to = !!data.disp_notification_to;
+
                     self.model.set(data);
 
                     var attachmentCollection = self.model.get('attachments');
@@ -591,7 +602,8 @@ define('io.ox/mail/compose/view', [
                         self.model.set('attachments', attachmentCollection);
                         obj = data = attachmentCollection = null;
                     });
-                }).fail(function () {
+                })
+                .fail(function () {
                     // Mark model as clean to prevent save/discard dialog when server side error occurs
                     self.clean();
                 });
@@ -774,6 +786,12 @@ define('io.ox/mail/compose/view', [
                 var discardText = isDraft ? gt.pgettext('dialog', 'Delete draft') : gt.pgettext('dialog', 'Discard message'),
                     saveText = isDraft ? gt('Keep draft') : gt('Save as draft'),
                     modalText = isDraft ? gt('Do you really want to delete this draft?') : gt('Do you really want to discard your message?');
+
+                if (this.app.getWindow && this.app.getWindow().floating) {
+                    this.app.getWindow().floating.toggle(true);
+                } else if (_.device('smartphone')) {
+                    this.app.getWindow().resume();
+                }
                 // button texts may become quite large in some languages (e. g. french, see Bug 35581)
                 // add some extra space
                 // TODO maybe we could use a more dynamical approach
@@ -979,17 +997,14 @@ define('io.ox/mail/compose/view', [
         },
 
         getParagraph: function (text, isHTML) {
-            //use div for html cause innerHTML for p tags with nested tags fail
-            var node = (/(<([^>]+)>)/ig).test(text) ? $('<div>') : $('<p>');
-            node.addClass('io-ox-signature')
-                .append(!!isHTML ? text : this.editor.ln2br(text));
+            var node = $('<div class="io-ox-signature">').append(!!isHTML ? text : this.editor.ln2br(text));
             return $('<div>').append(node).html();
         },
 
         prependNewLine: function () {
             // Prepend newline in all modes except when editing draft
             if (this.model.get('mode') === 'edit') return;
-            var content = this.editor.getContent().replace(/^\n+/, '').replace(/^(<p[^>]*class="default-style"[^>]*><br><\/p>)+/, '');
+            var content = this.editor.getContent().replace(/^\n+/, '').replace(/^(<div[^>]*class="default-style"[^>]*><br><\/div>)+/, '');
             var nl = this.model.get('editorMode') === 'html' ? mailUtil.getDefaultStyle().node.get(0).outerHTML : '\n';
             this.editor.setContent(nl + content);
         },
