@@ -131,7 +131,7 @@ define('io.ox/mail/mailfilter/settings/filter', [
             async: true,
             point: 'io.ox/settings/mailfilter/filter/settings/detail/dialog',
             title: header,
-            help: 'ox.appsuite.user.sect.email.mailfilter.change.html'
+            help: data.id === undefined ? 'ox.appsuite.user.sect.email.mailfilter.create.html' : 'ox.appsuite.user.sect.email.mailfilter.change.html'
         });
 
         myView.dialog.$body.append(
@@ -145,7 +145,7 @@ define('io.ox/mail/mailfilter/settings/filter', [
         .addCancelButton();
 
         //disable save button if no action is set
-        if (actionArray.length === 0) myView.dialog.$el.find('.modal-footer [data-action="save"]').prop('disabled', true);
+        if (actionArray.length === 0) myView.dialog.$el.find('.modal-footer[data-action="save"]').prop('disabled', true);
 
         myView.dialog.open();
         myView.$el.find('input[name="rulename"]').focus();
@@ -243,7 +243,7 @@ define('io.ox/mail/mailfilter/settings/filter', [
     });
 
     return {
-        editMailfilter: function ($node, baton) {
+        editMailfilter: function ($node) {
 
             var createExtpointForSelectedFilter = function (node, args, config) {
                     ext.point('io.ox/settings/mailfilter/filter/settings/detail').invoke('draw', node, args, config);
@@ -252,7 +252,6 @@ define('io.ox/mail/mailfilter/settings/filter', [
                 scrollPane =  $node.closest('.scrollable-pane');
 
             return this.initialize().then(function (data, config) {
-                data = data[0];
 
                 // adds test for testcase
                 // config.tests.push({ test: 'newtest', comparison: ['regex', 'is', 'contains', 'matches', 'testValue'] });
@@ -276,6 +275,15 @@ define('io.ox/mail/mailfilter/settings/filter', [
 
                     saveTimeout: 0,
 
+                    initialize: function () {
+                        if (_.indexOf(this.model.get('flags'), 'vacation') !== -1) this.listenTo(ox, 'mail:change:vacation-notice', this.handleToogleState);
+                        if (_.indexOf(this.model.get('flags'), 'autoforward') !== -1) this.listenTo(ox, 'mail:change:auto-forward', this.handleToogleState);
+                    },
+
+                    handleToogleState: function (model) {
+                        this.model.set('active', model.get('active'));
+                    },
+
                     render: function () {
                         var flag = (this.model.get('flags') || [])[0],
                             self = this,
@@ -481,12 +489,16 @@ define('io.ox/mail/mailfilter/settings/filter', [
 
                     onEditVacation: function (e) {
                         e.preventDefault();
-                        baton.tree.trigger('virtual', 'virtual/settings/' + 'io.ox/vacation', {});
+                        require(['io.ox/mail/mailfilter/vacationnotice/view'], function (view) {
+                            view.open();
+                        });
                     },
 
                     onEditAutoforward: function (e) {
                         e.preventDefault();
-                        baton.tree.trigger('virtual', 'virtual/settings/' + 'io.ox/autoforward', {});
+                        require(['io.ox/mail/mailfilter/autoforward/view'], function (view) {
+                            view.open();
+                        });
                     }
                 });
 
@@ -498,11 +510,13 @@ define('io.ox/mail/mailfilter/settings/filter', [
 
                     render: function () {
                         this.$el.empty();
-                        this.$el.append($('<h1>').addClass('pull-left').text(gt('Mail Filter Rules')),
-                            $('<div>').addClass('btn-group pull-right').append(
-                                $('<button type="button" class="btn btn-primary" data-action="add">').addClass('btn btn-primary').text(gt('Add new rule'))
+                        this.$el.append(
+                            $('<h1>').text(gt('Mail Filter Rules')),
+                            $('<div class="form-group buttons">').append(
+                                $('<button type="button" class="btn btn-primary" data-action="add">').append(
+                                    $('<i class="fa fa-plus" aria-hidden="true">'), $.txt(gt('Add new rule'))
+                                )
                             ),
-                            $('<div class="clearfix">'),
                             $('<div class="sr-only" role="log" aria-live="polite" aria-relevant="all">').attr('id', notificationId)
                         );
                         this.renderFilter();
@@ -564,6 +578,7 @@ define('io.ox/mail/mailfilter/settings/filter', [
             });
 
         },
+
         initialize: function () {
             // needed for mail actions
             var options = {
@@ -577,12 +592,10 @@ define('io.ox/mail/mailfilter/settings/filter', [
 
         refresh: function () {
             this.initialize().done(function (data) {
-                _.each(data[0], function (rule) {
+                _(data).each(function (rule) {
                     collection.add(factory.create(rule), { merge: true });
                 });
             });
-
         }
     };
-
 });
