@@ -30,9 +30,7 @@ define('io.ox/mail/settings/defaults', [], function () {
         'autoSaveDraftsAfter': 'disabled',
         'allowHtmlMessages': true,
         'allowHtmlImages': false,
-        'displayEmoticons': false,
         'isColorQuoted': false,
-        'beautifyPlainText': false,
         'defaultSignature': false,
         'defaultReplyForwardSignature': false,
         'mobileSignature': undefined,
@@ -43,12 +41,16 @@ define('io.ox/mail/settings/defaults', [], function () {
         'sort': 'thread',
         'order': 'desc',
         'unread': false,
-        'simpleLineBreaks': true,
         'notificationSoundName': 'bell',
         'playSound': true,
         'confirmReplyToMailingLists': true,
         'unseenMessagesFolder': true,
-        'showCheckboxes': true  // show checkboxes in mail list as default
+        'showCheckboxes': true,  // show checkboxes in mail list as default
+        'authenticity': {
+            // none, fail, fail_trusted, fail_trusted_pass, all, silly
+            level: 'fail_trusted',
+            domains: ''
+        }
     };
 
     return settingsDefaults;
