@@ -14,9 +14,8 @@
 define('io.ox/oauth/backbone', [
     'io.ox/core/http',
     'io.ox/core/yell',
-    'gettext!io.ox/oauth',
     'less!io.ox/oauth/style'
-], function (http, yell, gt) {
+], function (http, yell) {
     'use strict';
 
     var generateId = function () {
@@ -62,6 +61,7 @@ define('io.ox/oauth/backbone', [
             var callbackName = 'oauth' + generateId(),
                 params = {
                     action: 'init',
+                    action_hint: 'reauthorize',
                     serviceId: account.get('serviceId'),
                     displayName: account.get('displayName'),
                     cb: callbackName,
@@ -83,14 +83,18 @@ define('io.ox/oauth/backbone', [
                 popupWindow.location = interaction.authUrl;
 
                 return def;
-            }).then(function () {
+            }).then(function (res) {
+                var def = $.Deferred();
                 delete window['callback_' + callbackName];
                 popupWindow.close();
+                if (res.error) return def.reject(res);
+                return def.resolve(res);
+            }).then(function () {
                 account.enableScopes(account.get('enabledScopes'));
                 account.set('enabledScopes', account.get('wantedScopes'));
                 account.unset('wantedScopes');
                 return account;
-            });
+            }, yell);
         },
         sync: function (method, model, options) {
             switch (method) {
@@ -140,6 +144,11 @@ define('io.ox/oauth/backbone', [
                             model.set(res);
                             return res;
                         });
+                    }).then(function (res) {
+                        return require(['io.ox/oauth/keychain']).then(function (oauthAPI) {
+                            oauthAPI.accounts.add(model);
+                            return res;
+                        });
                     }).done(options.success).fail(options.error);
                 case 'update':
                     return model.reauthorize({ force: false }).then(function () {
@@ -227,12 +236,9 @@ define('io.ox/oauth/backbone', [
         render: function () {
             var shortId = this.model.get('icon') || this.model.id.match(/\.?(\w*)$/)[1] || 'fallback';
             this.$el.append(
-                $('<button>').addClass('btn btn-default').append(
-                    $('<i class="service-icon fa">')
-                        .addClass('logo-' + shortId),
-                    $('<div>')
-                        .addClass('service-label')
-                        .text(this.model.get('displayName'))
+                $('<button type="button" class="btn btn-default">').append(
+                    $('<i class="service-icon fa">').addClass('logo-' + shortId),
+                    $('<div class="service-label">').text(this.model.get('displayName'))
                 ).data({
                     cid: this.model.cid
                 })
@@ -240,21 +246,6 @@ define('io.ox/oauth/backbone', [
             return this;
         }
     });
-
-    var MailServiceItemView = ServiceItemView.extend({
-        render: function () {
-            var shortId = this.model.get('icon') || this.model.id.match(/\.?(\w*)$/)[1] || 'fallback';
-            var label = (this.model.get('displayName') === 'Google') ? gt('Sign in with Google. This will add your Gmail account.') : this.model.get('displayName');
-            this.$el.append(
-                $('<button type="button" class="btn btn-default">').data({ cid: this.model.cid }).append(
-                    $('<i class="service-icon fa">').addClass('logo-' + shortId)
-                ),
-                $('<div class="service-label">').text(label)
-            );
-            return this;
-        }
-    });
-
     var ServicesListView = Backbone.View.extend({
         tagName: 'ul',
         className: 'list-unstyled services-list-view',
@@ -265,19 +256,11 @@ define('io.ox/oauth/backbone', [
         ItemView: ServiceItemView,
         render: function () {
             var ItemView = this.ItemView;
-            var isMailService = this.model && this.model.mailService || false;
             this.$el.append(
                 this.collection.map(function (service) {
-                    var view;
-                    if (isMailService) {
-                        view = new MailServiceItemView({
-                            model: service
-                        });
-                    } else {
-                        view = new ItemView({
-                            model: service
-                        });
-                    }
+                    var view = new ItemView({
+                        model: service
+                    });
                     return view.render().$el;
                 })
             );
@@ -289,7 +272,7 @@ define('io.ox/oauth/backbone', [
 
             var service = this.collection.get($(ev.currentTarget).data('cid'));
             this.trigger('select', service);
-            this.trigger('select:' + service.id, service);
+            this.trigger('select:' + service.get('type'), service);
         }
     });
 
@@ -297,8 +280,7 @@ define('io.ox/oauth/backbone', [
         Account: Account,
         Views: {
             ServicesListView: ServicesListView,
-            ServiceItemView: ServiceItemView,
-            MailServiceItemView: MailServiceItemView
+            ServiceItemView: ServiceItemView
         }
     };
 });
