@@ -64,12 +64,12 @@ define('io.ox/onboarding/clients/wizard', [
             if (!_.contains(['device', 'scenario'], type)) return;
             // tabindex needed (wizard tabtrap)
             return $('<li class="option centered" data-value="back">').append(
-                        $('<button class="link box" role="menuitem">').append(
-                            $('<div class="icon-list">').append(options._getIcons('fa-angle-left')),
-                            // a11y
-                            options._getTitle({ title: gt('back') }).addClass('sr-only')
-                        )
-                    );
+                $('<button class="link box navigation" role="menuitem">').append(
+                    $('<div class="icon-list">').append(options._getIcons('fa-angle-left')),
+                    // a11y
+                    options._getTitle({ title: gt('back') }).addClass('sr-only')
+                )
+            );
         },
 
         _getLink: function (obj) {
@@ -154,6 +154,10 @@ define('io.ox/onboarding/clients/wizard', [
         this.trigger('next');
     }
 
+    function focus() {
+        this.$('.wizard-content').find('button[tabindex!="-1"][disabled!="disabled"]:not(.navigation):visible:first').focus();
+    }
+
     function drawPlatforms() {
         var config = this.parent.config,
             descriptionId = _.uniqueId('description');
@@ -296,7 +300,8 @@ define('io.ox/onboarding/clients/wizard', [
             Wizard.registry.add(opt, this.render.bind(this));
         },
 
-        // set predefined selections
+        // set predefined selections (deep link)
+        // ...&reg=client-onboarding&regopt=platform:windows,device:windows.desktop,scenario:emclientinstall
         set: function (data) {
             var props = { platform: 'platforms', device: 'devices', scenario: 'scenarios' },
                 obj = {};
@@ -308,7 +313,7 @@ define('io.ox/onboarding/clients/wizard', [
                 // invalid value
                 if (!this.config.hash[prop][value]) return;
                 obj[key] = value;
-            });
+            }.bind(this));
             this.model.set(obj);
         },
 
@@ -432,6 +437,7 @@ define('io.ox/onboarding/clients/wizard', [
                     minWidth: '540px'
                 })
                 .on('before:show', drawPlatforms)
+                .on('show', focus)
                 .end()
                 // device
                 .step({
@@ -442,6 +448,7 @@ define('io.ox/onboarding/clients/wizard', [
                     minWidth: '540px'
                 })
                 .on('before:show', drawDevices)
+                .on('show', focus)
                 .end()
                 // scenarios
                 .step({
@@ -452,6 +459,7 @@ define('io.ox/onboarding/clients/wizard', [
                     width: 'auto',
                     minWidth: '540px'
                 })
+                .on('show', focus)
                 .on('before:show', drawScenarios)
                 .end();
             // add some references to steps
