@@ -143,23 +143,23 @@ define('io.ox/search/autocomplete/extensions', [
             // some shortcuts
             ui = {
                 copyhelper: tokenview.$el.data('bs.tokenfield').$copyHelper || $(),
-                field: tokenview.input.attr('autofocus', true)
+                field: tokenview.input.prop('autofocus', true)
             };
 
             var updateState = function (e) {
                 var node = $('.token-input.tt-input'),
                     container = node.closest('.io-ox-search');
                 // no chars entered, no tokens
-                if (!node.val()) {
+                if ((!e || e.type === 'input') && !node.val()) {
                     container.addClass('empty');
                     $('.tokenfield > .twitter-typeahead').show();
-                    ui.copyhelper.removeAttr('disabled');
+                    ui.copyhelper.prop('disabled', false);
                     return;
                 }
                 // token exists
                 if (e.type === 'tokenfield:createdtoken') {
                     $('.tokenfield > .twitter-typeahead').hide();
-                    ui.copyhelper.attr('disabled', true);
+                    ui.copyhelper.prop('disabled', true);
                 }
                 // at least some chars are entered
                 container.removeClass('empty');
@@ -236,7 +236,7 @@ define('io.ox/search/autocomplete/extensions', [
 
             // construct url
             image = (baton.data.item && baton.data.item.image_url ? baton.data.item.image_url + '&height=42&scaleType=contain' : image)
-                .replace(/^https?\:\/\/[^\/]+/i, '');
+                .replace(/^https?:\/\/[^/]+/i, '');
             image = util.replacePrefix(image, ox.apiRoot);
 
             // add image node
