@@ -33,8 +33,9 @@ define('io.ox/search/items/main', [
                 render: view.render,
                 empty: function () {
                     delete this.timestamp;
-                    if (this.length)
+                    if (this.length) {
                         this.reset();
+                    }
                     return collection;
                 }
             });
