@@ -138,6 +138,15 @@ define('io.ox/tasks/actions', [
         }
     });
 
+    new Action('io.ox/tasks/actions/export', {
+        requires: 'some read',
+        multiple: function (list) {
+            require(['io.ox/core/export'], function (exportDialog) {
+                exportDialog.open('tasks', { list: list });
+            });
+        }
+    });
+
     new Action('io.ox/tasks/actions/print', {
         requires: function (e) {
             return e.collection.has('some', 'read') && _.device('!smartphone');
@@ -222,7 +231,7 @@ define('io.ox/tasks/actions', [
             $(this).append($('<div class="toolbar-button">')
                 .append($('<a href="#">')
                     .append(
-                        $('<i class="fa fa-check-square-o">')
+                        $('<i class="fa fa-check-square-o" aria-hidden="true">')
                             .on('click', { grid: data.grid }, function (e) {
                                 e.preventDefault();
                                 e.stopPropagation();
@@ -244,7 +253,7 @@ define('io.ox/tasks/actions', [
             $(this).append($('<div class="toolbar-button">')
                 .append($('<a href="#">')
                     .append(
-                        $('<i class="fa fa-square-o">')
+                        $('<i class="fa fa-square-o" aria-hidden="true">')
                             .on('click', { grid: data.grid }, function (e) {
                                 e.preventDefault();
                                 e.stopPropagation();
@@ -266,7 +275,7 @@ define('io.ox/tasks/actions', [
             $(this).append($('<div class="toolbar-button">')
                 .append($('<a href="#">')
                     .append(
-                        $('<i class="fa fa-sign-in">')
+                        $('<i class="fa fa-sign-in" aria-hidden="true">')
                             .on('click', { grid: data.grid }, function (e) {
                                 e.preventDefault();
                                 e.stopPropagation();
@@ -326,6 +335,15 @@ define('io.ox/tasks/actions', [
         ref: 'io.ox/tasks/actions/confirm'
     }));
 
+    ext.point('io.ox/tasks/links/inline').extend(new links.Link({
+        id: 'export',
+        index: 650,
+        prio: 'lo',
+        mobile: 'lo',
+        label: gt('Export'),
+        ref: 'io.ox/tasks/actions/export'
+    }));
+
     ext.point('io.ox/tasks/links/inline').extend(new links.Link({
         id: 'print',
         index: 700,
