@@ -39,23 +39,17 @@ define('plugins/core/feedback/register', [
             5: gt.pgettext('rating', 'It\'s awesome')
         },
         appWhiteList = [
-            'mail',
-            'contacts',
-            'calendar',
-            'files'
+            'io.ox/mail',
+            'io.ox/contacts',
+            'io.ox/calendar',
+            'io.ox/files'
         ];
 
     function getAppOptions(useWhitelist) {
-        var currentApp,
-            apps = _(appApi.getFavorites()).map(function (app) {
-                app.id = app.id.replace(/io\.ox\/(office\/portal\/|office\/)?/, '');
-
+        var currentApp = ox.ui.App.getCurrentApp(),
+            apps = appApi.forLauncher().map(function (app) {
                 if (useWhitelist && !_(appWhiteList).contains(app.id)) return;
-                // suport for edit dialogs
-                if (ox.ui.App.getCurrentApp() && ox.ui.App.getCurrentApp().get('name').replace(/io\.ox\/(office\/portal\/|office\/)?/, '').indexOf(app.id) === 0) {
-                    currentApp = app;
-                }
-                return $('<option>').val(app.id).text(/*#, dynamic*/gt.pgettext('app', app.title));
+                return $('<option>').val(app.id).text(app.get('title'));
             });
         apps = _(apps).compact();
         return { currentApp: currentApp, apps: apps };
@@ -131,16 +125,19 @@ define('plugins/core/feedback/register', [
             var apps = getAppOptions(true);
 
             if (settings.get('feedback/showModuleSelect', true)) {
+                var preSelect = apps.apps.filter(function (app) {
+                    return app.val() === apps.currentApp.id;
+                });
                 //#. used in feedback dialog for general feedback. Would be "Allgemein" in German for example
                 apps.apps.unshift($('<option>').val('general').text(gt('General')));
                 popupBody.append(
                     this.appSelect = $('<select class="feedback-select-box form-control">').append(apps.apps)
                 );
-                this.appSelect.val((apps.currentApp ? apps.currentApp.id : apps.apps[0].val()));
+                this.appSelect.val(preSelect.length > 0 && preSelect[0].val() || apps.apps[0].val());
             } else if (apps.currentApp) {
                 popupBody.append(
-                    $('<div class="form-control">').text(/*#, dynamic*/gt.pgettext('app', apps.currentApp.title)),
-                    this.appSelect = $('<div aria-hidden="true">').val(apps.currentApp.id).hide()
+                    $('<div class="form-control">').text(apps.currentApp.get('name')),
+                    this.appSelect = $('<div aria-hidden="true">').val(apps.currentApp.get('name')).hide()
                 );
             } else {
                 popupBody.append(
@@ -216,12 +213,6 @@ define('plugins/core/feedback/register', [
             };
         }
     });
-    // for custom dev
-    ext.point('plugins/core/feedback').extend({
-        id: 'process',
-        index: 200,
-        process: $.noop
-    });
 
     var modes = {
             nps: {
@@ -318,7 +309,7 @@ define('plugins/core/feedback/register', [
                             // feedback
                             score: this.ratingView.getValue(),
                             app: this.ratingView.appSelect ? this.ratingView.appSelect.val() : 'general',
-                            entry_point: (currentApp ? currentApp.id : 'general'),
+                            entry_point: (currentApp ? currentApp.get('name') : 'general'),
                             comment: this.$('.feedback-note').val() || '',
                             // system info
                             operating_system: 'Other',
@@ -335,17 +326,9 @@ define('plugins/core/feedback/register', [
                             data.operating_system = key;
                         }
                         if (!found && _.isNumber(val)) {
-                            // distinguish correctly between IE and edge
-                            // TODO can be removed when edge is no longer recognized as IE with higher version
-                            if (key === 'IE' && _.browser.edge) {
-                                data.browser = 'Edge';
-                                // round to one decimal place
-                                data.browser_version = parseInt(_.browser.Edge * 10, 10) / 10;
-                            } else {
-                                data.browser = key;
-                                data.browser_version = val;
-                            }
                             found = true;
+                            data.browser = key;
+                            data.browser_version = val;
                         }
                     });
 
@@ -383,7 +366,7 @@ define('plugins/core/feedback/register', [
                                 data.operating_system = 'Windows 8.1';
                                 break;
                             }
-                            if (navigator.userAgent.match(/Windows NT [10\.0|6\.4]?/)) {
+                            if (navigator.userAgent.match(/Windows NT [10.0|6.4]?/)) {
                                 data.operating_system = 'Windows 10';
                                 break;
                             }
@@ -395,10 +378,6 @@ define('plugins/core/feedback/register', [
                             break;
                         // no default
                     }
-
-                    var baton = ext.Baton.ensure(data);
-                    ext.point('plugins/core/feedback').invoke('process', this, baton);
-                    data = baton.data;
                     sendFeedback(data)
                         .done(function () {
                             //#. popup info message
@@ -415,7 +394,7 @@ define('plugins/core/feedback/register', [
 
         drawButton: function () {
             var button;
-            $('#io-ox-screens').append(
+            $('#io-ox-core').append(
                 button = $('<button type="button" class="feedback-button">')
                 .text(gt('Feedback'))
                 .addClass(settings.get('feedback/position', 'right') + 'side-button')
@@ -428,16 +407,14 @@ define('plugins/core/feedback/register', [
         }
     };
 
-    ext.point('io.ox/core/topbar/right/dropdown').extend({
+    ext.point('io.ox/core/appcontrol/right/dropdown').extend({
         id: 'feedback',
-        index: 250,
-        draw: function () {
+        index: 240,
+        extend: function () {
             var currentSetting = settings.get('feedback/show', 'both');
             if (currentSetting === 'both' || currentSetting === 'topbar') {
                 this.append(
-                    $('<li role="presentation">').append(
-                        $('<a href="#" data-action="feedback" role="menuitem" tabindex="-1">').text(gt('Give feedback'))
-                    )
+                    $('<a href="#" data-action="feedback" role="menuitem" tabindex="-1">').text(gt('Give feedback'))
                     .on('click', function (e) {
                         e.preventDefault();
                         feedback.show();
