@@ -48,7 +48,7 @@ define('plugins/portal/files/register', [
                     }
                 },
                 function fail(e) {
-                    return /^(FILE_STORAGE-0026|IFO-0300)$/.test(e.code) ? 'remove' : e;
+                    throw /^(FILE_STORAGE-0026|IFO-0300)$/.test(e.code) ? 'remove' : e;
                 }
             );
         },
@@ -106,7 +106,8 @@ define('plugins/portal/files/register', [
                 require(['io.ox/files/actions'], function () {
                     api.get(e.data.file).then(function (file) {
                         var model = api.pool.get('detail').get(_.cid(file));
-                        var baton = new ext.Baton({ data: e.data.file, model: model, collection: model.collection });
+                        var collection = new Backbone.Collection(model);
+                        var baton = new ext.Baton({ data: e.data.file, model: model, collection: collection });
                         ext.point('io.ox/files/actions/viewer').invoke('action', this, baton);
                     });
                 });
