@@ -19,45 +19,46 @@ module.exports = function (grunt) {
         concat: {
             bootjs: {
                 options: {
-                    banner: 'dependencies = {};\n'
+                    banner: 'if (typeof dependencies === "undefined") dependencies = {};\n'
                 },
                 files: [
                     {
                         src: [
-                            'bower_components/jquery/dist/jquery.js',
-                            'lib/jquery.mobile.touch.min.js',
-                            'bower_components/underscore/underscore.js', // load this before require.js to keep global object
+                            'node_modules/jquery/dist/jquery.js',
+                            //'node_modules/jquery-migrate/dist/jquery-migrate.js',
+                            'node_modules/jquery-touch-events/src/jquery.mobile-events.min.js',
+                            'node_modules/underscore/underscore.js', // load this before require.js to keep global object
                             'build/ox.js',
                             // add backbone and dot.js may be a AMD-variant would be better
-                            'bower_components/backbone/backbone.js',
-                            'bower_components/backbone-validation/dist/backbone-validation.js',
+                            'node_modules/backbone/backbone.js',
+                            'node_modules/backbone-validation/dist/backbone-validation.js',
                             // load moment before require, because of anonymous define
                             'build/static/3rd.party/moment/moment.js',
                             'build/static/3rd.party/moment/moment-timezone-with-data.js',
                             'build/static/3rd.party/moment/moment-interval.js',
-                            'build/static/3rd.party/velocity/velocity.min.js',
+                            'node_modules/velocity-animate/velocity.min.js',
                             'src/util.js',
-                            'bower_components/requirejs/require.js',
-                            'lib/require-fix.js',
+                            'node_modules/requirejs/require.js',
+                            'src/require-fix.js',
                             'lib/modernizr.js',
                             'src/lazyload.js',
                             'src/browser.js',
                             'src/plugins.js',
                             'src/jquery.plugins.js',
 
-                            'bower_components/blankshield/blankshield.js',
+                            'node_modules/blankshield/blankshield.js',
                             // add bootstrap JavaScript
-                            'bower_components/bootstrap/js/transition.js',
-                            'bower_components/bootstrap/js/alert.js',
-                            'bower_components/bootstrap/js/button.js',
-                            'bower_components/bootstrap/js/carousel.js',
-                            'bower_components/bootstrap/js/collapse.js',
-                            'bower_components/bootstrap/js/modal.js',
-                            'bower_components/bootstrap/js/tooltip.js',
-                            'bower_components/bootstrap/js/popover.js',
-                            'bower_components/bootstrap/js/scrollspy.js',
-                            'bower_components/bootstrap/js/tab.js',
-                            'bower_components/bootstrap/js/affix.js',
+                            'node_modules/bootstrap/js/transition.js',
+                            'node_modules/bootstrap/js/alert.js',
+                            'node_modules/bootstrap/js/button.js',
+                            'node_modules/bootstrap/js/carousel.js',
+                            'node_modules/bootstrap/js/collapse.js',
+                            'node_modules/bootstrap/js/modal.js',
+                            'node_modules/bootstrap/js/tooltip.js',
+                            'node_modules/bootstrap/js/popover.js',
+                            'node_modules/bootstrap/js/scrollspy.js',
+                            'node_modules/bootstrap/js/tab.js',
+                            'node_modules/bootstrap/js/affix.js',
                             // add custom bootstrap code
                             'apps/io.ox/core/tk/dropdown.js',
                             'lib/bootstrap-a11y.js',
@@ -80,6 +81,9 @@ module.exports = function (grunt) {
                             'apps/io.ox/core/settings/defaults.js',
                             'apps/io.ox/core/moment.js',
                             'apps/io.ox/core/viewer/main.js',
+                            'apps/io.ox/core/main/icons.js',
+                            'apps/io.ox/core/extPatterns/stage.js',
+                            'apps/io.ox/core/sockets.js',
                             // missing for signin
                             'apps/io.ox/core/boot/config.js',
                             'apps/io.ox/core/boot/fixes.js',
@@ -93,6 +97,7 @@ module.exports = function (grunt) {
                             'apps/io.ox/core/boot/login/openid.js',
                             'apps/io.ox/core/boot/login/standard.js',
                             'apps/io.ox/core/boot/login/token.js',
+                            'apps/io.ox/core/boot/warning.js',
                             'apps/io.ox/core/boot/main.js',
                             'build/apps/io.ox/core/boot.en_US.js',
                             'build/apps/io.ox/core/boot.de_DE.js',
@@ -126,7 +131,6 @@ module.exports = function (grunt) {
                             'apps/io.ox/find/view-placeholder.js',
                             'apps/io.ox/core/desktop.js',
                             'apps/io.ox/core/api/apps.js',
-                            'apps/io.ox/core/extPatterns/stage.js',
                             'apps/io.ox/core/yell.js',
                             'apps/io.ox/core/notifications.js',
                             'apps/io.ox/core/commons.js',
@@ -158,7 +162,6 @@ module.exports = function (grunt) {
                             'apps/io.ox/core/folder/favorites.js',
                             'apps/io.ox/core/folder/view.js',
                             'apps/io.ox/core/folder/extensions.js',
-                            'apps/io.ox/core/folder/folder-color.js',
                             // defaults
                             'apps/io.ox/core/settings/defaults.js',
                             'apps/io.ox/core/settingOptions/settings/defaults.js',
@@ -180,8 +183,19 @@ module.exports = function (grunt) {
                             'apps/io.ox/core/tk/selection.js',
                             'apps/io.ox/core/tk/visibility-api-util.js',
                             'apps/io.ox/core/desktopNotifications.js',
-                            'apps/io.ox/core/notifications/badgeview.js',
                             // core
+                            'apps/io.ox/core/main/addLauncher.js',
+                            'apps/io.ox/core/main/appcontrol.js',
+                            'apps/io.ox/core/main/autologout.js',
+                            'apps/io.ox/core/main/debug.js',
+                            'apps/io.ox/core/main/apps.js',
+                            'apps/io.ox/core/main/logout.js',
+                            'apps/io.ox/core/main/offline.js',
+                            'apps/io.ox/core/main/refresh.js',
+                            'apps/io.ox/core/main/registry.js',
+                            'apps/io.ox/core/main/stages.js',
+                            'apps/io.ox/core/main/topbar_right.js',
+                            'apps/io.ox/core/main/warning.js',
                             'apps/io.ox/core/main.js',
                             'apps/io.ox/core/links.js',
                             // mail app
@@ -241,7 +255,6 @@ module.exports = function (grunt) {
                             'apps/io.ox/core/tk/list-selection.js',
                             'apps/io.ox/backbone/mini-views/abstract.js',
                             'apps/io.ox/mail/detail/content.js',
-                            'apps/io.ox/core/emoji/util.js',
                             'apps/io.ox/mail/detail/links.js',
                             'apps/io.ox/core/download.js',
                             // mail app - main
@@ -256,25 +269,25 @@ module.exports = function (grunt) {
                 files: [
                     {
                         src: [
-                            'bower_components/mobiscroll/js/mobiscroll.core.js',
-                            'bower_components/mobiscroll/js/mobiscroll.util.datetime.js',
-                            'bower_components/mobiscroll/js/mobiscroll.frame.js',
-                            'bower_components/mobiscroll/js/mobiscroll.scroller.js',
-                            'bower_components/mobiscroll/js/mobiscroll.datetimebase.js',
-                            'bower_components/mobiscroll/js/mobiscroll.datetime.js',
-                            'bower_components/mobiscroll/js/mobiscroll.frame.ios.js'
+                            'node_modules/mobiscroll/js/mobiscroll.core.js',
+                            'node_modules/mobiscroll/js/mobiscroll.util.datetime.js',
+                            'node_modules/mobiscroll/js/mobiscroll.frame.js',
+                            'node_modules/mobiscroll/js/mobiscroll.scroller.js',
+                            'node_modules/mobiscroll/js/mobiscroll.datetimebase.js',
+                            'node_modules/mobiscroll/js/mobiscroll.datetime.js',
+                            'node_modules/mobiscroll/js/mobiscroll.frame.ios.js'
                         ],
-                        dest: 'build/static/3rd.party/mobiscroll/mobiscroll.js',
+                        dest: 'build/static/3rd.party/mobiscroll.js',
                         nonull: true
                     },
                     {
                         src: [
-                            'bower_components/mobiscroll/css/mobiscroll.frame.css',
-                            'bower_components/mobiscroll/css/mobiscroll.frame.ios.css',
-                            'bower_components/mobiscroll/css/mobiscroll.scroller.css',
-                            'bower_components/mobiscroll/css/mobiscroll.scroller.ios.css'
+                            'node_modules/mobiscroll/css/mobiscroll.frame.css',
+                            'node_modules/mobiscroll/css/mobiscroll.frame.ios.css',
+                            'node_modules/mobiscroll/css/mobiscroll.scroller.css',
+                            'node_modules/mobiscroll/css/mobiscroll.scroller.ios.css'
                         ],
-                        dest: 'build/apps/3rd.party/mobiscroll/mobiscroll.css',
+                        dest: 'build/apps/3rd.party/mobiscroll.css',
                         nonull: true
                     }
                 ]
@@ -304,10 +317,7 @@ module.exports = function (grunt) {
                             '\n',
                     footer: '\n' +
                             '  define.amd = _amd;\n' +
-                            '});\n\n' +
-                            'define("static/3rd.party/typeahead.js/dist/typeahead.jquery.js", _.noop);\n' +
-                            'define("static/3rd.party/jquery-ui.min.js", _.noop);\n' +
-                            'define("static/3rd.party/bootstrap-tokenfield/js/bootstrap-tokenfield.js", _.noop);\n'
+                            '});\n\n'
                 },
                 files: [
                     {
@@ -328,10 +338,7 @@ module.exports = function (grunt) {
                             'apps/io.ox/core/api/snippets.js',
                             'apps/io.ox/core/tk/contenteditable-editor.js',
                             'apps/io.ox/core/tk/textproc.js',
-                            'bower_components/tinymce-dist/jquery.tinymce.min.js',
-                            'build/static/3rd.party/jquery-ui.min.js',
-                            'build/static/3rd.party/typeahead.js/dist/typeahead.jquery.js',
-                            'build/static/3rd.party/bootstrap-tokenfield/js/bootstrap-tokenfield.js'
+                            'node_modules/tinymce/jquery.tinymce.min.js'
                         ],
                         dest: 'build/apps/io.ox/mail/compose/bundle.js',
                         nonull: true
@@ -371,34 +378,6 @@ module.exports = function (grunt) {
                         nonull: true
                     }
                 ]
-            },
-            emoji: {
-                options: {
-                    banner: 'define.async("io.ox/emoji/bundle", [], function () {\n\n' +
-                                '"use strict";\n\n',
-                    /* define 2nd wave that can not be included directly, so should need 2 requests to load emoji feature completely */
-                    footer: '\n\nreturn require([' +
-                            '"css!3rd.party/emoji/emoji.css",' +
-                            '"less!io.ox/emoji/emoji",' +
-                            '"gettext!io.ox/mail/emoji",' +
-                            '"raw!io.ox/emoji/unified.json",' +
-                            '"raw!io.ox/emoji/softbank.json",' +
-                            '"raw!io.ox/emoji/japan_carrier.json",' +
-                            '"3rd.party/emoji/emoji"' +
-                            ']).then(function () { return require(["io.ox/emoji/main"]); });\n});\n'
-                },
-                files: [
-                    {
-                        src: [
-                            'apps/io.ox/mail/emoji/settings/defaults.js',
-                            'apps/io.ox/emoji/categories.js',
-                            'apps/io.ox/emoji/conversions.js',
-                            'apps/io.ox/emoji/main.js'
-                        ],
-                        dest: 'build/apps/io.ox/emoji/bundle.js',
-                        nonull: true
-                    }
-                ]
             }
         }
     });
