@@ -46,7 +46,7 @@ define(['fixture!browser_support/userAgents.json'], function (userAgents) {
                 it('should detect ' + browser + ' ' + version, function () {
                     _.device.loadUA(userAgents.valid[browser][version]);
                     expect(_.device(browser), '_.device called with "' + browser + '"').to.be.true;
-                    expect(parseFloat(_.browser[browser])).to.be.at.least(version);
+                    expect(parseFloat(_.browser[browser])).to.be.at.least(Number(version.split(' ')[0]));
                 });
             });
         });
@@ -82,9 +82,7 @@ define(['fixture!browser_support/userAgents.json'], function (userAgents) {
             it('should use the fallback "unknown" if an unknown or broken user agent occurs', function () {
                 var spy = sinon.stub(console, 'warn').callsFake(function () {});
                 _.device.loadUA(userAgents.invalid[number]);
-                //FIXME: really test spy
-                //expect(spy).toHaveBeenCalledWithMatch('Could not detect browser, using fallback');
-                expect(spy).to.have.beenCalled;
+                expect(spy).to.have.been.calledWithMatch('Could not detect browser, using fallback');
                 expect(_.browser.unknown).to.be.true;
                 spy.restore();
             });
@@ -114,11 +112,38 @@ define(['fixture!browser_support/userAgents.json'], function (userAgents) {
             expect(window.isPlatformSupported()).to.be.false;
         });
 
-        it.skip('should handle Chrome on Windows 8 convertible devices as non-touch devices', function () {
+        it('should handle Chrome on Windows 8 convertible devices as non-touch devices', function () {
+            _.device.cache = {};
             _.device.loadUA(userAgents.valid.Chrome[34]);
             expect(_.device('touch')).to.be.false;
             expect(_.browser.windows8).to.be.true;
         });
-
+        it('should handle Firefox on Windows desktops as non-touch devices', function () {
+            _.device.cache = {};
+            _.device.loadUA(userAgents.valid.Firefox['52 Windows']);
+            expect(_.device('touch')).to.be.false;
+            expect(_.browser.windows).to.be.true;
+        });
+        it('should handle Chrome on Linux convertible devices as non-touch devices', function () {
+            _.device.cache = {};
+            _.device.loadUA(userAgents.valid.Chrome[59]);
+            expect(_.device('touch')).to.be.false;
+            expect(_.device('linux')).to.be.true;
+            expect(_.device('android')).to.be.false;
+        });
+        it('should handle Chrome on Android as touch device', function () {
+            // report touch!
+            var removeFakeTouch = false;
+            if (!window.ontouchstart) {
+                window.ontouchstart = _.noop;
+                removeFakeTouch = true;
+            }
+            _.device.cache = {};
+            _.device.loadUA(userAgents.valid.Android[6]);
+            expect(_.device('touch')).to.be.true;
+            expect(_.device('linux')).to.be.false;
+            expect(_.device('android')).to.be.true;
+            if (removeFakeTouch) delete window.ontouchstart;
+        });
     });
 });
