@@ -25,7 +25,7 @@
     $.escape = function (str) {
         // escape !"#$%&'()*+,./:;<=>?@[\]^`{|}~
         // see http://api.jquery.com/category/selectors/
-        return String(str).replace(/([!"#$%&'()*+,.\/:;<=>?@[\\\]^`{|}~])/g, '\\$1');
+        return String(str).replace(/([!"#$%&'()*+,./:;<=>?@[\\\]^`{|}~])/g, '\\$1');
     };
 
     $.button = function (options) {
@@ -70,7 +70,7 @@
         if (opt.purelink === true) {
             button = $('<a>').addClass(className).append(text);
         } else {
-            button = $('<button>').addClass(className).append(
+            button = $('<button type="button">').addClass(className).append(
                 $('<span>').append(text)
             );
         }
@@ -126,6 +126,22 @@
         node.scrollIntoView(/^(top|top:partial)$/.test(scrolledOut));
     };
 
+    //
+    // Unified and simplified solution
+    // should cover all cases, i.e. $.fn.intoViewport AND (newer) $.fn.intoView
+    //
+    $.fn.scrollIntoViewIfNeeded = function () {
+        var node = this[0], pane = $(node).closest('.scrollable-pane, .scrollpane')[0];
+        if (!node || !pane) return;
+        var outer = pane.getBoundingClientRect(), inner;
+        // first: bottom up
+        inner = node.getBoundingClientRect();
+        if (inner.bottom > outer.bottom) pane.scrollTop += inner.bottom - outer.bottom;
+        // second: top down
+        inner = node.getBoundingClientRect();
+        if (inner.top < outer.top) pane.scrollTop -= outer.top - inner.top;
+    };
+
     $.fn.intoViewport = function (node) {
 
         if (!node) node = this.closest('.scrollable-pane,.scrollpane');
