@@ -23,7 +23,7 @@
             var i = 0, $l = pairs.length, pair, obj = {}, d = decodeURIComponent;
             for (; i < $l; i++) {
                 pair = pairs[i];
-                var keyValue = pair.split(/\=/), key = keyValue[0], value = keyValue[1];
+                var keyValue = pair.split('='), key = keyValue[0], value = keyValue[1];
                 if (key !== '' || value !== undefined) {
                     obj[d(key)] = value !== undefined ? d(value) : undefined;
                 }
@@ -126,11 +126,20 @@
          */
         param: function (obj) {
             return this.serialize(obj, ' / ', _.identity);
+        },
+
+        // quite like param but also drop undefined values
+        cacheKey: function (obj) {
+            return this.param($.extend({}, obj));
         }
     });
 
     $(window).resize(_.recheckDevice);
 
+    $(document).on('shown.bs.popover hide.bs.popover', function (e) {
+        $(e.target).toggleClass('popover-open', e.type === 'shown');
+    });
+
     //
     // Cookie handling
     //
@@ -289,7 +298,7 @@
                 // firefox has a bug and already decodes the hash string, so we use href
                 var hash = location.href.split(/#/)[1] || '';
                 url.data = url.decrypt(deserialize(
-                     hash.substr(0, 1) === '?' ? rot(decodeURIComponent(hash.substr(1)), -1) : hash
+                    hash.substr(0, 1) === '?' ? rot(decodeURIComponent(hash.substr(1)), -1) : hash
                 ));
             }
 
@@ -320,7 +329,7 @@
 
         get: function (path) {
             var l = location;
-            return l.protocol + '//' + l.host + l.pathname.replace(/\/[^\/]*$/, '/' + path);
+            return l.protocol + '//' + l.host + l.pathname.replace(/\/[^/]*$/, '/' + path);
         },
 
         // replace [variables] in a string; usually an URL. Values get escaped.
@@ -682,7 +691,7 @@
                 regXSearchWhitespaceGlobally = (/[\x09\x0A\x0B\x0C\x0D\x20\xA0\u1680\u180E\u2000\u2001\u2002\u2003\u2004\u2005\u2006\u2007\u2008\u2009\u200A\u202F\u205F\u3000\u2028\u2029]+/g),
                 regXSearchZeroWhitespaceGlobally = (/[\u200B\uFEFF]+/g),
 
-              //softHyphenChar = '\u00AD',
+                //softHyphenChar = '\u00AD',
                 nonBreakingHyphenChar = '\u2011',
                 nonBreakingWhitespaceChar = '\u00A0',
                 breakingZeroWhitespaceChar = '\u200B';
@@ -716,6 +725,41 @@
             return node;
         },
 
+        // deferred helpers
+
+        allResolved: function () {
+            return _.whenSome.apply(undefined, arguments).then(function (data) { return data.resolved; });
+        },
+
+        allRejected: function () {
+            return _.whenSome.apply(undefined, arguments).then(function (data) { return data.rejected; });
+        },
+
+        // $.when-like api that always resolved with { resolved: [], rejected: [] }
+        whenSome: function () {
+            var def = $.Deferred(),
+                args = Array.prototype.slice.call(arguments),
+                resp = { resolved: [], rejected: [] },
+                remaining = args.length;
+
+            _.each(args, function (item, index) {
+                // wrap to support non-deferred objects
+                $.when(item).always(_.partial(process, _, item, index));
+            });
+
+            function process(data, item, index) {
+                var state = item && _.isFunction(item.state) ? item.state() : 'resolved';
+                // keep order and remove invalid afterwards
+                resp[state][index] = data;
+                if (--remaining) return;
+                def.resolve({
+                    resolved: _.compact(resp.resolved),
+                    rejected: _.compact(resp.rejected)
+                });
+            }
+            return def.promise();
+        },
+
         // makes sure you have an array
         getArray: function (o) {
             return _.isArray(o) ? o : [o];
@@ -836,7 +880,9 @@
                 }
                 // add tail (with just 1 parameter substring and substr are identical)
                 parts[p] += s.substring(index);
-                return p === 0 ? { id: parts[0] } : { folder_id: parts[0], id: parts[1] };
+                // some apis use folder (chronos) and some use folder_id
+                // TODO look if this creates problems
+                return p === 0 ? { id: parts[0] } : { folder_id: parts[0], folder: parts[0], id: parts[1] };
             }
 
             return function (o) {
@@ -888,9 +934,11 @@
             return tmp;
         },
 
-        noI18n: !_.url.hash('debug-i18n') ? _.identity : function (text) {
-            return '\u200b' + String(text).replace(/[\u200b\u200c]/g, '') + '\u200c';
-        }
+        noI18n: (function () {
+            return !_.url.hash('debug-i18n') ? _.identity : function (text) {
+                return '\u200b' + String(text).replace(/[\u200b\u200c]/g, '') + '\u200c';
+            };
+        }())
     });
 
     _.noI18n.fix = !_.url.hash('debug-i18n') ? _.identity : function (text) {
@@ -927,13 +975,12 @@
     _.unescapeHTML = function (html) {
         /*eslint no-nested-ternary: 0*/
         return (html || '').replace(/&(?:(\w+)|#x([0-9A-Fa-f]+)|#(\d+));/g,
-                            function (original, entity, hex, dec) {
-                                return entity ? _.unescapeHTML.entities[entity] || original :
-                                       hex ? String.fromCharCode(parseInt(hex, 16)) : String.fromCharCode(parseInt(dec, 10));
-                            });
+            function (original, entity, hex, dec) {
+                return entity ? _.unescapeHTML.entities[entity] || original :
+                    hex ? String.fromCharCode(parseInt(hex, 16)) : String.fromCharCode(parseInt(dec, 10));
+            });
     };
 
-    /* jshint -W015 */
     _.unescapeHTML.entities = (function (es) {
         for (var i in es) {
             es[i] = String.fromCharCode(es[i]);
@@ -983,6 +1030,5 @@
         sbquo: 8218, ldquo: 8220, rdquo: 8221, bdquo: 8222, dagger: 8224,
         Dagger: 8225, permil: 8240, lsaquo: 8249, rsaquo: 8250, euro: 8364
     }));
-    /* jshint +W015 */
 
 }());
