@@ -74,7 +74,7 @@ less.Parser.fileLoader = function (file, currentFileInfo, callback, env) {
     for (var i = 0; i < themes.length; i++) {
         var dir = themes[i];
         if (!dir.isDirectory()) continue;
-        function subDir(name) { return new java.io.File(dir, name); }
+        var subDir = function (name) { return new java.io.File(dir, name); };
         var defs2 = subDir('definitions.less');
 
         //clean up css files that are most likely generated by update-themes
